//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Core/Background/ConstantBackground.h
//! @brief     Defines class ConstantBackground.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_CORE_BACKGROUND_CONSTANTBACKGROUND_H
#define BORNAGAIN_CORE_BACKGROUND_CONSTANTBACKGROUND_H

#include "Core/Background/IBackground.h"

//! Constant background, to be added to simulated scattering.
//!
//! @ingroup background

class ConstantBackground : public IBackground {
public:
    ConstantBackground(std::vector<double> P);
    ConstantBackground(double background_value);

    ConstantBackground* clone() const override;
    std::string className() const final { return "ConstantBackground"; }
    // const auto tooltip = "class_tooltip";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"BackgroundValue", "", "para_tooltip", 0, +INF, 0}};
    }

    double backgroundValue() const { return m_background_value; }

    double addBackground(double intensity) const override;

private:
    const double& m_background_value;
};

#endif // BORNAGAIN_CORE_BACKGROUND_CONSTANTBACKGROUND_H
