//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Core/Background/PoissonBackground.h
//! @brief     Defines class PoissonBackground.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_CORE_BACKGROUND_POISSONBACKGROUND_H
#define BORNAGAIN_CORE_BACKGROUND_POISSONBACKGROUND_H

#include "Core/Background/IBackground.h"

//! Poisson distributed noise, to be added to simulated scattering.
//!
//! @ingroup background

class PoissonBackground : public IBackground {
public:
    PoissonBackground();
    PoissonBackground* clone() const override;
    std::string className() const final { return "PoissonBackground"; }
    // const auto tooltip = "class_tooltip";

    double addBackground(double intensity) const override;
};

#endif // BORNAGAIN_CORE_BACKGROUND_POISSONBACKGROUND_H
