//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Core/Contrib/ParticleLayoutContribution.h
//! @brief     Defines class ParticleLayoutContribution.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_CORE_CONTRIB_PARTICLELAYOUTCONTRIBUTION_H
#define BORNAGAIN_CORE_CONTRIB_PARTICLELAYOUTCONTRIBUTION_H

#include <memory>

class IInterparticleStrategy;
class reLayout;
class DiffuseElement;
class SimulationOptions;

//! Computes the scattering contribution from one particle layout.
//! Instances are created and used by DWBAComputation.

class ParticleLayoutContribution final {
public:
    ParticleLayoutContribution(const reLayout& re_layout, const SimulationOptions& options,
                               bool polarized);
    ~ParticleLayoutContribution();

    void compute(DiffuseElement& ele) const;

private:
    const reLayout& m_layout;
    const std::unique_ptr<const IInterparticleStrategy> m_interparticle_strategy;
};

#endif // BORNAGAIN_CORE_CONTRIB_PARTICLELAYOUTCONTRIBUTION_H
#endif // USER_API
