//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Descriptor/DoubleProperty.h
//! @brief     Defines class DoubleProperty
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_DESCRIPTOR_DOUBLEPROPERTY_H
#define BORNAGAIN_GUI_MODEL_DESCRIPTOR_DOUBLEPROPERTY_H

#include "GUI/Model/Descriptor/DoubleDescriptor.h"

class Streamer;

// #baMigration docu
class DoubleProperty {
public:
    void init(const QString& label, const QString& tooltip, double value,
              const variant<QString, Unit>& unit, const QString& persistentTag);
    void init(const QString& label, const QString& tooltip, double value,
              const variant<QString, Unit>& unit, int decimals, const RealLimits& limits,
              const QString& persistentTag);

    DoubleDescriptor descriptor() const { return m_descriptor; }
    operator DoubleDescriptor() const { return m_descriptor; }
    operator double() const { return m_value; }
    void set(double d) { m_value = d; }
    double get() const { return m_value; }

    QString persistentTag() const { return m_persistentTag; }
    QString uid() const { return m_uid; }
    void setUid(const QString& uid) { m_uid = uid; }
    unsigned decimals() const { return m_decimals; }
    void setDecimals(unsigned decimals) { m_decimals = decimals; }
    void setTooltip(const QString& tooltip);
    void setUnit(const variant<QString, Unit>& unit);
    void setLimits(const RealLimits& limits);

    bool isInitialized() const;

private:
    double m_value = 0.0;
    unsigned m_decimals = 3;
    QString m_persistentTag;
    QString m_uid;

    DoubleDescriptor m_descriptor;
};

namespace Serialize {
void rwProperty(Streamer& s, DoubleProperty& d);
} // namespace Serialize

//! Add a member, a getter and a setter for a DoubleProperty
#define DOUBLE_PROPERTY(nameLower, nameUpper)                                                      \
protected:                                                                                         \
    DoubleProperty m_##nameLower;                                                                  \
                                                                                                   \
public:                                                                                            \
    DoubleDescriptor nameLower() const { return m_##nameLower; }                                   \
    void set##nameUpper(double v) { m_##nameLower.set(v); }


#endif // BORNAGAIN_GUI_MODEL_DESCRIPTOR_DOUBLEPROPERTY_H
