//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Descriptor/VectorProperty.h
//! @brief     Defines class VectorProperty
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_DESCRIPTOR_VECTORPROPERTY_H
#define BORNAGAIN_GUI_MODEL_DESCRIPTOR_VECTORPROPERTY_H

#include "GUI/Model/Descriptor/VectorDescriptor.h"
#include <heinz/Vectors3D.h>

class Streamer;

//! Holds a 3D vector of type R3 as well as additional info like label, tooltip.
//!
//! Use this as a member in your class to hold a 3D vector if you want to have support for
//! serialization, and if this vector is editable on the UI.

class VectorProperty {
public:
    void init(const QString& label, const QString& tooltip, const variant<QString, Unit>& unit,
              const QString& persistentTag);

    VectorDescriptor descriptor() const { return m_descriptor; }
    operator VectorDescriptor() const { return m_descriptor; }
    operator R3() const { return m_value; }
    void set(const R3& d) { m_value = d; }
    R3 get() const { return m_value; }

    QString persistentTag() const { return m_persistentTag; }
    QString uid() const { return m_uid; }
    void setUid(const QString& uid) { m_uid = uid; }

    R3& r3() { return m_value; }

private:
    R3 m_value;
    QString m_persistentTag;
    QString m_uid;

    VectorDescriptor m_descriptor;
};

namespace Serialize {
void rwProperty(Streamer& s, VectorProperty& d);
} // namespace Serialize

//! Add a member, a getter and a setter for a VectorProperty
#define VECTOR_PROPERTY(nameLower, nameUpper)                                                      \
protected:                                                                                         \
    VectorProperty m_##nameLower;                                                                  \
                                                                                                   \
public:                                                                                            \
    VectorDescriptor nameLower() const { return m_##nameLower; }                                   \
    void set##nameUpper(const R3& v) { m_##nameLower.set(v); }
;


#endif // BORNAGAIN_GUI_MODEL_DESCRIPTOR_VECTORPROPERTY_H
