//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Device/RectangularDetectorItem.h
//! @brief     Defines class RectangularDetectorItem
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_DEVICE_RECTANGULARDETECTORITEM_H
#define BORNAGAIN_GUI_MODEL_DEVICE_RECTANGULARDETECTORITEM_H

#include "Device/Detector/RectangularDetector.h"
#include "GUI/Model/Descriptor/AxisProperty.h"
#include "GUI/Model/Descriptor/DoubleProperty.h"
#include "GUI/Model/Descriptor/VectorProperty.h"
#include "GUI/Model/Device/DetectorItems.h"

class RectangularDetectorItem : public DetectorItem {
private:
    static constexpr auto P_X_AXIS{"X axis"};
    static constexpr auto P_Y_AXIS{"Y axis"};
    static constexpr auto P_NORMAL{"Normal vector"};
    static constexpr auto P_DIRECTION{"Direction vector"};
    static constexpr auto P_U0{"u0"};
    static constexpr auto P_V0{"v0"};
    static constexpr auto P_DBEAM_U0{"u0 (dbeam)"};
    static constexpr auto P_DBEAM_V0{"v0 (dbeam)"};
    static constexpr auto P_DISTANCE{"Distance"};

public:
    RectangularDetectorItem();

    void serialize(Streamer& s) override;

    int xSize() const override;
    void setXSize(size_t nx) override;

    int ySize() const override;
    void setYSize(size_t ny) override;

    DOUBLE_PROPERTY(width, Width);
    DOUBLE_PROPERTY(height, Height);

    void setDetectorAlignment(RectangularDetector::EDetectorArrangement alignment);
    RectangularDetector::EDetectorArrangement detectorAlignment() const;
    SelectionDescriptor<RectangularDetector::EDetectorArrangement>
    detectorAlignmentSelection() const;

    //! The properties of the currently active alignment. Sorted as expected on the UI
    QVector<std::variant<VectorDescriptor, DoubleDescriptor>> alignmentPropertiesForUI() const;

    VECTOR_PROPERTY(normalVector, NormalVector);
    VECTOR_PROPERTY(directionVector, DirectionVector);

    DOUBLE_PROPERTY(u0, U0);
    DOUBLE_PROPERTY(v0, V0);
    DOUBLE_PROPERTY(distance, Distance);

private:
    std::unique_ptr<IDetector2D> createDomainDetector() const override;
    void updateTooltips();

private:
    RectangularDetector::EDetectorArrangement m_detectorAlignment;
    int m_xSize;
    int m_ySize;
};

#endif // BORNAGAIN_GUI_MODEL_DEVICE_RECTANGULARDETECTORITEM_H
