//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/AxisPropertyEditor.cpp
//! @brief     Implement class AxisPropertyEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2022
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Instrument/AxisPropertyEditor.h"
#include "GUI/Model/Descriptor/AxisProperty.h"
#include "GUI/View/Edit/DoubleSpinBox.h"
#include "GUI/View/Tool/WidgetUtils.h"
#include <QFormLayout>
#include <QGroupBox>
#include <QSpinBox>

AxisPropertyEditor::AxisPropertyEditor(QWidget* parent, const QString& groupTitle,
                                       AxisProperty* axisProperty)
    : QGroupBox(groupTitle, parent)
    , m_axisProperty(axisProperty)
{
    auto* formLayout = new QFormLayout(this);

    m_nbinsSpinBox = GUI::Util::createSpinBox(formLayout, axisProperty->nbins());
    m_minSpinBox = GUI::Util::createSpinBox(formLayout, axisProperty->min());
    m_maxSpinBox = GUI::Util::createSpinBox(formLayout, axisProperty->max());

    connect(m_nbinsSpinBox, qOverload<int>(&QSpinBox::valueChanged), [=](int v) {
        if (axisProperty->nbins() != static_cast<uint>(v)) {
            axisProperty->setNbins(v);
            emit dataChanged();
        }
    });

    connect(m_minSpinBox, qOverload<double>(&DoubleSpinBox::baseValueChanged), [=](double v) {
        if (m_axisProperty->min() != v) {
            m_axisProperty->setMin(v);
            emit dataChanged();
            if (m_axisProperty->max() < v) {
                m_axisProperty->setMax(v);
                m_maxSpinBox->updateValue();
            }
        }
    });

    connect(m_maxSpinBox, qOverload<double>(&DoubleSpinBox::baseValueChanged), [=](double v) {
        if (m_axisProperty->max() != v) {
            m_axisProperty->setMax(v);
            emit dataChanged();
            if (m_axisProperty->min() > v) {
                m_axisProperty->setMin(v);
                m_minSpinBox->updateValue();
            }
        }
    });
}

void AxisPropertyEditor::updateData()
{
    QSignalBlocker b(m_nbinsSpinBox);
    m_nbinsSpinBox->setValue(m_axisProperty->nbins());
    m_minSpinBox->updateValue();
    m_maxSpinBox->updateValue();
}
