//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/EditDistributionDialog.h
//! @brief     Defines class EditDistributionDialog
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_INSTRUMENT_EDITDISTRIBUTIONDIALOG_H
#define BORNAGAIN_GUI_VIEW_INSTRUMENT_EDITDISTRIBUTIONDIALOG_H

#include "GUI/View/Tool/ID.h"
#include <QDialog>
#include <optional>

class DistributionPlot;
class DistributionSelector;
class BeamDistributionItem;
struct MeanConfig;

//! The dialog which shows an editor to change parameters of DistributionItem
class EditDistributionDialog : public QDialog {
    Q_OBJECT

public:
    EditDistributionDialog(BeamDistributionItem* item, const QString& title,
                           const std::optional<MeanConfig>& mean_config,
                           GUI::ID::Distributions distributions, QWidget* parent = nullptr,
                           Qt::WindowFlags f = Qt::WindowFlags());

signals:
    void distributionChanged();

private slots:
    void updatePlot();

private:
    DistributionPlot* m_plot;
    DistributionSelector* m_selector;
    BeamDistributionItem* m_item;
};

#endif // BORNAGAIN_GUI_VIEW_INSTRUMENT_EDITDISTRIBUTIONDIALOG_H
