//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/FootprintCorrectionEditor.cpp
//! @brief     Implements class FootprintCorrectionEditor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/View/Instrument/FootprintCorrectionEditor.h"
#include "GUI/Model/Device/FootprintItems.h"
#include "GUI/Model/Device/InstrumentItems.h"
#include "GUI/View/Edit/DoubleSpinBox.h"
#include "GUI/View/Tool/WidgetUtils.h"
#include <QFormLayout>
#include <QGroupBox>

FootprintCorrectionEditor::FootprintCorrectionEditor(QWidget* parent, SpecularBeamItem* item)
    : QWidget(parent)
    , m_item(item)
{
    ASSERT(item);
    auto* layout = new QVBoxLayout(this);

    auto* gbox = new QGroupBox("Footprint correction", this);
    layout->addWidget(gbox);
    m_formLayout = new QFormLayout(gbox);
    auto* typeCombo = GUI::Util::createSelectionCombo(this, item->footprintSelection(), [=](int) {
        createFootprintWidgets();
        emit dataChanged();
    });
    m_formLayout->addRow("Type:", typeCombo);

    createFootprintWidgets();
}

void FootprintCorrectionEditor::createFootprintWidgets()
{
    while (m_formLayout->rowCount() > 1)
        m_formLayout->removeRow(1);

    auto* footprintItem = m_item->footprintSelection().currentItem();
    if (auto* square = dynamic_cast<FootprintSquareItem*>(footprintItem)) {
        auto* spinbox = new DoubleSpinBox(this, square->squareFootprintValue());
        spinbox->setSingleStep(0.01);
        m_formLayout->addRow("Width ratio:", spinbox);
        connect(spinbox, qOverload<double>(&DoubleSpinBox::baseValueChanged), [=](double newValue) {
            square->setSquareFootprintValue(newValue);
            emit dataChanged();
        });
    } else if (auto* gauss = dynamic_cast<FootprintGaussianItem*>(footprintItem)) {
        auto* spinbox = new DoubleSpinBox(this, gauss->gaussianFootprintValue());
        spinbox->setSingleStep(0.01);
        m_formLayout->addRow("Width ratio:", spinbox);
        connect(spinbox, qOverload<double>(&DoubleSpinBox::baseValueChanged), [=](double newValue) {
            gauss->setGaussianFootprintValue(newValue);
            emit dataChanged();
        });
    }
}
