//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Coherence/SumDWBA.h
//! @brief     Defines class SumDWBA.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_COHERENCE_SUMDWBA_H
#define BORNAGAIN_RESAMPLE_COHERENCE_SUMDWBA_H

#include "Base/Vector/EigenCore.h"
#include <heinz/Complex.h>
#include <memory>
#include <optional>

class DiffuseElement; // used by all children
class IFlux;          // used by all children
class IReParticle;
class WavevectorInfo; // used by all children

//! Computes coherent sum of the four DWBA terms.
//! Wraps an IReParticle, and provides functions evaluate or evaluatePol.
//! Used from CoherentFFSum.

class SumDWBA {
public:
    SumDWBA(const IReParticle& ff, size_t i_layer);
    SumDWBA(const IReParticle& ff);

    virtual ~SumDWBA();

    const IReParticle& ff() const { return *m_ff; }
    size_t iLayer() const;

    //! Returns the coherent sum of the four DWBA terms for scalar scattering.
    complex_t coherentFF(const DiffuseElement& ele) const;

    //! Returns the coherent sum of the four DWBA terms for polarized scattering.
    Eigen::Matrix2cd coherentPolFF(const DiffuseElement& ele) const;

private:
    const std::unique_ptr<const IReParticle> m_ff;
    const std::optional<size_t> m_i_layer;

    friend class TestPolarizedDWBATerm;
};

#endif // BORNAGAIN_RESAMPLE_COHERENCE_SUMDWBA_H
#endif // USER_API
