//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Resample/Processed/ReLayout.h
//! @brief     Defines class reLayout.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifdef SWIG
#error no need to expose this header to Swig
#endif

#ifndef USER_API
#ifndef BORNAGAIN_RESAMPLE_PROCESSED_RELAYOUT_H
#define BORNAGAIN_RESAMPLE_PROCESSED_RELAYOUT_H

#include <map>
#include <memory>
#include <vector>

class CoherentFFSum;
class IInterference;
class Admixtures;

//! Data structure that contains preprocessed data for a single layout.
//!
//! If particles in the layout crossed the limits of the layer slices,
//! these particles will be sliced themselves.

class reLayout {
public:
    reLayout(bool polarized, double surface_density,
             std::vector<std::unique_ptr<const CoherentFFSum>>&& formfactors,
             const IInterference* iff, std::map<size_t, Admixtures>&& slice2admixtures);
    reLayout(reLayout&& other);

    ~reLayout();

    double surfaceDensity() const { return m_surface_density; }
    const std::vector<std::unique_ptr<const CoherentFFSum>>& formfactorList() const
    {
        return m_formfactors;
    }
    const IInterference* interferenceFunction() const { return m_iff.get(); }
    const std::map<size_t, Admixtures>& regionMap() const { return m_slice2admixtures; }

private:
    const bool m_polarized;
    const double m_surface_density;
    std::vector<std::unique_ptr<const CoherentFFSum>> m_formfactors;
    std::unique_ptr<const IInterference> m_iff;
    std::map<size_t, Admixtures> m_slice2admixtures;
};

#endif // BORNAGAIN_RESAMPLE_PROCESSED_RELAYOUT_H
#endif // USER_API
