//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FormFactorCylinder.h
//! @brief     Defines class FormFactorCylinder.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORCYLINDER_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORCYLINDER_H

#include "Sample/Particle/IBornFF.h"

//! A circular cylinder.
//! @ingroup hardParticle

class FormFactorCylinder : public IBornFF {
public:
    FormFactorCylinder(double radius, double height);
#ifndef USER_API
    FormFactorCylinder(std::vector<double> P);

    FormFactorCylinder* clone() const override
    {
        return new FormFactorCylinder(m_radius, m_height);
    }
    std::string className() const final { return "FormFactorCylinder"; }
    // const auto tooltip = "circular cylinder";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Radius", "nm", "radius of base", 0, +INF, 0},
                {"Height", "nm", "height", 0, +INF, 0}};
    }

    double height() const { return m_height; }
    double radius() const { return m_radius; }

    double radialExtension() const override { return m_radius; }

    complex_t formfactor_at_bottom(C3 q) const override;

private:
    const double& m_radius;
    const double& m_height;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORCYLINDER_H
