//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FormFactorHemiEllipsoid.h
//! @brief     Defines class FormFactorHemiEllipsoid.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORHEMIELLIPSOID_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORHEMIELLIPSOID_H

#include "Sample/Particle/IBornFF.h"

//! An hemi ellipsoid,
//!   obtained by truncating a full ellipsoid in the middle plane spanned by two principal axes.
//! @ingroup hardParticle

class FormFactorHemiEllipsoid : public IBornFF {
public:
    FormFactorHemiEllipsoid(double radius_x, double radius_y, double height);
#ifndef USER_API
    FormFactorHemiEllipsoid(std::vector<double> P);
    ~FormFactorHemiEllipsoid() override = default;

    FormFactorHemiEllipsoid* clone() const override
    {
        return new FormFactorHemiEllipsoid(m_radius_x, m_radius_y, m_height);
    }
    std::string className() const final { return "FormFactorHemiEllipsoid"; }
    // const auto tooltip = "actually a spheroid, truncated at central xy plane";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"RadiusX", "nm", "radius in x direction", 0, +INF, 0},
                {"RadiusY", "nm", "radius in y direction", 0, +INF, 0},
                {"Height", "nm", "height = radius in z direction", 0, +INF, 0}};
    }

    double height() const { return m_height; }
    double radiusX() const { return m_radius_x; }
    double radiusY() const { return m_radius_y; }

    double radialExtension() const override;

    complex_t formfactor_at_bottom(C3 q) const override;

private:
    const double& m_radius_x;
    const double& m_radius_y;
    const double& m_height;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORHEMIELLIPSOID_H
