//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FormFactorLongBoxGauss.h
//! @brief     Defines class FormFactorLongBoxGauss.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORLONGBOXGAUSS_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORLONGBOXGAUSS_H

#include "Sample/Particle/IBornFF.h"

//! The form factor for a long rectangular box.
//! @ingroup legacyGrating

class FormFactorLongBoxGauss : public IBornFF {
public:
    FormFactorLongBoxGauss(double length, double width, double height);
#ifndef USER_API
    FormFactorLongBoxGauss(std::vector<double> P);

    FormFactorLongBoxGauss* clone() const override
    {
        return new FormFactorLongBoxGauss(m_length, m_width, m_height);
    }
    std::string className() const final { return "FormFactorLongBoxGauss"; }
    // const auto tooltip = "class_tooltip";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"Length", "nm", "para_tooltip", 0, +INF, 0},
                {"Width", "nm", "para_tooltip", 0, +INF, 0},
                {"Height", "nm", "para_tooltip", 0, +INF, 0}};
    }

    double length() const { return m_length; }
    double height() const { return m_height; }
    double width() const { return m_width; }
    double radialExtension() const override { return m_length / 2.0; }

    complex_t formfactor_at_bottom(C3 q) const override;

private:
    const double& m_length;
    const double& m_width;
    const double& m_height;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORLONGBOXGAUSS_H
