//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FormFactorPrism6.h
//! @brief     Defines class FormFactorPrism6.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORPRISM6_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORPRISM6_H

#include "Sample/HardParticle/IFormFactorPrism.h"

//! A prism based on a regular hexagonal.
//! @ingroup hardParticle

class FormFactorPrism6 : public IFormFactorPrism {
public:
    FormFactorPrism6(double base_edge, double height);
#ifndef USER_API
    FormFactorPrism6(std::vector<double> P);

    FormFactorPrism6* clone() const override { return new FormFactorPrism6(m_base_edge, m_height); }
    std::string className() const final { return "FormFactorPrism6"; }
    // const auto tooltip = "prism with regular hexagonal base";
    std::vector<ParaMeta> parDefs() const final
    {
        return {{"BaseEdge", "nm", "edge length of hexagonal base", 0, +INF, 0},
                {"Height", "nm", "height", 0, +INF, 0}};
    }

    double baseEdge() const { return m_base_edge; }
    double height() const override { return m_height; }

private:
    const double& m_base_edge;
    const double& m_height;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORPRISM6_H
