//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      Sample/HardParticle/FormFactorPyramid3.h
//! @brief     Defines class FormFactorPyramid3
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORPYRAMID3_H
#define BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORPYRAMID3_H

#include "Sample/HardParticle/IFormFactorPolyhedron.h"

//! A frustum with equilateral trigonal base.
//! @ingroup hardParticle

class FormFactorPyramid3 : public IFormFactorPolyhedron {
public:
    FormFactorPyramid3(double base_edge, double height, double alpha);
#ifndef USER_API
    FormFactorPyramid3(std::vector<double> P);

    FormFactorPyramid3* clone() const override
    {
        return new FormFactorPyramid3(m_base_edge, m_height, m_alpha);
    }
    std::string className() const final { return "FormFactorPyramid3"; }
    // const auto tooltip = "actually, not a tetrahedron, but a trigonal frustum";
    std::vector<ParaMeta> parDefs() const final
    {
        return {
            {"BaseEdge", "nm", "edge of base triangle", 0, +INF, 0},
            {"Height", "nm", "height of frustum", 0, +INF, 0},
            {"Alpha", "rad", "angle between base and a side face", 0., M_PI_2 + 0.0000000001, 0}};
    }

    double baseEdge() const { return m_base_edge; }
    double height() const { return m_height; }
    double alpha() const { return m_alpha; }

private:
    static const ff::PolyhedralTopology topology;
    const double& m_base_edge;
    const double& m_height;
    const double& m_alpha;
#endif // USER_API
};

#endif // BORNAGAIN_SAMPLE_HARDPARTICLE_FORMFACTORPYRAMID3_H
