#include "Base/Vector/RotMatrix.h"
#include "Tests/GTestWrapper/google_test.h"

class KVectorTest : public ::testing::Test {
};

TEST_F(KVectorTest, BasicTransformation)
{
    const double epsilon = 1e-12;
    R3 a, v;

    // rotation via transformation
    a = R3(std::sqrt(3.) / 2., 2., 0.5);
    RotMatrix m2 = RotMatrix::createRotateY(M_PI / 6.);
    v = m2.transformed(a);
    EXPECT_NEAR(v.x(), 1.0, epsilon);
    EXPECT_DOUBLE_EQ(v.y(), 2.0);
    EXPECT_NEAR(v.z(), 0.0, epsilon);

    a = R3(0.5, std::sqrt(3.) / 2., 2.);
    RotMatrix m3 = RotMatrix::createRotateZ(M_PI / 6.);
    v = m3.transformed(a);
    EXPECT_NEAR(v.x(), 0.0, epsilon);
    EXPECT_NEAR(v.y(), 1.0, epsilon);
    EXPECT_DOUBLE_EQ(v.z(), 2.0);
    RotMatrix m4 = m3.getInverse();
    v = m4.transformed(v);
    EXPECT_NEAR(v.x(), a.x(), epsilon);
    EXPECT_NEAR(v.y(), a.y(), epsilon);
    EXPECT_NEAR(v.z(), a.z(), epsilon);
}
