#include "GUI/Model/BaseItem/GroupItem.h"
#include "GUI/Model/Descriptor/DistributionItems.h"
#include "GUI/Model/Model/SessionModel.h"
#include "GUI/Model/Sample/FormFactorItems.h"
#include "GUI/Support/Type/VariantUtil.h"
#include "GUI/Util/ComboProperty.h"
#include "Tests/GTestWrapper/google_test.h"
#include "Tests/Unit/GUI/Utils.h"

class TestGroupItem : public ::testing::Test {
};

TEST_F(TestGroupItem, groupInfo)
{
    GroupInfo info;
    info.add("BBB", "b_label");
    info.add("AAA", "a_label");
    info.add("CCC", "c_label");
    info.setDefaultType("AAA");

    // sorted group (default behavior)
    EXPECT_EQ(info.defaultType(), "AAA");
    EXPECT_EQ(info.itemTypes(), QStringList() << "AAA"
                                              << "BBB"
                                              << "CCC");
    EXPECT_EQ(info.itemLabels(), QStringList() << "a_label"
                                               << "b_label"
                                               << "c_label");

    // unsorted group
    info = GroupInfo(false);
    info.add("BBB2", "b_label2");
    info.add("AAA2", "a_label2");
    info.add("CCC2", "c_label2");
    info.setDefaultType("AAA2");
    EXPECT_EQ(info.defaultType(), "AAA2");
    EXPECT_EQ(info.itemTypes(), QStringList() << "BBB2"
                                              << "AAA2"
                                              << "CCC2");
    EXPECT_EQ(info.itemLabels(), QStringList() << "b_label2"
                                               << "a_label2"
                                               << "c_label2");

    // attempt to set non-existing default type
    EXPECT_THROW(info.setDefaultType("XXX"), std::runtime_error);

    // attempt to add same info twice
    EXPECT_THROW(info.add("CCC2", "c_label2"), std::runtime_error);
}
