
// File: index.xml

// File: classAdmixtures.xml
%feature("docstring") Admixtures "

The list of material admixtures to a slice.

Needed for calculating the average of a material, which is needed in the Fresnel calculation.

C++ includes: Admixtures.h
";

%feature("docstring")  Admixtures::Admixtures "Admixtures::Admixtures()=default
";

%feature("docstring")  Admixtures::Admixtures "Admixtures::Admixtures(const std::vector< OneAdmixture > &_super)
";


// File: classBaseMaterialImpl.xml
%feature("docstring") BaseMaterialImpl "

Interface for material implementation classes. Inherited by  MagneticMaterialImpl, which has further children.

C++ includes: BaseMaterialImpl.h
";

%feature("docstring")  BaseMaterialImpl::BaseMaterialImpl "BaseMaterialImpl::BaseMaterialImpl(std::string name)

Constructs basic material with name. 
";

%feature("docstring")  BaseMaterialImpl::~BaseMaterialImpl "virtual BaseMaterialImpl::~BaseMaterialImpl()=default
";

%feature("docstring")  BaseMaterialImpl::clone "virtual BaseMaterialImpl* BaseMaterialImpl::clone() const =0

Returns pointer to a copy of material. 
";

%feature("docstring")  BaseMaterialImpl::inverted "virtual BaseMaterialImpl* BaseMaterialImpl::inverted() const =0

Constructs a material with inverted magnetization. 
";

%feature("docstring")  BaseMaterialImpl::refractiveIndex "virtual complex_t BaseMaterialImpl::refractiveIndex(double wavelength) const =0

Returns refractive index. 
";

%feature("docstring")  BaseMaterialImpl::refractiveIndex2 "virtual complex_t BaseMaterialImpl::refractiveIndex2(double wavelength) const =0

Returns squared refractive index. 
";

%feature("docstring")  BaseMaterialImpl::isScalarMaterial "virtual bool BaseMaterialImpl::isScalarMaterial() const =0

Indicates whether the interaction with the material is scalar. This means that different polarization states will be diffracted equally 
";

%feature("docstring")  BaseMaterialImpl::isMagneticMaterial "virtual bool BaseMaterialImpl::isMagneticMaterial() const =0
";

%feature("docstring")  BaseMaterialImpl::magnetization "virtual R3 BaseMaterialImpl::magnetization() const =0

Returns the magnetization (in A/m) 
";

%feature("docstring")  BaseMaterialImpl::materialData "virtual complex_t BaseMaterialImpl::materialData() const =0

Returns underlying material data. 
";

%feature("docstring")  BaseMaterialImpl::typeID "virtual MATERIAL_TYPES BaseMaterialImpl::typeID() const =0

Returns type of material implementation. 
";

%feature("docstring")  BaseMaterialImpl::scalarSubtrSLD "virtual complex_t BaseMaterialImpl::scalarSubtrSLD(double lambda0) const =0

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld), sld being the scattering length density. 
";

%feature("docstring")  BaseMaterialImpl::polarizedSubtrSLD "virtual Eigen::Matrix2cd BaseMaterialImpl::polarizedSubtrSLD(const WavevectorInfo &wavevectors) const =0

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld) matrix with magnetization corrections. 
";

%feature("docstring")  BaseMaterialImpl::rotatedMaterial "virtual BaseMaterialImpl* BaseMaterialImpl::rotatedMaterial(const RotMatrix &transform) const =0
";

%feature("docstring")  BaseMaterialImpl::print "virtual void BaseMaterialImpl::print(std::ostream &ostr) const =0

Prints object data. 
";

%feature("docstring")  BaseMaterialImpl::matName "const std::string& BaseMaterialImpl::matName() const

Returns name of the material. 
";


// File: classBasicLattice2D.xml
%feature("docstring") BasicLattice2D "

A two-dimensional Bravais lattice with no special symmetry.

C++ includes: Lattice2D.h
";

%feature("docstring")  BasicLattice2D::BasicLattice2D "BasicLattice2D::BasicLattice2D(double length1, double length2, double angle, double xi)
";

%feature("docstring")  BasicLattice2D::clone "BasicLattice2D * BasicLattice2D::clone() const override
";

%feature("docstring")  BasicLattice2D::className "std::string BasicLattice2D::className() const final
";

%feature("docstring")  BasicLattice2D::parDefs "std::vector<ParaMeta> BasicLattice2D::parDefs() const final
";

%feature("docstring")  BasicLattice2D::length1 "double BasicLattice2D::length1() const override
";

%feature("docstring")  BasicLattice2D::length2 "double BasicLattice2D::length2() const override
";

%feature("docstring")  BasicLattice2D::latticeAngle "double BasicLattice2D::latticeAngle() const override
";

%feature("docstring")  BasicLattice2D::unitCellArea "double BasicLattice2D::unitCellArea() const override
";


// File: classBox.xml
%feature("docstring") Box "";

%feature("docstring")  Box::Box "Box::Box(double length, double width, double height)
";

%feature("docstring")  Box::~Box "Box::~Box() override
";


// File: classCrystal.xml
%feature("docstring") Crystal "

A crystal structure, defined by a Bravais lattice, a basis, and a position variance.

Computations are delegated to class ReMesocrystal.

Used in  MesoCrystal, where it is given an outer shape.

C++ includes: Crystal.h
";

%feature("docstring")  Crystal::Crystal "Crystal::Crystal(const IParticle &basis, const Lattice3D &lattice, double position_variance=0)
";

%feature("docstring")  Crystal::~Crystal "Crystal::~Crystal() override
";

%feature("docstring")  Crystal::clone "Crystal * Crystal::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Crystal::className "std::string Crystal::className() const final
";

%feature("docstring")  Crystal::nodeChildren "std::vector< const INode * > Crystal::nodeChildren() const override
";

%feature("docstring")  Crystal::parDefs "std::vector<ParaMeta> Crystal::parDefs() const final
";

%feature("docstring")  Crystal::basis "const IParticle* Crystal::basis() const
";

%feature("docstring")  Crystal::lattice "const Lattice3D* Crystal::lattice() const
";

%feature("docstring")  Crystal::position_variance "double Crystal::position_variance() const
";

%feature("docstring")  Crystal::transformed "Crystal * Crystal::transformed(const IRotation *rotation, const R3 &translation) const
";


// File: classDistribution1DCauchySampler.xml
%feature("docstring") Distribution1DCauchySampler "";

%feature("docstring")  Distribution1DCauchySampler::Distribution1DCauchySampler "Distribution1DCauchySampler::Distribution1DCauchySampler(double lambda)
";

%feature("docstring")  Distribution1DCauchySampler::randomSample "double Distribution1DCauchySampler::randomSample() const override
";


// File: classDistribution1DCosineSampler.xml
%feature("docstring") Distribution1DCosineSampler "";

%feature("docstring")  Distribution1DCosineSampler::Distribution1DCosineSampler "Distribution1DCosineSampler::Distribution1DCosineSampler(double omega)
";

%feature("docstring")  Distribution1DCosineSampler::randomSample "double Distribution1DCosineSampler::randomSample() const override
";


// File: classDistribution1DGateSampler.xml
%feature("docstring") Distribution1DGateSampler "";

%feature("docstring")  Distribution1DGateSampler::Distribution1DGateSampler "Distribution1DGateSampler::Distribution1DGateSampler(double a, double b)
";

%feature("docstring")  Distribution1DGateSampler::randomSample "double Distribution1DGateSampler::randomSample() const override
";


// File: classDistribution1DGaussSampler.xml
%feature("docstring") Distribution1DGaussSampler "";

%feature("docstring")  Distribution1DGaussSampler::Distribution1DGaussSampler "Distribution1DGaussSampler::Distribution1DGaussSampler(double mean, double stddev)
";

%feature("docstring")  Distribution1DGaussSampler::randomSample "double Distribution1DGaussSampler::randomSample() const override
";


// File: classDistribution1DTriangleSampler.xml
%feature("docstring") Distribution1DTriangleSampler "";

%feature("docstring")  Distribution1DTriangleSampler::Distribution1DTriangleSampler "Distribution1DTriangleSampler::Distribution1DTriangleSampler(double omega)
";

%feature("docstring")  Distribution1DTriangleSampler::randomSample "double Distribution1DTriangleSampler::randomSample() const override
";


// File: classDistribution2DCauchySampler.xml
%feature("docstring") Distribution2DCauchySampler "";

%feature("docstring")  Distribution2DCauchySampler::Distribution2DCauchySampler "Distribution2DCauchySampler::Distribution2DCauchySampler(double omega_x, double omega_y)
";

%feature("docstring")  Distribution2DCauchySampler::randomSample "std::pair< double, double > Distribution2DCauchySampler::randomSample() const override
";


// File: classDistribution2DConeSampler.xml
%feature("docstring") Distribution2DConeSampler "";

%feature("docstring")  Distribution2DConeSampler::Distribution2DConeSampler "Distribution2DConeSampler::Distribution2DConeSampler(double omega_x, double omega_y)
";

%feature("docstring")  Distribution2DConeSampler::randomSample "std::pair< double, double > Distribution2DConeSampler::randomSample() const override
";


// File: classDistribution2DGateSampler.xml
%feature("docstring") Distribution2DGateSampler "";

%feature("docstring")  Distribution2DGateSampler::Distribution2DGateSampler "Distribution2DGateSampler::Distribution2DGateSampler(double omega_x, double omega_y)
";

%feature("docstring")  Distribution2DGateSampler::randomSample "std::pair< double, double > Distribution2DGateSampler::randomSample() const override
";


// File: classDistribution2DGaussSampler.xml
%feature("docstring") Distribution2DGaussSampler "";

%feature("docstring")  Distribution2DGaussSampler::Distribution2DGaussSampler "Distribution2DGaussSampler::Distribution2DGaussSampler(double omega_x, double omega_y)
";

%feature("docstring")  Distribution2DGaussSampler::randomSample "std::pair< double, double > Distribution2DGaussSampler::randomSample() const override
";


// File: classDoubleEllipse.xml
%feature("docstring") DoubleEllipse "";

%feature("docstring")  DoubleEllipse::DoubleEllipse "DoubleEllipse::DoubleEllipse(double r0_x, double r0_y, double z, double rz_x, double rz_y)
";

%feature("docstring")  DoubleEllipse::~DoubleEllipse "DoubleEllipse::~DoubleEllipse() override
";


// File: classFormFactorBarGauss.xml
%feature("docstring") FormFactorBarGauss "

The form factor of an elongated bar, with Gaussian profile in elongation direction.

C++ includes: FormFactorBar.h
";

%feature("docstring")  FormFactorBarGauss::FormFactorBarGauss "FormFactorBarGauss::FormFactorBarGauss(double length, double width, double height)
";

%feature("docstring")  FormFactorBarGauss::FormFactorBarGauss "FormFactorBarGauss::FormFactorBarGauss(std::vector< double > P)
";

%feature("docstring")  FormFactorBarGauss::clone "FormFactorBarGauss * FormFactorBarGauss::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorBarGauss::className "std::string FormFactorBarGauss::className() const final
";

%feature("docstring")  FormFactorBarGauss::parDefs "std::vector<ParaMeta> FormFactorBarGauss::parDefs() const final
";


// File: classFormFactorBarLorentz.xml
%feature("docstring") FormFactorBarLorentz "

The form factor of an elongated, with Lorentz form factor in elongation direction.

C++ includes: FormFactorBar.h
";

%feature("docstring")  FormFactorBarLorentz::FormFactorBarLorentz "FormFactorBarLorentz::FormFactorBarLorentz(double length, double width, double height)
";

%feature("docstring")  FormFactorBarLorentz::FormFactorBarLorentz "FormFactorBarLorentz::FormFactorBarLorentz(std::vector< double > P)
";

%feature("docstring")  FormFactorBarLorentz::clone "FormFactorBarLorentz * FormFactorBarLorentz::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorBarLorentz::className "std::string FormFactorBarLorentz::className() const final
";

%feature("docstring")  FormFactorBarLorentz::parDefs "std::vector<ParaMeta> FormFactorBarLorentz::parDefs() const final
";


// File: classFormFactorBipyramid4.xml
%feature("docstring") FormFactorBipyramid4 "

A truncated bifrustum with quadratic base.

C++ includes: FormFactorBipyramid4.h
";

%feature("docstring")  FormFactorBipyramid4::FormFactorBipyramid4 "FormFactorBipyramid4::FormFactorBipyramid4(double length, double height, double height_ratio, double alpha)
";

%feature("docstring")  FormFactorBipyramid4::FormFactorBipyramid4 "FormFactorBipyramid4::FormFactorBipyramid4(std::vector< double > P)
";

%feature("docstring")  FormFactorBipyramid4::clone "FormFactorBipyramid4* FormFactorBipyramid4::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorBipyramid4::className "std::string FormFactorBipyramid4::className() const final
";

%feature("docstring")  FormFactorBipyramid4::parDefs "std::vector<ParaMeta> FormFactorBipyramid4::parDefs() const final
";

%feature("docstring")  FormFactorBipyramid4::length "double FormFactorBipyramid4::length() const
";

%feature("docstring")  FormFactorBipyramid4::height "double FormFactorBipyramid4::height() const
";

%feature("docstring")  FormFactorBipyramid4::heightRatio "double FormFactorBipyramid4::heightRatio() const
";

%feature("docstring")  FormFactorBipyramid4::alpha "double FormFactorBipyramid4::alpha() const
";


// File: classFormFactorBox.xml
%feature("docstring") FormFactorBox "

A rectangular prism (parallelepiped).

C++ includes: FormFactorBox.h
";

%feature("docstring")  FormFactorBox::FormFactorBox "FormFactorBox::FormFactorBox(double length, double width, double height)
";

%feature("docstring")  FormFactorBox::FormFactorBox "FormFactorBox::FormFactorBox(std::vector< double > P)
";

%feature("docstring")  FormFactorBox::clone "FormFactorBox* FormFactorBox::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorBox::className "std::string FormFactorBox::className() const final
";

%feature("docstring")  FormFactorBox::parDefs "std::vector<ParaMeta> FormFactorBox::parDefs() const final
";

%feature("docstring")  FormFactorBox::length "double FormFactorBox::length() const
";

%feature("docstring")  FormFactorBox::width "double FormFactorBox::width() const
";

%feature("docstring")  FormFactorBox::height "double FormFactorBox::height() const override
";

%feature("docstring")  FormFactorBox::volume "double FormFactorBox::volume() const override
";

%feature("docstring")  FormFactorBox::radialExtension "double FormFactorBox::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorBox::formfactor_at_bottom "complex_t FormFactorBox::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorCantellatedCube.xml
%feature("docstring") FormFactorCantellatedCube "

A cube, with truncation of all edges and corners, as in Croset (2017) Fig 7

C++ includes: FormFactorCantellatedCube.h
";

%feature("docstring")  FormFactorCantellatedCube::FormFactorCantellatedCube "FormFactorCantellatedCube::FormFactorCantellatedCube(double length, double removed_length)
";

%feature("docstring")  FormFactorCantellatedCube::FormFactorCantellatedCube "FormFactorCantellatedCube::FormFactorCantellatedCube(std::vector< double > P)
";

%feature("docstring")  FormFactorCantellatedCube::clone "FormFactorCantellatedCube* FormFactorCantellatedCube::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCantellatedCube::className "std::string FormFactorCantellatedCube::className() const final
";

%feature("docstring")  FormFactorCantellatedCube::parDefs "std::vector<ParaMeta> FormFactorCantellatedCube::parDefs() const final
";

%feature("docstring")  FormFactorCantellatedCube::length "double FormFactorCantellatedCube::length() const
";

%feature("docstring")  FormFactorCantellatedCube::removedLength "double FormFactorCantellatedCube::removedLength() const
";


// File: classFormFactorComponents.xml
%feature("docstring") FormFactorComponents "

Predefined form factors for functional tests.

C++ includes: FormFactorComponents.h
";

%feature("docstring")  FormFactorComponents::FormFactorComponents "FormFactorComponents::FormFactorComponents()
";


// File: classFormFactorCone.xml
%feature("docstring") FormFactorCone "

A conical frustum (cone truncated parallel to the base) with circular base.

C++ includes: FormFactorCone.h
";

%feature("docstring")  FormFactorCone::FormFactorCone "FormFactorCone::FormFactorCone(double radius, double height, double alpha)
";

%feature("docstring")  FormFactorCone::FormFactorCone "FormFactorCone::FormFactorCone(std::vector< double > P)
";

%feature("docstring")  FormFactorCone::clone "FormFactorCone* FormFactorCone::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCone::className "std::string FormFactorCone::className() const final
";

%feature("docstring")  FormFactorCone::parDefs "std::vector<ParaMeta> FormFactorCone::parDefs() const final
";

%feature("docstring")  FormFactorCone::height "double FormFactorCone::height() const
";

%feature("docstring")  FormFactorCone::alpha "double FormFactorCone::alpha() const
";

%feature("docstring")  FormFactorCone::radius "double FormFactorCone::radius() const
";

%feature("docstring")  FormFactorCone::radialExtension "double FormFactorCone::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorCone::formfactor_at_bottom "complex_t FormFactorCone::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorCosineRippleBox.xml
%feature("docstring") FormFactorCosineRippleBox "

The form factor for a cosine ripple, with box profile in elongation direction.

C++ includes: FormFactorCosineRipple.h
";

%feature("docstring")  FormFactorCosineRippleBox::FormFactorCosineRippleBox "FormFactorCosineRippleBox::FormFactorCosineRippleBox(double length, double width, double height)
";

%feature("docstring")  FormFactorCosineRippleBox::FormFactorCosineRippleBox "FormFactorCosineRippleBox::FormFactorCosineRippleBox(std::vector< double > P)
";

%feature("docstring")  FormFactorCosineRippleBox::clone "FormFactorCosineRippleBox * FormFactorCosineRippleBox::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCosineRippleBox::className "std::string FormFactorCosineRippleBox::className() const final
";

%feature("docstring")  FormFactorCosineRippleBox::parDefs "std::vector<ParaMeta> FormFactorCosineRippleBox::parDefs() const final
";


// File: classFormFactorCosineRippleGauss.xml
%feature("docstring") FormFactorCosineRippleGauss "

The form factor for a cosine ripple, with Gaussian profile in elongation direction.

C++ includes: FormFactorCosineRipple.h
";

%feature("docstring")  FormFactorCosineRippleGauss::FormFactorCosineRippleGauss "FormFactorCosineRippleGauss::FormFactorCosineRippleGauss(double length, double width, double height)
";

%feature("docstring")  FormFactorCosineRippleGauss::FormFactorCosineRippleGauss "FormFactorCosineRippleGauss::FormFactorCosineRippleGauss(std::vector< double > P)
";

%feature("docstring")  FormFactorCosineRippleGauss::clone "FormFactorCosineRippleGauss * FormFactorCosineRippleGauss::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCosineRippleGauss::className "std::string FormFactorCosineRippleGauss::className() const final
";

%feature("docstring")  FormFactorCosineRippleGauss::parDefs "std::vector<ParaMeta> FormFactorCosineRippleGauss::parDefs() const final
";


// File: classFormFactorCosineRippleLorentz.xml
%feature("docstring") FormFactorCosineRippleLorentz "

The form factor for a cosine ripple, with Lorentz form factor in elongation direction.

C++ includes: FormFactorCosineRipple.h
";

%feature("docstring")  FormFactorCosineRippleLorentz::FormFactorCosineRippleLorentz "FormFactorCosineRippleLorentz::FormFactorCosineRippleLorentz(double length, double width, double height)
";

%feature("docstring")  FormFactorCosineRippleLorentz::FormFactorCosineRippleLorentz "FormFactorCosineRippleLorentz::FormFactorCosineRippleLorentz(std::vector< double > P)
";

%feature("docstring")  FormFactorCosineRippleLorentz::clone "FormFactorCosineRippleLorentz * FormFactorCosineRippleLorentz::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCosineRippleLorentz::className "std::string FormFactorCosineRippleLorentz::className() const final
";

%feature("docstring")  FormFactorCosineRippleLorentz::parDefs "std::vector<ParaMeta> FormFactorCosineRippleLorentz::parDefs() const final
";


// File: classFormFactorCylinder.xml
%feature("docstring") FormFactorCylinder "

A circular cylinder.

C++ includes: FormFactorCylinder.h
";

%feature("docstring")  FormFactorCylinder::FormFactorCylinder "FormFactorCylinder::FormFactorCylinder(double radius, double height)
";

%feature("docstring")  FormFactorCylinder::FormFactorCylinder "FormFactorCylinder::FormFactorCylinder(std::vector< double > P)
";

%feature("docstring")  FormFactorCylinder::clone "FormFactorCylinder* FormFactorCylinder::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorCylinder::className "std::string FormFactorCylinder::className() const final
";

%feature("docstring")  FormFactorCylinder::parDefs "std::vector<ParaMeta> FormFactorCylinder::parDefs() const final
";

%feature("docstring")  FormFactorCylinder::height "double FormFactorCylinder::height() const
";

%feature("docstring")  FormFactorCylinder::radius "double FormFactorCylinder::radius() const
";

%feature("docstring")  FormFactorCylinder::radialExtension "double FormFactorCylinder::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorCylinder::formfactor_at_bottom "complex_t FormFactorCylinder::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorDodecahedron.xml
%feature("docstring") FormFactorDodecahedron "

A regular dodecahedron.

C++ includes: FormFactorDodecahedron.h
";

%feature("docstring")  FormFactorDodecahedron::FormFactorDodecahedron "FormFactorDodecahedron::FormFactorDodecahedron(double edge)
";

%feature("docstring")  FormFactorDodecahedron::FormFactorDodecahedron "FormFactorDodecahedron::FormFactorDodecahedron(std::vector< double > P)
";

%feature("docstring")  FormFactorDodecahedron::clone "FormFactorDodecahedron* FormFactorDodecahedron::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorDodecahedron::className "std::string FormFactorDodecahedron::className() const final
";

%feature("docstring")  FormFactorDodecahedron::parDefs "std::vector<ParaMeta> FormFactorDodecahedron::parDefs() const final
";

%feature("docstring")  FormFactorDodecahedron::edge "double FormFactorDodecahedron::edge() const
";


// File: classFormFactorEllipsoidalCylinder.xml
%feature("docstring") FormFactorEllipsoidalCylinder "

A cylinder with elliptical base.

C++ includes: FormFactorEllipsoidalCylinder.h
";

%feature("docstring")  FormFactorEllipsoidalCylinder::FormFactorEllipsoidalCylinder "FormFactorEllipsoidalCylinder::FormFactorEllipsoidalCylinder(double radius_x, double radius_y, double height)
";

%feature("docstring")  FormFactorEllipsoidalCylinder::FormFactorEllipsoidalCylinder "FormFactorEllipsoidalCylinder::FormFactorEllipsoidalCylinder(std::vector< double > P)
";

%feature("docstring")  FormFactorEllipsoidalCylinder::clone "FormFactorEllipsoidalCylinder* FormFactorEllipsoidalCylinder::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorEllipsoidalCylinder::className "std::string FormFactorEllipsoidalCylinder::className() const final
";

%feature("docstring")  FormFactorEllipsoidalCylinder::parDefs "std::vector<ParaMeta> FormFactorEllipsoidalCylinder::parDefs() const final
";

%feature("docstring")  FormFactorEllipsoidalCylinder::radiusX "double FormFactorEllipsoidalCylinder::radiusX() const
";

%feature("docstring")  FormFactorEllipsoidalCylinder::radiusY "double FormFactorEllipsoidalCylinder::radiusY() const
";

%feature("docstring")  FormFactorEllipsoidalCylinder::height "double FormFactorEllipsoidalCylinder::height() const
";

%feature("docstring")  FormFactorEllipsoidalCylinder::radialExtension "double FormFactorEllipsoidalCylinder::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorEllipsoidalCylinder::formfactor_at_bottom "complex_t FormFactorEllipsoidalCylinder::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorFullSphere.xml
%feature("docstring") FormFactorFullSphere "

A full sphere.

C++ includes: FormFactorFullSphere.h
";

%feature("docstring")  FormFactorFullSphere::FormFactorFullSphere "FormFactorFullSphere::FormFactorFullSphere(double radius, bool position_at_center=false)
";

%feature("docstring")  FormFactorFullSphere::FormFactorFullSphere "FormFactorFullSphere::FormFactorFullSphere(std::vector< double > P, bool position_at_center=false)
";

%feature("docstring")  FormFactorFullSphere::clone "FormFactorFullSphere* FormFactorFullSphere::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorFullSphere::className "std::string FormFactorFullSphere::className() const final
";

%feature("docstring")  FormFactorFullSphere::parDefs "std::vector<ParaMeta> FormFactorFullSphere::parDefs() const final
";

%feature("docstring")  FormFactorFullSphere::radius "double FormFactorFullSphere::radius() const
";

%feature("docstring")  FormFactorFullSphere::radialExtension "double FormFactorFullSphere::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorFullSphere::bottomZ "double FormFactorFullSphere::bottomZ(const IRotation *rotation) const override
";

%feature("docstring")  FormFactorFullSphere::topZ "double FormFactorFullSphere::topZ(const IRotation *rotation) const override
";

%feature("docstring")  FormFactorFullSphere::formfactor_at_bottom "complex_t FormFactorFullSphere::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorFullSpheroid.xml
%feature("docstring") FormFactorFullSpheroid "

A full spheroid (an ellipsoid with two equal axes, hence with circular cross section)

C++ includes: FormFactorFullSpheroid.h
";

%feature("docstring")  FormFactorFullSpheroid::FormFactorFullSpheroid "FormFactorFullSpheroid::FormFactorFullSpheroid(double radius, double height)
";

%feature("docstring")  FormFactorFullSpheroid::FormFactorFullSpheroid "FormFactorFullSpheroid::FormFactorFullSpheroid(std::vector< double > P)
";

%feature("docstring")  FormFactorFullSpheroid::clone "FormFactorFullSpheroid* FormFactorFullSpheroid::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorFullSpheroid::className "std::string FormFactorFullSpheroid::className() const final
";

%feature("docstring")  FormFactorFullSpheroid::parDefs "std::vector<ParaMeta> FormFactorFullSpheroid::parDefs() const final
";

%feature("docstring")  FormFactorFullSpheroid::height "double FormFactorFullSpheroid::height() const
";

%feature("docstring")  FormFactorFullSpheroid::radius "double FormFactorFullSpheroid::radius() const
";

%feature("docstring")  FormFactorFullSpheroid::radialExtension "double FormFactorFullSpheroid::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorFullSpheroid::formfactor_at_bottom "complex_t FormFactorFullSpheroid::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorGaussSphere.xml
%feature("docstring") FormFactorGaussSphere "

The form factor of a Gaussian sphere.

C++ includes: FormFactorGauss.h
";

%feature("docstring")  FormFactorGaussSphere::FormFactorGaussSphere "FormFactorGaussSphere::FormFactorGaussSphere(std::vector< double > P)
";

%feature("docstring")  FormFactorGaussSphere::FormFactorGaussSphere "FormFactorGaussSphere::FormFactorGaussSphere(double mean_radius)
";

%feature("docstring")  FormFactorGaussSphere::clone "FormFactorGaussSphere* FormFactorGaussSphere::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorGaussSphere::className "std::string FormFactorGaussSphere::className() const final
";

%feature("docstring")  FormFactorGaussSphere::parDefs "std::vector<ParaMeta> FormFactorGaussSphere::parDefs() const final
";

%feature("docstring")  FormFactorGaussSphere::meanRadius "double FormFactorGaussSphere::meanRadius() const
";

%feature("docstring")  FormFactorGaussSphere::radialExtension "double FormFactorGaussSphere::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorGaussSphere::formfactor_at_bottom "complex_t FormFactorGaussSphere::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorHemiEllipsoid.xml
%feature("docstring") FormFactorHemiEllipsoid "

An hemi ellipsoid, obtained by truncating a full ellipsoid in the middle plane spanned by two principal axes.

C++ includes: FormFactorHemiEllipsoid.h
";

%feature("docstring")  FormFactorHemiEllipsoid::FormFactorHemiEllipsoid "FormFactorHemiEllipsoid::FormFactorHemiEllipsoid(double radius_x, double radius_y, double height)
";

%feature("docstring")  FormFactorHemiEllipsoid::FormFactorHemiEllipsoid "FormFactorHemiEllipsoid::FormFactorHemiEllipsoid(std::vector< double > P)
";

%feature("docstring")  FormFactorHemiEllipsoid::~FormFactorHemiEllipsoid "FormFactorHemiEllipsoid::~FormFactorHemiEllipsoid() override=default
";

%feature("docstring")  FormFactorHemiEllipsoid::clone "FormFactorHemiEllipsoid* FormFactorHemiEllipsoid::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorHemiEllipsoid::className "std::string FormFactorHemiEllipsoid::className() const final
";

%feature("docstring")  FormFactorHemiEllipsoid::parDefs "std::vector<ParaMeta> FormFactorHemiEllipsoid::parDefs() const final
";

%feature("docstring")  FormFactorHemiEllipsoid::height "double FormFactorHemiEllipsoid::height() const
";

%feature("docstring")  FormFactorHemiEllipsoid::radiusX "double FormFactorHemiEllipsoid::radiusX() const
";

%feature("docstring")  FormFactorHemiEllipsoid::radiusY "double FormFactorHemiEllipsoid::radiusY() const
";

%feature("docstring")  FormFactorHemiEllipsoid::radialExtension "double FormFactorHemiEllipsoid::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorHemiEllipsoid::formfactor_at_bottom "complex_t FormFactorHemiEllipsoid::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorHollowSphere.xml
%feature("docstring") FormFactorHollowSphere "

Integrated full sphere form factor over a uniform distribution of radii.

C++ includes: FormFactorHollowSphere.h
";

%feature("docstring")  FormFactorHollowSphere::FormFactorHollowSphere "FormFactorHollowSphere::FormFactorHollowSphere(double mean, double full_width)
";

%feature("docstring")  FormFactorHollowSphere::FormFactorHollowSphere "FormFactorHollowSphere::FormFactorHollowSphere(std::vector< double > P)
";

%feature("docstring")  FormFactorHollowSphere::clone "FormFactorHollowSphere* FormFactorHollowSphere::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorHollowSphere::className "std::string FormFactorHollowSphere::className() const final
";

%feature("docstring")  FormFactorHollowSphere::parDefs "std::vector<ParaMeta> FormFactorHollowSphere::parDefs() const final
";

%feature("docstring")  FormFactorHollowSphere::radialExtension "double FormFactorHollowSphere::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorHollowSphere::formfactor_at_bottom "complex_t FormFactorHollowSphere::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorIcosahedron.xml
%feature("docstring") FormFactorIcosahedron "

A regular icosahedron.

C++ includes: FormFactorIcosahedron.h
";

%feature("docstring")  FormFactorIcosahedron::FormFactorIcosahedron "FormFactorIcosahedron::FormFactorIcosahedron(double edge)
";

%feature("docstring")  FormFactorIcosahedron::FormFactorIcosahedron "FormFactorIcosahedron::FormFactorIcosahedron(std::vector< double > P)
";

%feature("docstring")  FormFactorIcosahedron::clone "FormFactorIcosahedron* FormFactorIcosahedron::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorIcosahedron::className "std::string FormFactorIcosahedron::className() const final
";

%feature("docstring")  FormFactorIcosahedron::parDefs "std::vector<ParaMeta> FormFactorIcosahedron::parDefs() const final
";

%feature("docstring")  FormFactorIcosahedron::edge "double FormFactorIcosahedron::edge() const
";


// File: classFormFactorLongBoxGauss.xml
%feature("docstring") FormFactorLongBoxGauss "

The form factor for a long rectangular box.

C++ includes: FormFactorLongBoxGauss.h
";

%feature("docstring")  FormFactorLongBoxGauss::FormFactorLongBoxGauss "FormFactorLongBoxGauss::FormFactorLongBoxGauss(double length, double width, double height)
";

%feature("docstring")  FormFactorLongBoxGauss::FormFactorLongBoxGauss "FormFactorLongBoxGauss::FormFactorLongBoxGauss(std::vector< double > P)
";

%feature("docstring")  FormFactorLongBoxGauss::clone "FormFactorLongBoxGauss* FormFactorLongBoxGauss::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorLongBoxGauss::className "std::string FormFactorLongBoxGauss::className() const final
";

%feature("docstring")  FormFactorLongBoxGauss::parDefs "std::vector<ParaMeta> FormFactorLongBoxGauss::parDefs() const final
";

%feature("docstring")  FormFactorLongBoxGauss::length "double FormFactorLongBoxGauss::length() const
";

%feature("docstring")  FormFactorLongBoxGauss::height "double FormFactorLongBoxGauss::height() const
";

%feature("docstring")  FormFactorLongBoxGauss::width "double FormFactorLongBoxGauss::width() const
";

%feature("docstring")  FormFactorLongBoxGauss::radialExtension "double FormFactorLongBoxGauss::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorLongBoxGauss::formfactor_at_bottom "complex_t FormFactorLongBoxGauss::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorLongBoxLorentz.xml
%feature("docstring") FormFactorLongBoxLorentz "

The form factor for a long rectangular box.

C++ includes: FormFactorLongBoxLorentz.h
";

%feature("docstring")  FormFactorLongBoxLorentz::FormFactorLongBoxLorentz "FormFactorLongBoxLorentz::FormFactorLongBoxLorentz(double length, double width, double height)
";

%feature("docstring")  FormFactorLongBoxLorentz::FormFactorLongBoxLorentz "FormFactorLongBoxLorentz::FormFactorLongBoxLorentz(std::vector< double > P)
";

%feature("docstring")  FormFactorLongBoxLorentz::clone "FormFactorLongBoxLorentz* FormFactorLongBoxLorentz::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorLongBoxLorentz::className "std::string FormFactorLongBoxLorentz::className() const final
";

%feature("docstring")  FormFactorLongBoxLorentz::parDefs "std::vector<ParaMeta> FormFactorLongBoxLorentz::parDefs() const final
";

%feature("docstring")  FormFactorLongBoxLorentz::length "double FormFactorLongBoxLorentz::length() const
";

%feature("docstring")  FormFactorLongBoxLorentz::height "double FormFactorLongBoxLorentz::height() const
";

%feature("docstring")  FormFactorLongBoxLorentz::width "double FormFactorLongBoxLorentz::width() const
";

%feature("docstring")  FormFactorLongBoxLorentz::radialExtension "double FormFactorLongBoxLorentz::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorLongBoxLorentz::formfactor_at_bottom "complex_t FormFactorLongBoxLorentz::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorPlatonicOctahedron.xml
%feature("docstring") FormFactorPlatonicOctahedron "

A truncated bifrustum with quadratic base.

C++ includes: FormFactorPlatonicOctahedron.h
";

%feature("docstring")  FormFactorPlatonicOctahedron::FormFactorPlatonicOctahedron "FormFactorPlatonicOctahedron::FormFactorPlatonicOctahedron(double edge)
";

%feature("docstring")  FormFactorPlatonicOctahedron::FormFactorPlatonicOctahedron "FormFactorPlatonicOctahedron::FormFactorPlatonicOctahedron(std::vector< double > P)
";

%feature("docstring")  FormFactorPlatonicOctahedron::clone "FormFactorPlatonicOctahedron* FormFactorPlatonicOctahedron::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPlatonicOctahedron::className "std::string FormFactorPlatonicOctahedron::className() const final
";

%feature("docstring")  FormFactorPlatonicOctahedron::parDefs "std::vector<ParaMeta> FormFactorPlatonicOctahedron::parDefs() const final
";

%feature("docstring")  FormFactorPlatonicOctahedron::edge "double FormFactorPlatonicOctahedron::edge() const
";

%feature("docstring")  FormFactorPlatonicOctahedron::height "double FormFactorPlatonicOctahedron::height() const
";


// File: classFormFactorPlatonicTetrahedron.xml
%feature("docstring") FormFactorPlatonicTetrahedron "

A frustum with equilateral trigonal base.

C++ includes: FormFactorPlatonicTetrahedron.h
";

%feature("docstring")  FormFactorPlatonicTetrahedron::FormFactorPlatonicTetrahedron "FormFactorPlatonicTetrahedron::FormFactorPlatonicTetrahedron(double edge)
";

%feature("docstring")  FormFactorPlatonicTetrahedron::FormFactorPlatonicTetrahedron "FormFactorPlatonicTetrahedron::FormFactorPlatonicTetrahedron(std::vector< double > P)
";

%feature("docstring")  FormFactorPlatonicTetrahedron::clone "FormFactorPlatonicTetrahedron* FormFactorPlatonicTetrahedron::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPlatonicTetrahedron::className "std::string FormFactorPlatonicTetrahedron::className() const final
";

%feature("docstring")  FormFactorPlatonicTetrahedron::parDefs "std::vector<ParaMeta> FormFactorPlatonicTetrahedron::parDefs() const final
";

%feature("docstring")  FormFactorPlatonicTetrahedron::edge "double FormFactorPlatonicTetrahedron::edge() const
";

%feature("docstring")  FormFactorPlatonicTetrahedron::height "double FormFactorPlatonicTetrahedron::height() const
";


// File: classFormFactorPrism3.xml
%feature("docstring") FormFactorPrism3 "

A prism based on an equilateral triangle.

C++ includes: FormFactorPrism3.h
";

%feature("docstring")  FormFactorPrism3::FormFactorPrism3 "FormFactorPrism3::FormFactorPrism3(double base_edge, double height)
";

%feature("docstring")  FormFactorPrism3::FormFactorPrism3 "FormFactorPrism3::FormFactorPrism3(std::vector< double > P)
";

%feature("docstring")  FormFactorPrism3::clone "FormFactorPrism3* FormFactorPrism3::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPrism3::className "std::string FormFactorPrism3::className() const final
";

%feature("docstring")  FormFactorPrism3::parDefs "std::vector<ParaMeta> FormFactorPrism3::parDefs() const final
";

%feature("docstring")  FormFactorPrism3::baseEdge "double FormFactorPrism3::baseEdge() const
";

%feature("docstring")  FormFactorPrism3::height "double FormFactorPrism3::height() const override
";


// File: classFormFactorPrism6.xml
%feature("docstring") FormFactorPrism6 "

A prism based on a regular hexagonal.

C++ includes: FormFactorPrism6.h
";

%feature("docstring")  FormFactorPrism6::FormFactorPrism6 "FormFactorPrism6::FormFactorPrism6(double base_edge, double height)
";

%feature("docstring")  FormFactorPrism6::FormFactorPrism6 "FormFactorPrism6::FormFactorPrism6(std::vector< double > P)
";

%feature("docstring")  FormFactorPrism6::clone "FormFactorPrism6* FormFactorPrism6::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPrism6::className "std::string FormFactorPrism6::className() const final
";

%feature("docstring")  FormFactorPrism6::parDefs "std::vector<ParaMeta> FormFactorPrism6::parDefs() const final
";

%feature("docstring")  FormFactorPrism6::baseEdge "double FormFactorPrism6::baseEdge() const
";

%feature("docstring")  FormFactorPrism6::height "double FormFactorPrism6::height() const override
";


// File: classFormFactorPyramid2.xml
%feature("docstring") FormFactorPyramid2 "

A frustum (truncated pyramid) with rectangular base.

C++ includes: FormFactorPyramid2.h
";

%feature("docstring")  FormFactorPyramid2::FormFactorPyramid2 "FormFactorPyramid2::FormFactorPyramid2(double length, double width, double height, double alpha)
";

%feature("docstring")  FormFactorPyramid2::FormFactorPyramid2 "FormFactorPyramid2::FormFactorPyramid2(std::vector< double > P)
";

%feature("docstring")  FormFactorPyramid2::clone "FormFactorPyramid2* FormFactorPyramid2::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPyramid2::className "std::string FormFactorPyramid2::className() const final
";

%feature("docstring")  FormFactorPyramid2::parDefs "std::vector<ParaMeta> FormFactorPyramid2::parDefs() const final
";

%feature("docstring")  FormFactorPyramid2::length "double FormFactorPyramid2::length() const
";

%feature("docstring")  FormFactorPyramid2::width "double FormFactorPyramid2::width() const
";

%feature("docstring")  FormFactorPyramid2::height "double FormFactorPyramid2::height() const
";

%feature("docstring")  FormFactorPyramid2::alpha "double FormFactorPyramid2::alpha() const
";


// File: classFormFactorPyramid3.xml
%feature("docstring") FormFactorPyramid3 "

A frustum with equilateral trigonal base.

C++ includes: FormFactorPyramid3.h
";

%feature("docstring")  FormFactorPyramid3::FormFactorPyramid3 "FormFactorPyramid3::FormFactorPyramid3(double base_edge, double height, double alpha)
";

%feature("docstring")  FormFactorPyramid3::FormFactorPyramid3 "FormFactorPyramid3::FormFactorPyramid3(std::vector< double > P)
";

%feature("docstring")  FormFactorPyramid3::clone "FormFactorPyramid3* FormFactorPyramid3::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPyramid3::className "std::string FormFactorPyramid3::className() const final
";

%feature("docstring")  FormFactorPyramid3::parDefs "std::vector<ParaMeta> FormFactorPyramid3::parDefs() const final
";

%feature("docstring")  FormFactorPyramid3::baseEdge "double FormFactorPyramid3::baseEdge() const
";

%feature("docstring")  FormFactorPyramid3::height "double FormFactorPyramid3::height() const
";

%feature("docstring")  FormFactorPyramid3::alpha "double FormFactorPyramid3::alpha() const
";


// File: classFormFactorPyramid4.xml
%feature("docstring") FormFactorPyramid4 "

A frustum with a quadratic base.

C++ includes: FormFactorPyramid4.h
";

%feature("docstring")  FormFactorPyramid4::FormFactorPyramid4 "FormFactorPyramid4::FormFactorPyramid4(double base_edge, double height, double alpha)
";

%feature("docstring")  FormFactorPyramid4::FormFactorPyramid4 "FormFactorPyramid4::FormFactorPyramid4(std::vector< double > P)
";

%feature("docstring")  FormFactorPyramid4::clone "FormFactorPyramid4* FormFactorPyramid4::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPyramid4::className "std::string FormFactorPyramid4::className() const final
";

%feature("docstring")  FormFactorPyramid4::parDefs "std::vector<ParaMeta> FormFactorPyramid4::parDefs() const final
";

%feature("docstring")  FormFactorPyramid4::height "double FormFactorPyramid4::height() const
";

%feature("docstring")  FormFactorPyramid4::baseEdge "double FormFactorPyramid4::baseEdge() const
";

%feature("docstring")  FormFactorPyramid4::alpha "double FormFactorPyramid4::alpha() const
";


// File: classFormFactorPyramid6.xml
%feature("docstring") FormFactorPyramid6 "

A frustum (truncated pyramid) with regular hexagonal base.

C++ includes: FormFactorPyramid6.h
";

%feature("docstring")  FormFactorPyramid6::FormFactorPyramid6 "FormFactorPyramid6::FormFactorPyramid6(double base_edge, double height, double alpha)
";

%feature("docstring")  FormFactorPyramid6::FormFactorPyramid6 "FormFactorPyramid6::FormFactorPyramid6(std::vector< double > P)
";

%feature("docstring")  FormFactorPyramid6::clone "FormFactorPyramid6* FormFactorPyramid6::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorPyramid6::className "std::string FormFactorPyramid6::className() const final
";

%feature("docstring")  FormFactorPyramid6::parDefs "std::vector<ParaMeta> FormFactorPyramid6::parDefs() const final
";

%feature("docstring")  FormFactorPyramid6::baseEdge "double FormFactorPyramid6::baseEdge() const
";

%feature("docstring")  FormFactorPyramid6::height "double FormFactorPyramid6::height() const
";

%feature("docstring")  FormFactorPyramid6::alpha "double FormFactorPyramid6::alpha() const
";


// File: classFormFactorSawtoothRippleBox.xml
%feature("docstring") FormFactorSawtoothRippleBox "

The form factor for a cosine ripple, with box profile in elongation direction.

C++ includes: FormFactorSawtoothRipple.h
";

%feature("docstring")  FormFactorSawtoothRippleBox::FormFactorSawtoothRippleBox "FormFactorSawtoothRippleBox::FormFactorSawtoothRippleBox(double length, double width, double height, double asymmetry)
";

%feature("docstring")  FormFactorSawtoothRippleBox::FormFactorSawtoothRippleBox "FormFactorSawtoothRippleBox::FormFactorSawtoothRippleBox(std::vector< double > P)
";

%feature("docstring")  FormFactorSawtoothRippleBox::clone "FormFactorSawtoothRippleBox * FormFactorSawtoothRippleBox::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSawtoothRippleBox::className "std::string FormFactorSawtoothRippleBox::className() const final
";

%feature("docstring")  FormFactorSawtoothRippleBox::parDefs "std::vector<ParaMeta> FormFactorSawtoothRippleBox::parDefs() const final
";


// File: classFormFactorSawtoothRippleGauss.xml
%feature("docstring") FormFactorSawtoothRippleGauss "

The form factor for a cosine ripple, with Gaussian profile in elongation direction.

C++ includes: FormFactorSawtoothRipple.h
";

%feature("docstring")  FormFactorSawtoothRippleGauss::FormFactorSawtoothRippleGauss "FormFactorSawtoothRippleGauss::FormFactorSawtoothRippleGauss(double length, double width, double height, double asymmetry)
";

%feature("docstring")  FormFactorSawtoothRippleGauss::FormFactorSawtoothRippleGauss "FormFactorSawtoothRippleGauss::FormFactorSawtoothRippleGauss(std::vector< double > P)
";

%feature("docstring")  FormFactorSawtoothRippleGauss::clone "FormFactorSawtoothRippleGauss * FormFactorSawtoothRippleGauss::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSawtoothRippleGauss::className "std::string FormFactorSawtoothRippleGauss::className() const final
";

%feature("docstring")  FormFactorSawtoothRippleGauss::parDefs "std::vector<ParaMeta> FormFactorSawtoothRippleGauss::parDefs() const final
";


// File: classFormFactorSawtoothRippleLorentz.xml
%feature("docstring") FormFactorSawtoothRippleLorentz "

The form factor for a cosine ripple, with Lorentz form factor in elongation direction.

C++ includes: FormFactorSawtoothRipple.h
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::FormFactorSawtoothRippleLorentz "FormFactorSawtoothRippleLorentz::FormFactorSawtoothRippleLorentz(double length, double width, double height, double asymmetry)
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::FormFactorSawtoothRippleLorentz "FormFactorSawtoothRippleLorentz::FormFactorSawtoothRippleLorentz(std::vector< double > P)
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::clone "FormFactorSawtoothRippleLorentz * FormFactorSawtoothRippleLorentz::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::className "std::string FormFactorSawtoothRippleLorentz::className() const final
";

%feature("docstring")  FormFactorSawtoothRippleLorentz::parDefs "std::vector<ParaMeta> FormFactorSawtoothRippleLorentz::parDefs() const final
";


// File: classFormFactorSphereGaussianRadius.xml
%feature("docstring") FormFactorSphereGaussianRadius "

A sphere with gaussian radius distribution.

C++ includes: FormFactorSphereGaussianRadius.h
";

%feature("docstring")  FormFactorSphereGaussianRadius::FormFactorSphereGaussianRadius "FormFactorSphereGaussianRadius::FormFactorSphereGaussianRadius(std::vector< double > P)
";

%feature("docstring")  FormFactorSphereGaussianRadius::FormFactorSphereGaussianRadius "FormFactorSphereGaussianRadius::FormFactorSphereGaussianRadius(double mean, double sigma)
";

%feature("docstring")  FormFactorSphereGaussianRadius::clone "FormFactorSphereGaussianRadius* FormFactorSphereGaussianRadius::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSphereGaussianRadius::className "std::string FormFactorSphereGaussianRadius::className() const final
";

%feature("docstring")  FormFactorSphereGaussianRadius::parDefs "std::vector<ParaMeta> FormFactorSphereGaussianRadius::parDefs() const final
";

%feature("docstring")  FormFactorSphereGaussianRadius::radialExtension "double FormFactorSphereGaussianRadius::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorSphereGaussianRadius::formfactor_at_bottom "complex_t FormFactorSphereGaussianRadius::formfactor_at_bottom(C3 q) const override
";


// File: classFormFactorSphereLogNormalRadius.xml
%feature("docstring") FormFactorSphereLogNormalRadius "

A sphere with log normal radius distribution.

C++ includes: FormFactorSphereLogNormalRadius.h
";

%feature("docstring")  FormFactorSphereLogNormalRadius::FormFactorSphereLogNormalRadius "FormFactorSphereLogNormalRadius::FormFactorSphereLogNormalRadius(std::vector< double > P, size_t n_samples=0)
";

%feature("docstring")  FormFactorSphereLogNormalRadius::FormFactorSphereLogNormalRadius "FormFactorSphereLogNormalRadius::FormFactorSphereLogNormalRadius(double mean, double scale_param, size_t n_samples)
";

%feature("docstring")  FormFactorSphereLogNormalRadius::clone "FormFactorSphereLogNormalRadius * FormFactorSphereLogNormalRadius::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorSphereLogNormalRadius::className "std::string FormFactorSphereLogNormalRadius::className() const final
";

%feature("docstring")  FormFactorSphereLogNormalRadius::parDefs "std::vector<ParaMeta> FormFactorSphereLogNormalRadius::parDefs() const final
";

%feature("docstring")  FormFactorSphereLogNormalRadius::radialExtension "double FormFactorSphereLogNormalRadius::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorSphereLogNormalRadius::formfactor_at_bottom "complex_t FormFactorSphereLogNormalRadius::formfactor_at_bottom(C3 q) const override
";

%feature("docstring")  FormFactorSphereLogNormalRadius::pythonConstructor "std::string FormFactorSphereLogNormalRadius::pythonConstructor() const override

Creates the Python constructor of this class (or derived classes) 
";


// File: classFormFactorTruncatedCube.xml
%feature("docstring") FormFactorTruncatedCube "

A cube, with tetrahedral truncation of all corners

C++ includes: FormFactorTruncatedCube.h
";

%feature("docstring")  FormFactorTruncatedCube::FormFactorTruncatedCube "FormFactorTruncatedCube::FormFactorTruncatedCube(double length, double removed_length)
";

%feature("docstring")  FormFactorTruncatedCube::FormFactorTruncatedCube "FormFactorTruncatedCube::FormFactorTruncatedCube(std::vector< double > P)
";

%feature("docstring")  FormFactorTruncatedCube::clone "FormFactorTruncatedCube* FormFactorTruncatedCube::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorTruncatedCube::className "std::string FormFactorTruncatedCube::className() const final
";

%feature("docstring")  FormFactorTruncatedCube::parDefs "std::vector<ParaMeta> FormFactorTruncatedCube::parDefs() const final
";

%feature("docstring")  FormFactorTruncatedCube::length "double FormFactorTruncatedCube::length() const
";

%feature("docstring")  FormFactorTruncatedCube::removedLength "double FormFactorTruncatedCube::removedLength() const
";


// File: classFormFactorTruncatedSphere.xml
%feature("docstring") FormFactorTruncatedSphere "

A truncated Sphere.

C++ includes: FormFactorTruncatedSphere.h
";

%feature("docstring")  FormFactorTruncatedSphere::FormFactorTruncatedSphere "FormFactorTruncatedSphere::FormFactorTruncatedSphere(double radius, double height, double dh)
";

%feature("docstring")  FormFactorTruncatedSphere::FormFactorTruncatedSphere "FormFactorTruncatedSphere::FormFactorTruncatedSphere(std::vector< double > P)
";

%feature("docstring")  FormFactorTruncatedSphere::clone "FormFactorTruncatedSphere* FormFactorTruncatedSphere::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorTruncatedSphere::className "std::string FormFactorTruncatedSphere::className() const final
";

%feature("docstring")  FormFactorTruncatedSphere::parDefs "std::vector<ParaMeta> FormFactorTruncatedSphere::parDefs() const final
";

%feature("docstring")  FormFactorTruncatedSphere::height "double FormFactorTruncatedSphere::height() const
";

%feature("docstring")  FormFactorTruncatedSphere::radius "double FormFactorTruncatedSphere::radius() const
";

%feature("docstring")  FormFactorTruncatedSphere::removedTop "double FormFactorTruncatedSphere::removedTop() const
";

%feature("docstring")  FormFactorTruncatedSphere::radialExtension "double FormFactorTruncatedSphere::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorTruncatedSphere::formfactor_at_bottom "complex_t FormFactorTruncatedSphere::formfactor_at_bottom(C3 q) const override

Complex form factor. 
";


// File: classFormFactorTruncatedSpheroid.xml
%feature("docstring") FormFactorTruncatedSpheroid "

A truncated spheroid. An ellipsoid with two equal axis, truncated by a plane perpendicular to the third axis.

C++ includes: FormFactorTruncatedSpheroid.h
";

%feature("docstring")  FormFactorTruncatedSpheroid::FormFactorTruncatedSpheroid "FormFactorTruncatedSpheroid::FormFactorTruncatedSpheroid(double radius, double height, double height_flattening, double dh)
";

%feature("docstring")  FormFactorTruncatedSpheroid::FormFactorTruncatedSpheroid "FormFactorTruncatedSpheroid::FormFactorTruncatedSpheroid(std::vector< double > P)
";

%feature("docstring")  FormFactorTruncatedSpheroid::clone "FormFactorTruncatedSpheroid* FormFactorTruncatedSpheroid::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  FormFactorTruncatedSpheroid::className "std::string FormFactorTruncatedSpheroid::className() const final
";

%feature("docstring")  FormFactorTruncatedSpheroid::parDefs "std::vector<ParaMeta> FormFactorTruncatedSpheroid::parDefs() const final
";

%feature("docstring")  FormFactorTruncatedSpheroid::radius "double FormFactorTruncatedSpheroid::radius() const
";

%feature("docstring")  FormFactorTruncatedSpheroid::height "double FormFactorTruncatedSpheroid::height() const
";

%feature("docstring")  FormFactorTruncatedSpheroid::heightFlattening "double FormFactorTruncatedSpheroid::heightFlattening() const
";

%feature("docstring")  FormFactorTruncatedSpheroid::removedTop "double FormFactorTruncatedSpheroid::removedTop() const
";

%feature("docstring")  FormFactorTruncatedSpheroid::radialExtension "double FormFactorTruncatedSpheroid::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  FormFactorTruncatedSpheroid::formfactor_at_bottom "complex_t FormFactorTruncatedSpheroid::formfactor_at_bottom(C3 q) const override
";


// File: classGaussFisherPeakShape.xml
%feature("docstring") GaussFisherPeakShape "

A peak shape that is Gaussian in the radial direction and uses the Mises-Fisher distribution in the angular direction.

C++ includes: IPeakShape.h
";

%feature("docstring")  GaussFisherPeakShape::GaussFisherPeakShape "GaussFisherPeakShape::GaussFisherPeakShape(double max_intensity, double radial_size, double kappa)
";

%feature("docstring")  GaussFisherPeakShape::~GaussFisherPeakShape "GaussFisherPeakShape::~GaussFisherPeakShape() override
";

%feature("docstring")  GaussFisherPeakShape::clone "GaussFisherPeakShape * GaussFisherPeakShape::clone() const override
";

%feature("docstring")  GaussFisherPeakShape::className "std::string GaussFisherPeakShape::className() const final
";

%feature("docstring")  GaussFisherPeakShape::parDefs "std::vector<ParaMeta> GaussFisherPeakShape::parDefs() const final
";

%feature("docstring")  GaussFisherPeakShape::peakDistribution "double GaussFisherPeakShape::peakDistribution(R3 q, R3 q_lattice_point) const override

Peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  GaussFisherPeakShape::angularDisorder "bool GaussFisherPeakShape::angularDisorder() const override

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classHexagonalLattice2D.xml
%feature("docstring") HexagonalLattice2D "

A two-dimensional Bravais lattice with hexagonal symmetry.

C++ includes: Lattice2D.h
";

%feature("docstring")  HexagonalLattice2D::HexagonalLattice2D "HexagonalLattice2D::HexagonalLattice2D(double length, double xi)
";

%feature("docstring")  HexagonalLattice2D::clone "HexagonalLattice2D * HexagonalLattice2D::clone() const override
";

%feature("docstring")  HexagonalLattice2D::className "std::string HexagonalLattice2D::className() const final
";

%feature("docstring")  HexagonalLattice2D::parDefs "std::vector<ParaMeta> HexagonalLattice2D::parDefs() const final
";

%feature("docstring")  HexagonalLattice2D::length1 "double HexagonalLattice2D::length1() const override
";

%feature("docstring")  HexagonalLattice2D::length2 "double HexagonalLattice2D::length2() const override
";

%feature("docstring")  HexagonalLattice2D::latticeAngle "double HexagonalLattice2D::latticeAngle() const override
";

%feature("docstring")  HexagonalLattice2D::unitCellArea "double HexagonalLattice2D::unitCellArea() const override
";


// File: classIBornFF.xml
%feature("docstring") IBornFF "

Abstract base class for Born form factors.

In contrast to the generic IReParticle, a Born form factor does not depend on the incoming and outgoing wave vectors ki and kf, except through their difference, the scattering vector q=ki-kf.

C++ includes: IBornFF.h
";

%feature("docstring")  IBornFF::IBornFF "IBornFF::IBornFF()
";

%feature("docstring")  IBornFF::IBornFF "IBornFF::IBornFF(const std::vector< double > &PValues)
";

%feature("docstring")  IBornFF::~IBornFF "IBornFF::~IBornFF() override
";

%feature("docstring")  IBornFF::clone "IBornFF* IBornFF::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IBornFF::theFF "complex_t IBornFF::theFF(const WavevectorInfo &wavevectors) const
";

%feature("docstring")  IBornFF::shapeName "std::string IBornFF::shapeName() const
";

%feature("docstring")  IBornFF::thePolFF "Eigen::Matrix2cd IBornFF::thePolFF(const WavevectorInfo &wavevectors) const
";

%feature("docstring")  IBornFF::bottomZ "double IBornFF::bottomZ(const IRotation *rotation) const
";

%feature("docstring")  IBornFF::topZ "double IBornFF::topZ(const IRotation *rotation) const
";

%feature("docstring")  IBornFF::volume "double IBornFF::volume() const
";

%feature("docstring")  IBornFF::radialExtension "virtual double IBornFF::radialExtension() const =0

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  IBornFF::formfactor_at_bottom "virtual complex_t IBornFF::formfactor_at_bottom(C3 q) const =0
";

%feature("docstring")  IBornFF::pythonConstructor "std::string IBornFF::pythonConstructor() const

Creates the Python constructor of this class (or derived classes) 
";

%feature("docstring")  IBornFF::canSliceAnalytically "bool IBornFF::canSliceAnalytically(const IRotation *rot) const

Default implementation only allows rotations along z-axis. 
";

%feature("docstring")  IBornFF::formfactor_pol "Eigen::Matrix2cd IBornFF::formfactor_pol(C3 q) const

Returns scattering amplitude for complex scattering wavevector q=k_i-k_f in case of matrix interactions. Default implementation calls formfactor_at_bottom(q) and multiplies with the unit matrix. 
";


// File: classICosineRipple.xml
%feature("docstring") ICosineRipple "

Base class for form factors with a cosine ripple profile in the yz plane.

C++ includes: IProfileRipple.h
";

%feature("docstring")  ICosineRipple::ICosineRipple "ICosineRipple::ICosineRipple(const std::vector< double > &PValues)
";


// File: classIdentityRotation.xml
%feature("docstring") IdentityRotation "

The identity rotation, which leaves everything in place.

C++ includes: Rotations.h
";

%feature("docstring")  IdentityRotation::IdentityRotation "IdentityRotation::IdentityRotation()
";

%feature("docstring")  IdentityRotation::clone "IdentityRotation* IdentityRotation::clone() const override
";

%feature("docstring")  IdentityRotation::className "std::string IdentityRotation::className() const final
";

%feature("docstring")  IdentityRotation::createInverse "IdentityRotation* IdentityRotation::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  IdentityRotation::rotMatrix "RotMatrix IdentityRotation::rotMatrix() const override

Returns transformation. 
";

%feature("docstring")  IdentityRotation::isIdentity "bool IdentityRotation::isIdentity() const override

Returns true if rotation matrix is identity matrix (no rotations) 
";


// File: classIDistribution1DSampler.xml
%feature("docstring") IDistribution1DSampler "";

%feature("docstring")  IDistribution1DSampler::IDistribution1DSampler "IDistribution1DSampler::IDistribution1DSampler()=default
";

%feature("docstring")  IDistribution1DSampler::~IDistribution1DSampler "IDistribution1DSampler::~IDistribution1DSampler()
";

%feature("docstring")  IDistribution1DSampler::randomSample "virtual double IDistribution1DSampler::randomSample() const =0
";


// File: classIDistribution2DSampler.xml
%feature("docstring") IDistribution2DSampler "";

%feature("docstring")  IDistribution2DSampler::IDistribution2DSampler "IDistribution2DSampler::IDistribution2DSampler()=default
";

%feature("docstring")  IDistribution2DSampler::~IDistribution2DSampler "IDistribution2DSampler::~IDistribution2DSampler()
";

%feature("docstring")  IDistribution2DSampler::randomSample "virtual std::pair<double, double> IDistribution2DSampler::randomSample() const =0
";


// File: classIFormFactorPolyhedron.xml
%feature("docstring") IFormFactorPolyhedron "

A polyhedron, for form factor computation.

C++ includes: IFormFactorPolyhedron.h
";

%feature("docstring")  IFormFactorPolyhedron::IFormFactorPolyhedron "IFormFactorPolyhedron::IFormFactorPolyhedron(const std::vector< double > &PValues)

The mathematics implemented here is described in full detail in a paper by Joachim Wuttke, entitled \"Form factor (Fourier shape transform) of polygon and polyhedron.\" 
";

%feature("docstring")  IFormFactorPolyhedron::~IFormFactorPolyhedron "IFormFactorPolyhedron::~IFormFactorPolyhedron() override
";

%feature("docstring")  IFormFactorPolyhedron::bottomZ "double IFormFactorPolyhedron::bottomZ(const IRotation *rotation) const override
";

%feature("docstring")  IFormFactorPolyhedron::topZ "double IFormFactorPolyhedron::topZ(const IRotation *rotation) const override
";

%feature("docstring")  IFormFactorPolyhedron::formfactor_at_bottom "complex_t IFormFactorPolyhedron::formfactor_at_bottom(C3 q) const override
";

%feature("docstring")  IFormFactorPolyhedron::volume "double IFormFactorPolyhedron::volume() const override
";

%feature("docstring")  IFormFactorPolyhedron::radialExtension "double IFormFactorPolyhedron::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  IFormFactorPolyhedron::assert_platonic "void IFormFactorPolyhedron::assert_platonic() const

Assertions for Platonic solid. 
";


// File: classIFormFactorPrism.xml
%feature("docstring") IFormFactorPrism "

A prism with a polygonal base, for form factor computation.

C++ includes: IFormFactorPrism.h
";

%feature("docstring")  IFormFactorPrism::IFormFactorPrism "IFormFactorPrism::IFormFactorPrism(const std::vector< double > &PValues)
";

%feature("docstring")  IFormFactorPrism::~IFormFactorPrism "IFormFactorPrism::~IFormFactorPrism() override
";

%feature("docstring")  IFormFactorPrism::bottomZ "double IFormFactorPrism::bottomZ(const IRotation *rotation) const override
";

%feature("docstring")  IFormFactorPrism::topZ "double IFormFactorPrism::topZ(const IRotation *rotation) const override
";

%feature("docstring")  IFormFactorPrism::formfactor_at_bottom "complex_t IFormFactorPrism::formfactor_at_bottom(C3 q) const override

Returns the form factor F(q) of this polyhedron, respecting the offset height/2. 
";

%feature("docstring")  IFormFactorPrism::volume "double IFormFactorPrism::volume() const override

Returns the volume of this prism. 
";

%feature("docstring")  IFormFactorPrism::radialExtension "double IFormFactorPrism::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  IFormFactorPrism::height "virtual double IFormFactorPrism::height() const =0
";


// File: classIInterference.xml
%feature("docstring") IInterference "

Abstract base class of interference functions.

C++ includes: IInterference.h
";

%feature("docstring")  IInterference::clone "IInterference* IInterference::clone() const override=0
";

%feature("docstring")  IInterference::structureFactor "double IInterference::structureFactor(R3 q, double outer_iff=1.0) const

The interference function for a given wavevector transfer. 
";

%feature("docstring")  IInterference::setPositionVariance "void IInterference::setPositionVariance(double var)

Sets the variance of the position for the calculation of the DW factor It is defined as the variance in each relevant dimension 
";

%feature("docstring")  IInterference::positionVariance "double IInterference::positionVariance() const

Returns the position variance. 
";

%feature("docstring")  IInterference::particleDensity "virtual double IInterference::particleDensity() const

If defined by this interference function's parameters, returns the particle density (per area). Otherwise, returns zero or a user-defined value 
";

%feature("docstring")  IInterference::supportsMultilayer "virtual bool IInterference::supportsMultilayer() const

Indicates if this interference function can be used with a multilayer (DWBA mode) 
";

%feature("docstring")  IInterference::DWfactor "double IInterference::DWfactor(R3 q) const

structureFactors the Debye-Waller factor for a given wavevector transfer 
";


// File: classInterference1DLattice.xml
%feature("docstring") Interference1DLattice "

Interference function of a 1D lattice.

C++ includes: Interference1DLattice.h
";

%feature("docstring")  Interference1DLattice::Interference1DLattice "Interference1DLattice::Interference1DLattice(double length, double xi)

Constructor of interference function of one-dimensional lattice.

Parameters:
-----------

length: 
lattice constant in nanometers

xi: 
rotation of lattice with respect to x-axis in radians 
";

%feature("docstring")  Interference1DLattice::~Interference1DLattice "Interference1DLattice::~Interference1DLattice() override
";

%feature("docstring")  Interference1DLattice::clone "Interference1DLattice * Interference1DLattice::clone() const override
";

%feature("docstring")  Interference1DLattice::className "std::string Interference1DLattice::className() const final
";

%feature("docstring")  Interference1DLattice::parDefs "std::vector<ParaMeta> Interference1DLattice::parDefs() const final
";

%feature("docstring")  Interference1DLattice::setDecayFunction "void Interference1DLattice::setDecayFunction(const IProfile1D &decay)

Sets one-dimensional decay function.

Parameters:
-----------

decay: 
one-dimensional decay function in reciprocal space 
";

%feature("docstring")  Interference1DLattice::length "double Interference1DLattice::length() const
";

%feature("docstring")  Interference1DLattice::xi "double Interference1DLattice::xi() const
";

%feature("docstring")  Interference1DLattice::nodeChildren "std::vector< const INode * > Interference1DLattice::nodeChildren() const override
";


// File: classInterference2DLattice.xml
%feature("docstring") Interference2DLattice "

Interference function of a 2D lattice.

C++ includes: Interference2DLattice.h
";

%feature("docstring")  Interference2DLattice::Interference2DLattice "Interference2DLattice::Interference2DLattice(const Lattice2D &lattice)
";

%feature("docstring")  Interference2DLattice::~Interference2DLattice "Interference2DLattice::~Interference2DLattice() override
";

%feature("docstring")  Interference2DLattice::clone "Interference2DLattice * Interference2DLattice::clone() const override
";

%feature("docstring")  Interference2DLattice::className "std::string Interference2DLattice::className() const final
";

%feature("docstring")  Interference2DLattice::setDecayFunction "void Interference2DLattice::setDecayFunction(const IProfile2D &decay)

Sets two-dimensional decay function.

Parameters:
-----------

decay: 
two-dimensional decay function in reciprocal space 
";

%feature("docstring")  Interference2DLattice::setIntegrationOverXi "void Interference2DLattice::setIntegrationOverXi(bool integrate_xi)
";

%feature("docstring")  Interference2DLattice::integrationOverXi "bool Interference2DLattice::integrationOverXi() const
";

%feature("docstring")  Interference2DLattice::lattice "const Lattice2D & Interference2DLattice::lattice() const
";

%feature("docstring")  Interference2DLattice::particleDensity "double Interference2DLattice::particleDensity() const override

Returns the particle density associated with this 2d lattice. 
";

%feature("docstring")  Interference2DLattice::nodeChildren "std::vector< const INode * > Interference2DLattice::nodeChildren() const override
";


// File: classInterference2DParaCrystal.xml
%feature("docstring") Interference2DParaCrystal "

Interference function of a 2D paracrystal.

C++ includes: Interference2DParaCrystal.h
";

%feature("docstring")  Interference2DParaCrystal::Interference2DParaCrystal "Interference2DParaCrystal::Interference2DParaCrystal(const Lattice2D &lattice, double damping_length, double domain_size_1, double domain_size_2)
";

%feature("docstring")  Interference2DParaCrystal::~Interference2DParaCrystal "Interference2DParaCrystal::~Interference2DParaCrystal() override
";

%feature("docstring")  Interference2DParaCrystal::clone "Interference2DParaCrystal * Interference2DParaCrystal::clone() const override
";

%feature("docstring")  Interference2DParaCrystal::className "std::string Interference2DParaCrystal::className() const final
";

%feature("docstring")  Interference2DParaCrystal::parDefs "std::vector<ParaMeta> Interference2DParaCrystal::parDefs() const final
";

%feature("docstring")  Interference2DParaCrystal::setDomainSizes "void Interference2DParaCrystal::setDomainSizes(double size_1, double size_2)

Sets the sizes of coherence domains.

Parameters:
-----------

size_1: 
coherence domain size along the first basis vector in nanometers

size_2: 
coherence domain size along the second basis vector in nanometers 
";

%feature("docstring")  Interference2DParaCrystal::setProbabilityDistributions "void Interference2DParaCrystal::setProbabilityDistributions(const IProfile2D &pdf_1, const IProfile2D &pdf_2)

Sets the probability distributions (Fourier transformed) for the two lattice directions.

Parameters:
-----------

pdf_1: 
probability distribution in first lattice direction

pdf_2: 
probability distribution in second lattice direction 
";

%feature("docstring")  Interference2DParaCrystal::setDampingLength "void Interference2DParaCrystal::setDampingLength(double damping_length)

Sets the damping length.

Parameters:
-----------

damping_length: 
the damping (coherence) length of the paracrystal in nanometers 
";

%feature("docstring")  Interference2DParaCrystal::domainSizes "std::vector< double > Interference2DParaCrystal::domainSizes() const
";

%feature("docstring")  Interference2DParaCrystal::setIntegrationOverXi "void Interference2DParaCrystal::setIntegrationOverXi(bool integrate_xi)

Enables/disables averaging over the lattice rotation angle.

Parameters:
-----------

integrate_xi: 
integration flag 
";

%feature("docstring")  Interference2DParaCrystal::integrationOverXi "bool Interference2DParaCrystal::integrationOverXi() const
";

%feature("docstring")  Interference2DParaCrystal::dampingLength "double Interference2DParaCrystal::dampingLength() const
";

%feature("docstring")  Interference2DParaCrystal::lattice "const Lattice2D & Interference2DParaCrystal::lattice() const
";

%feature("docstring")  Interference2DParaCrystal::particleDensity "double Interference2DParaCrystal::particleDensity() const override

If defined by this interference function's parameters, returns the particle density (per area). Otherwise, returns zero or a user-defined value 
";

%feature("docstring")  Interference2DParaCrystal::nodeChildren "std::vector< const INode * > Interference2DParaCrystal::nodeChildren() const override
";

%feature("docstring")  Interference2DParaCrystal::pdf1 "const IProfile2D* Interference2DParaCrystal::pdf1() const
";

%feature("docstring")  Interference2DParaCrystal::pdf2 "const IProfile2D* Interference2DParaCrystal::pdf2() const
";


// File: classInterference2DSuperLattice.xml
%feature("docstring") Interference2DSuperLattice "

Interference function of a 2D superlattice with a configurable interference function for each lattice site.

C++ includes: Interference2DSuperLattice.h
";

%feature("docstring")  Interference2DSuperLattice::Interference2DSuperLattice "Interference2DSuperLattice::Interference2DSuperLattice(const Lattice2D &lattice, unsigned size_1, unsigned size_2)
";

%feature("docstring")  Interference2DSuperLattice::Interference2DSuperLattice "Interference2DSuperLattice::Interference2DSuperLattice(double length_1, double length_2, double alpha, double xi, unsigned size_1, unsigned size_2)

Constructor of two-dimensional interference function.

Parameters:
-----------

length_1: 
length of first lattice vector in nanometers

length_2: 
length of second lattice vector in nanometers

alpha: 
angle between lattice vectors in radians

xi: 
rotation of lattice with respect to x-axis (beam direction) in radians

size_1: 
correlation length in direction 1

size_2: 
correlation length in direction 2 
";

%feature("docstring")  Interference2DSuperLattice::~Interference2DSuperLattice "Interference2DSuperLattice::~Interference2DSuperLattice() override
";

%feature("docstring")  Interference2DSuperLattice::clone "Interference2DSuperLattice * Interference2DSuperLattice::clone() const override
";

%feature("docstring")  Interference2DSuperLattice::className "std::string Interference2DSuperLattice::className() const final
";

%feature("docstring")  Interference2DSuperLattice::parDefs "std::vector<ParaMeta> Interference2DSuperLattice::parDefs() const final
";

%feature("docstring")  Interference2DSuperLattice::setSubstructureIFF "void Interference2DSuperLattice::setSubstructureIFF(const IInterference &sub_iff)
";

%feature("docstring")  Interference2DSuperLattice::substructureIFF "const IInterference & Interference2DSuperLattice::substructureIFF() const
";

%feature("docstring")  Interference2DSuperLattice::structureFactor "double Interference2DSuperLattice::structureFactor(R3 q, double outer_iff=1.0) const override

The interference function for a given wavevector transfer. 
";

%feature("docstring")  Interference2DSuperLattice::domainSize1 "unsigned Interference2DSuperLattice::domainSize1() const
";

%feature("docstring")  Interference2DSuperLattice::domainSize2 "unsigned Interference2DSuperLattice::domainSize2() const
";

%feature("docstring")  Interference2DSuperLattice::setIntegrationOverXi "void Interference2DSuperLattice::setIntegrationOverXi(bool integrate_xi)
";

%feature("docstring")  Interference2DSuperLattice::integrationOverXi "bool Interference2DSuperLattice::integrationOverXi() const
";

%feature("docstring")  Interference2DSuperLattice::lattice "const Lattice2D & Interference2DSuperLattice::lattice() const
";

%feature("docstring")  Interference2DSuperLattice::nodeChildren "std::vector< const INode * > Interference2DSuperLattice::nodeChildren() const override
";


// File: classInterference3DLattice.xml
%feature("docstring") Interference3DLattice "

Interference function of a 3D lattice.

C++ includes: Interference3DLattice.h
";

%feature("docstring")  Interference3DLattice::Interference3DLattice "Interference3DLattice::Interference3DLattice(const Lattice3D &lattice)
";

%feature("docstring")  Interference3DLattice::~Interference3DLattice "Interference3DLattice::~Interference3DLattice() override
";

%feature("docstring")  Interference3DLattice::clone "Interference3DLattice * Interference3DLattice::clone() const override
";

%feature("docstring")  Interference3DLattice::className "std::string Interference3DLattice::className() const final
";

%feature("docstring")  Interference3DLattice::setPeakShape "void Interference3DLattice::setPeakShape(const IPeakShape &peak_shape)
";

%feature("docstring")  Interference3DLattice::lattice "const Lattice3D & Interference3DLattice::lattice() const
";

%feature("docstring")  Interference3DLattice::supportsMultilayer "bool Interference3DLattice::supportsMultilayer() const override

Indicates if this interference function can be used with a multilayer (DWBA mode) 
";

%feature("docstring")  Interference3DLattice::nodeChildren "std::vector< const INode * > Interference3DLattice::nodeChildren() const override
";


// File: classInterferenceFinite2DLattice.xml
%feature("docstring") InterferenceFinite2DLattice "

Interference function of a finite 2D lattice.

C++ includes: InterferenceFinite2DLattice.h
";

%feature("docstring")  InterferenceFinite2DLattice::InterferenceFinite2DLattice "InterferenceFinite2DLattice::InterferenceFinite2DLattice(const Lattice2D &lattice, unsigned N_1, unsigned N_2)

Constructor of two-dimensional finite lattice interference function.

Parameters:
-----------

lattice: 
object specifying a 2d lattice structure

N_1: 
number of lattice cells in the first lattice direction

N_2: 
number of lattice cells in the second lattice direction 
";

%feature("docstring")  InterferenceFinite2DLattice::~InterferenceFinite2DLattice "InterferenceFinite2DLattice::~InterferenceFinite2DLattice() override
";

%feature("docstring")  InterferenceFinite2DLattice::clone "InterferenceFinite2DLattice * InterferenceFinite2DLattice::clone() const override
";

%feature("docstring")  InterferenceFinite2DLattice::className "std::string InterferenceFinite2DLattice::className() const final
";

%feature("docstring")  InterferenceFinite2DLattice::numberUnitCells1 "unsigned InterferenceFinite2DLattice::numberUnitCells1() const
";

%feature("docstring")  InterferenceFinite2DLattice::numberUnitCells2 "unsigned InterferenceFinite2DLattice::numberUnitCells2() const
";

%feature("docstring")  InterferenceFinite2DLattice::setIntegrationOverXi "void InterferenceFinite2DLattice::setIntegrationOverXi(bool integrate_xi)
";

%feature("docstring")  InterferenceFinite2DLattice::integrationOverXi "bool InterferenceFinite2DLattice::integrationOverXi() const
";

%feature("docstring")  InterferenceFinite2DLattice::lattice "const Lattice2D & InterferenceFinite2DLattice::lattice() const
";

%feature("docstring")  InterferenceFinite2DLattice::particleDensity "double InterferenceFinite2DLattice::particleDensity() const override

Returns the particle density associated with this 2d lattice. 
";

%feature("docstring")  InterferenceFinite2DLattice::nodeChildren "std::vector< const INode * > InterferenceFinite2DLattice::nodeChildren() const override
";


// File: classInterferenceFinite3DLattice.xml
%feature("docstring") InterferenceFinite3DLattice "

Interference function of a finite 3D lattice.

C++ includes: InterferenceFinite3DLattice.h
";

%feature("docstring")  InterferenceFinite3DLattice::InterferenceFinite3DLattice "InterferenceFinite3DLattice::InterferenceFinite3DLattice(const Lattice3D &lattice, unsigned N_1, unsigned N_2, unsigned N_3)
";

%feature("docstring")  InterferenceFinite3DLattice::~InterferenceFinite3DLattice "InterferenceFinite3DLattice::~InterferenceFinite3DLattice() override
";

%feature("docstring")  InterferenceFinite3DLattice::clone "InterferenceFinite3DLattice * InterferenceFinite3DLattice::clone() const override
";

%feature("docstring")  InterferenceFinite3DLattice::className "std::string InterferenceFinite3DLattice::className() const final
";

%feature("docstring")  InterferenceFinite3DLattice::numberUnitCells1 "unsigned InterferenceFinite3DLattice::numberUnitCells1() const
";

%feature("docstring")  InterferenceFinite3DLattice::numberUnitCells2 "unsigned InterferenceFinite3DLattice::numberUnitCells2() const
";

%feature("docstring")  InterferenceFinite3DLattice::numberUnitCells3 "unsigned InterferenceFinite3DLattice::numberUnitCells3() const
";

%feature("docstring")  InterferenceFinite3DLattice::lattice "const Lattice3D & InterferenceFinite3DLattice::lattice() const
";

%feature("docstring")  InterferenceFinite3DLattice::supportsMultilayer "bool InterferenceFinite3DLattice::supportsMultilayer() const override

Indicates if this interference function can be used with a multilayer (DWBA mode) 
";

%feature("docstring")  InterferenceFinite3DLattice::nodeChildren "std::vector< const INode * > InterferenceFinite3DLattice::nodeChildren() const override
";


// File: classInterferenceHardDisk.xml
%feature("docstring") InterferenceHardDisk "

Percus-Yevick hard disk interference function.

M.S. Ripoll & C.F. Tejero (1995) Approximate analytical expression for the direct correlation function of hard discs within the Percus-Yevick equation, Molecular Physics, 85:2, 423-428, DOI: 10.1080/00268979500101211

C++ includes: InterferenceHardDisk.h
";

%feature("docstring")  InterferenceHardDisk::InterferenceHardDisk "InterferenceHardDisk::InterferenceHardDisk(double radius, double density, double position_var=0)
";

%feature("docstring")  InterferenceHardDisk::~InterferenceHardDisk "InterferenceHardDisk::~InterferenceHardDisk() override=default
";

%feature("docstring")  InterferenceHardDisk::parDefs "std::vector<ParaMeta> InterferenceHardDisk::parDefs() const final
";

%feature("docstring")  InterferenceHardDisk::clone "InterferenceHardDisk * InterferenceHardDisk::clone() const override
";

%feature("docstring")  InterferenceHardDisk::className "std::string InterferenceHardDisk::className() const final
";

%feature("docstring")  InterferenceHardDisk::particleDensity "double InterferenceHardDisk::particleDensity() const override

If defined by this interference function's parameters, returns the particle density (per area). Otherwise, returns zero or a user-defined value 
";

%feature("docstring")  InterferenceHardDisk::radius "double InterferenceHardDisk::radius() const
";

%feature("docstring")  InterferenceHardDisk::density "double InterferenceHardDisk::density() const
";


// File: classInterferenceNone.xml
%feature("docstring") InterferenceNone "

Default interference function (i.e. absence of any interference).

C++ includes: InterferenceNone.h
";

%feature("docstring")  InterferenceNone::InterferenceNone "InterferenceNone::InterferenceNone()
";

%feature("docstring")  InterferenceNone::clone "InterferenceNone * InterferenceNone::clone() const override
";

%feature("docstring")  InterferenceNone::className "std::string InterferenceNone::className() const final
";


// File: classInterferenceRadialParaCrystal.xml
%feature("docstring") InterferenceRadialParaCrystal "

Interference function of radial paracrystal.

C++ includes: InterferenceRadialParaCrystal.h
";

%feature("docstring")  InterferenceRadialParaCrystal::InterferenceRadialParaCrystal "InterferenceRadialParaCrystal::InterferenceRadialParaCrystal(double peak_distance, double damping_length)

Constructor of interference function of radial paracrystal.

Parameters:
-----------

peak_distance: 
average distance to the next neighbor in nanometers

damping_length: 
the damping (coherence) length of the paracrystal in nanometers 
";

%feature("docstring")  InterferenceRadialParaCrystal::clone "InterferenceRadialParaCrystal * InterferenceRadialParaCrystal::clone() const override
";

%feature("docstring")  InterferenceRadialParaCrystal::className "std::string InterferenceRadialParaCrystal::className() const final
";

%feature("docstring")  InterferenceRadialParaCrystal::parDefs "std::vector<ParaMeta> InterferenceRadialParaCrystal::parDefs() const final
";

%feature("docstring")  InterferenceRadialParaCrystal::setKappa "void InterferenceRadialParaCrystal::setKappa(double kappa)

Sets size spacing coupling parameter of the Size Spacing Correlation Approximation. 
";

%feature("docstring")  InterferenceRadialParaCrystal::kappa "double InterferenceRadialParaCrystal::kappa() const
";

%feature("docstring")  InterferenceRadialParaCrystal::setDomainSize "void InterferenceRadialParaCrystal::setDomainSize(double size)

Sets domain size (finite size corrections).

Parameters:
-----------

size: 
size of coherence domain along the lattice main axis in nanometers 
";

%feature("docstring")  InterferenceRadialParaCrystal::domainSize "double InterferenceRadialParaCrystal::domainSize() const
";

%feature("docstring")  InterferenceRadialParaCrystal::FTPDF "complex_t InterferenceRadialParaCrystal::FTPDF(double qpar) const
";

%feature("docstring")  InterferenceRadialParaCrystal::setProbabilityDistribution "void InterferenceRadialParaCrystal::setProbabilityDistribution(const IProfile1D &pdf)

Sets one-dimensional probability distribution.

Parameters:
-----------

pdf: 
probability distribution (Fourier transform of probability density) 
";

%feature("docstring")  InterferenceRadialParaCrystal::peakDistance "double InterferenceRadialParaCrystal::peakDistance() const
";

%feature("docstring")  InterferenceRadialParaCrystal::dampingLength "double InterferenceRadialParaCrystal::dampingLength() const
";

%feature("docstring")  InterferenceRadialParaCrystal::nodeChildren "std::vector< const INode * > InterferenceRadialParaCrystal::nodeChildren() const override
";

%feature("docstring")  InterferenceRadialParaCrystal::randomSample "double InterferenceRadialParaCrystal::randomSample() const
";


// File: classInterferenceTwin.xml
%feature("docstring") InterferenceTwin "

Interference function for two particles at a mean distance and given standard deviation from each other in a given direction. TODO: RENAME (has nothing to do with crystallographic twin)

C++ includes: InterferenceTwin.h
";

%feature("docstring")  InterferenceTwin::InterferenceTwin "InterferenceTwin::InterferenceTwin(const R3 &direction, double mean_distance, double std_dev)
";

%feature("docstring")  InterferenceTwin::clone "InterferenceTwin * InterferenceTwin::clone() const override
";

%feature("docstring")  InterferenceTwin::className "std::string InterferenceTwin::className() const final
";

%feature("docstring")  InterferenceTwin::parDefs "std::vector<ParaMeta> InterferenceTwin::parDefs() const final
";

%feature("docstring")  InterferenceTwin::direction "R3 InterferenceTwin::direction() const
";

%feature("docstring")  InterferenceTwin::meanDistance "double InterferenceTwin::meanDistance() const
";

%feature("docstring")  InterferenceTwin::stdDev "double InterferenceTwin::stdDev() const
";


// File: classIParticle.xml
%feature("docstring") IParticle "

Abstract base class for  Particle,  ParticleComposition,  ParticleCoreShell,  MesoCrystal. Provides position/rotation and form factor. Abundance is inherited from  IParticle.

C++ includes: IParticle.h
";

%feature("docstring")  IParticle::~IParticle "IParticle::~IParticle() override
";

%feature("docstring")  IParticle::clone "IParticle* IParticle::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  IParticle::nodeChildren "std::vector< const INode * > IParticle::nodeChildren() const override
";

%feature("docstring")  IParticle::abundance "double IParticle::abundance() const
";

%feature("docstring")  IParticle::setAbundance "void IParticle::setAbundance(double abundance)

Sets particle abundance.

Parameters:
-----------

abundance: 
proportion of this type of particles normalized to the total number of particles in the layout. 
";

%feature("docstring")  IParticle::particlePosition "R3 IParticle::particlePosition() const

Returns particle position. 
";

%feature("docstring")  IParticle::setParticlePosition "void IParticle::setParticlePosition(R3 position)

Sets relative position of the particle's reference point in the coordinate system of parent.

Parameters:
-----------

position: 
relative position vector (components are in nanometers) 
";

%feature("docstring")  IParticle::setParticlePosition "void IParticle::setParticlePosition(double x, double y, double z)

Sets relative position of the particle's reference point in the coordinate system of parent.

Parameters:
-----------

x: 
x-coordinate in nanometers

y: 
y-coordinate in nanometers

z: 
z-coordinate in nanometers 
";

%feature("docstring")  IParticle::translate "IParticle * IParticle::translate(R3 translation)

Translates the particle, and returns this. 
";

%feature("docstring")  IParticle::rotation "const IRotation * IParticle::rotation() const

Returns rotation object. 
";

%feature("docstring")  IParticle::setRotation "void IParticle::setRotation(const IRotation &rotation)

Sets transformation. 
";

%feature("docstring")  IParticle::rotate "IParticle * IParticle::rotate(const IRotation &rotation)

Rotates the particle, and returns this. 
";

%feature("docstring")  IParticle::decompose "std::vector< std::unique_ptr< IParticle > > IParticle::decompose() const

Decompose in constituent  IParticle objects. 
";


// File: classIPeakShape.xml
%feature("docstring") IPeakShape "

Abstract base class class that defines the peak shape of a Bragg peak.

C++ includes: IPeakShape.h
";

%feature("docstring")  IPeakShape::IPeakShape "IPeakShape::IPeakShape()=default
";

%feature("docstring")  IPeakShape::IPeakShape "IPeakShape::IPeakShape(const std::vector< double > &PValues)
";

%feature("docstring")  IPeakShape::~IPeakShape "IPeakShape::~IPeakShape() override
";

%feature("docstring")  IPeakShape::clone "IPeakShape* IPeakShape::clone() const override=0
";

%feature("docstring")  IPeakShape::peakDistribution "virtual double IPeakShape::peakDistribution(R3 q, R3 q_lattice_point) const =0

Peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  IPeakShape::angularDisorder "virtual bool IPeakShape::angularDisorder() const

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classIProfile1D.xml
%feature("docstring") IProfile1D "

Interface for a one-dimensional distribution, with normalization adjusted so that the Fourier transform standardizedFT(q) is a decay function that starts at standardizedFT(0)=1.

C++ includes: Profiles1D.h
";

%feature("docstring")  IProfile1D::IProfile1D "IProfile1D::IProfile1D(const std::vector< double > &PValues)
";

%feature("docstring")  IProfile1D::clone "IProfile1D* IProfile1D::clone() const override=0
";

%feature("docstring")  IProfile1D::standardizedFT "virtual double IProfile1D::standardizedFT(double q) const =0

Returns Fourier transform of the normalized distribution; is a decay function starting at standardizedFT(0)=1. 
";

%feature("docstring")  IProfile1D::decayFT "virtual double IProfile1D::decayFT(double q) const =0

Returns Fourier transform of the distribution scaled as decay function f(x)/f(0). 
";

%feature("docstring")  IProfile1D::omega "double IProfile1D::omega() const
";

%feature("docstring")  IProfile1D::decayLength "double IProfile1D::decayLength() const
";

%feature("docstring")  IProfile1D::qSecondDerivative "virtual double IProfile1D::qSecondDerivative() const =0

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  IProfile1D::createSampler "virtual std::unique_ptr<IDistribution1DSampler> IProfile1D::createSampler() const =0
";

%feature("docstring")  IProfile1D::pythonConstructor "std::string IProfile1D::pythonConstructor() const

Creates the Python constructor of this class (or derived classes) 
";


// File: classIProfile2D.xml
%feature("docstring") IProfile2D "

Interface for two-dimensional distributions in Fourier space.

C++ includes: Profiles2D.h
";

%feature("docstring")  IProfile2D::IProfile2D "IProfile2D::IProfile2D(const std::vector< double > &PValues)
";

%feature("docstring")  IProfile2D::clone "IProfile2D* IProfile2D::clone() const override=0
";

%feature("docstring")  IProfile2D::omegaX "double IProfile2D::omegaX() const
";

%feature("docstring")  IProfile2D::omegaY "double IProfile2D::omegaY() const
";

%feature("docstring")  IProfile2D::decayLengthX "double IProfile2D::decayLengthX() const
";

%feature("docstring")  IProfile2D::decayLengthY "double IProfile2D::decayLengthY() const
";

%feature("docstring")  IProfile2D::gamma "double IProfile2D::gamma() const
";

%feature("docstring")  IProfile2D::delta "double IProfile2D::delta() const

Angle in direct space between X- and Y-axis of distribution. 
";

%feature("docstring")  IProfile2D::standardizedFT2D "virtual double IProfile2D::standardizedFT2D(double qx, double qy) const =0

Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  IProfile2D::decayFT2D "virtual double IProfile2D::decayFT2D(double qx, double qy) const =0
";

%feature("docstring")  IProfile2D::createSampler "virtual std::unique_ptr<IDistribution2DSampler> IProfile2D::createSampler() const =0
";

%feature("docstring")  IProfile2D::pythonConstructor "std::string IProfile2D::pythonConstructor() const

Creates the Python constructor of this class (or derived classes) 
";


// File: classIProfileRectangularRipple.xml
%feature("docstring") IProfileRectangularRipple "

Base class for form factors with a rectangular ripple (bar) profile in the yz plane.

C++ includes: IProfileRipple.h
";

%feature("docstring")  IProfileRectangularRipple::IProfileRectangularRipple "IProfileRectangularRipple::IProfileRectangularRipple(const std::vector< double > &PValues)
";


// File: classIProfileRipple.xml
%feature("docstring") IProfileRipple "

Base class for form factors with a cosine ripple profile in the yz plane.

C++ includes: IProfileRipple.h
";

%feature("docstring")  IProfileRipple::IProfileRipple "IProfileRipple::IProfileRipple(const std::vector< double > &PValues)
";

%feature("docstring")  IProfileRipple::length "double IProfileRipple::length() const
";

%feature("docstring")  IProfileRipple::height "double IProfileRipple::height() const
";

%feature("docstring")  IProfileRipple::width "double IProfileRipple::width() const
";

%feature("docstring")  IProfileRipple::radialExtension "double IProfileRipple::radialExtension() const override

Returns the (approximate in some cases) radial size of the particle of this form factor's shape. This is used for SSCA calculations 
";

%feature("docstring")  IProfileRipple::formfactor_at_bottom "complex_t IProfileRipple::formfactor_at_bottom(C3 q) const override
";


// File: classIRegistry.xml
%feature("docstring") IRegistry "

Templated object registry.

C++ includes: IRegistry.h
";

%feature("docstring")  IRegistry::getItem "const ValueType* IRegistry< ValueType >::getItem(const std::string &key) const
";

%feature("docstring")  IRegistry::keys "std::vector<std::string> IRegistry< ValueType >::keys() const
";

%feature("docstring")  IRegistry::size "size_t IRegistry< ValueType >::size() const
";


// File: classIRotation.xml
%feature("docstring") IRotation "

Abstract base class for rotations.

C++ includes: Rotations.h
";

%feature("docstring")  IRotation::IRotation "IRotation::IRotation(const std::vector< double > &PValues)
";

%feature("docstring")  IRotation::clone "IRotation* IRotation::clone() const override=0
";

%feature("docstring")  IRotation::createInverse "virtual IRotation* IRotation::createInverse() const =0

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  IRotation::rotMatrix "virtual RotMatrix IRotation::rotMatrix() const =0

Returns transformation. 
";

%feature("docstring")  IRotation::transformed "R3 IRotation::transformed(const R3 &v) const
";

%feature("docstring")  IRotation::isIdentity "bool IRotation::isIdentity() const

Returns true if rotation matrix is identity matrix (no rotations) 
";

%feature("docstring")  IRotation::zInvariant "bool IRotation::zInvariant() const
";


// File: classISampleNode.xml
%feature("docstring") ISampleNode "

Abstract base class for sample components and properties related to scattering.

C++ includes: ISampleNode.h
";

%feature("docstring")  ISampleNode::ISampleNode "ISampleNode::ISampleNode()=default
";

%feature("docstring")  ISampleNode::ISampleNode "ISampleNode::ISampleNode(const std::vector< double > &PValues)
";

%feature("docstring")  ISampleNode::clone "ISampleNode* ISampleNode::clone() const override=0

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  ISampleNode::material "virtual const Material* ISampleNode::material() const

Returns nullptr, unless overwritten to return a specific material. 
";

%feature("docstring")  ISampleNode::containedMaterials "std::vector< const Material * > ISampleNode::containedMaterials() const

Returns set of unique materials contained in this  ISampleNode. 
";

%feature("docstring")  ISampleNode::isMagnetic "bool ISampleNode::isMagnetic() const

Returns true if there is any magnetic material in this  ISampleNode. 
";


// File: classISawtoothRipple.xml
%feature("docstring") ISawtoothRipple "

Base class for form factors with a triangular ripple profile in the yz plane.

C++ includes: IProfileRipple.h
";

%feature("docstring")  ISawtoothRipple::ISawtoothRipple "ISawtoothRipple::ISawtoothRipple(const std::vector< double > &PValues)
";

%feature("docstring")  ISawtoothRipple::asymmetry "double ISawtoothRipple::asymmetry() const
";


// File: classISelectionRule.xml
%feature("docstring") ISelectionRule "

Abstract base class for selection rules.

C++ includes: ISelectionRule.h
";

%feature("docstring")  ISelectionRule::~ISelectionRule "virtual ISelectionRule::~ISelectionRule()=default
";

%feature("docstring")  ISelectionRule::clone "virtual ISelectionRule* ISelectionRule::clone() const =0
";

%feature("docstring")  ISelectionRule::coordinateSelected "virtual bool ISelectionRule::coordinateSelected(const I3 &coordinate) const =0
";


// File: classIShape3D.xml
%feature("docstring") IShape3D "

Abstract base class for different shapes.

In contrast to the form factors, these shapes only provide an interface for returning a set of vertices.

C++ includes: IShape3D.h
";

%feature("docstring")  IShape3D::IShape3D "IShape3D::IShape3D()=default
";

%feature("docstring")  IShape3D::~IShape3D "virtual IShape3D::~IShape3D()=default
";

%feature("docstring")  IShape3D::vertices "std::vector< R3 > IShape3D::vertices() const

Retrieves a list of the vertices constituting this concrete shape. 
";


// File: classIsotropicGaussPeakShape.xml
%feature("docstring") IsotropicGaussPeakShape "

Class that implements an isotropic Gaussian peak shape of a Bragg peak.

C++ includes: IPeakShape.h
";

%feature("docstring")  IsotropicGaussPeakShape::IsotropicGaussPeakShape "IsotropicGaussPeakShape::IsotropicGaussPeakShape(double max_intensity, double domainsize)
";

%feature("docstring")  IsotropicGaussPeakShape::~IsotropicGaussPeakShape "IsotropicGaussPeakShape::~IsotropicGaussPeakShape() override
";

%feature("docstring")  IsotropicGaussPeakShape::clone "IsotropicGaussPeakShape * IsotropicGaussPeakShape::clone() const override
";

%feature("docstring")  IsotropicGaussPeakShape::className "std::string IsotropicGaussPeakShape::className() const final
";

%feature("docstring")  IsotropicGaussPeakShape::parDefs "std::vector<ParaMeta> IsotropicGaussPeakShape::parDefs() const final
";

%feature("docstring")  IsotropicGaussPeakShape::peakDistribution "double IsotropicGaussPeakShape::peakDistribution(R3 q, R3 q_lattice_point) const override

Peak shape at q from a reciprocal lattice point at q_lattice_point. 
";


// File: classIsotropicLorentzPeakShape.xml
%feature("docstring") IsotropicLorentzPeakShape "

An isotropic Lorentzian peak shape of a Bragg peak.

C++ includes: IPeakShape.h
";

%feature("docstring")  IsotropicLorentzPeakShape::IsotropicLorentzPeakShape "IsotropicLorentzPeakShape::IsotropicLorentzPeakShape(double max_intensity, double domainsize)
";

%feature("docstring")  IsotropicLorentzPeakShape::~IsotropicLorentzPeakShape "IsotropicLorentzPeakShape::~IsotropicLorentzPeakShape() override
";

%feature("docstring")  IsotropicLorentzPeakShape::clone "IsotropicLorentzPeakShape * IsotropicLorentzPeakShape::clone() const override
";

%feature("docstring")  IsotropicLorentzPeakShape::className "std::string IsotropicLorentzPeakShape::className() const final
";

%feature("docstring")  IsotropicLorentzPeakShape::parDefs "std::vector<ParaMeta> IsotropicLorentzPeakShape::parDefs() const final
";

%feature("docstring")  IsotropicLorentzPeakShape::peakDistribution "double IsotropicLorentzPeakShape::peakDistribution(R3 q, R3 q_lattice_point) const override

Peak shape at q from a reciprocal lattice point at q_lattice_point. 
";


// File: classLattice2D.xml
%feature("docstring") Lattice2D "

A two-dimensional Bravais lattice.

C++ includes: Lattice2D.h
";

%feature("docstring")  Lattice2D::Lattice2D "Lattice2D::Lattice2D(const std::vector< double > &PValues)
";

%feature("docstring")  Lattice2D::Lattice2D "Lattice2D::Lattice2D(double xi)
";

%feature("docstring")  Lattice2D::clone "Lattice2D* Lattice2D::clone() const override=0
";

%feature("docstring")  Lattice2D::length1 "virtual double Lattice2D::length1() const =0
";

%feature("docstring")  Lattice2D::length2 "virtual double Lattice2D::length2() const =0
";

%feature("docstring")  Lattice2D::latticeAngle "virtual double Lattice2D::latticeAngle() const =0
";

%feature("docstring")  Lattice2D::unitCellArea "virtual double Lattice2D::unitCellArea() const =0
";

%feature("docstring")  Lattice2D::rotationAngle "double Lattice2D::rotationAngle() const
";

%feature("docstring")  Lattice2D::reciprocalBases "Lattice2D::ReciprocalBases Lattice2D::reciprocalBases() const
";

%feature("docstring")  Lattice2D::setRotationEnabled "void Lattice2D::setRotationEnabled(bool enabled)
";


// File: classLattice3D.xml
%feature("docstring") Lattice3D "

A Bravais lattice, characterized by three basis vectors, and optionally an  ISelectionRule.

C++ includes: Lattice3D.h
";

%feature("docstring")  Lattice3D::Lattice3D "Lattice3D::Lattice3D(R3 a, R3 b, R3 c)
";

%feature("docstring")  Lattice3D::Lattice3D "Lattice3D::Lattice3D(const Lattice3D &lattice)
";

%feature("docstring")  Lattice3D::~Lattice3D "Lattice3D::~Lattice3D() override
";

%feature("docstring")  Lattice3D::className "std::string Lattice3D::className() const final
";

%feature("docstring")  Lattice3D::rotated "Lattice3D Lattice3D::rotated(const RotMatrix &rotMatrix) const

Creates rotated lattice. 
";

%feature("docstring")  Lattice3D::basisVectorA "R3 Lattice3D::basisVectorA() const

Returns basis vector a. 
";

%feature("docstring")  Lattice3D::basisVectorB "R3 Lattice3D::basisVectorB() const

Returns basis vector b. 
";

%feature("docstring")  Lattice3D::basisVectorC "R3 Lattice3D::basisVectorC() const

Returns basis vector c. 
";

%feature("docstring")  Lattice3D::getMillerDirection "R3 Lattice3D::getMillerDirection(double h, double k, double l) const

Returns normalized direction corresponding to the given Miller indices.

Currently unused but may be useful for checks. 
";

%feature("docstring")  Lattice3D::unitCellVolume "double Lattice3D::unitCellVolume() const

Returns the volume of the unit cell. 
";

%feature("docstring")  Lattice3D::reciprocalLatticeBasis "void Lattice3D::reciprocalLatticeBasis(R3 &ra, R3 &rb, R3 &rc) const

Returns the reciprocal basis vectors.

Currently only used in tests. 
";

%feature("docstring")  Lattice3D::nearestReciprocalLatticeVectorCoordinates "I3 Lattice3D::nearestReciprocalLatticeVectorCoordinates(R3 q) const

Returns the nearest reciprocal lattice point from a given vector. 
";

%feature("docstring")  Lattice3D::reciprocalLatticeVectorsWithinRadius "std::vector< R3 > Lattice3D::reciprocalLatticeVectorsWithinRadius(R3 q, double dq) const

Returns a list of reciprocal lattice vectors within distance dq of a vector q. 
";

%feature("docstring")  Lattice3D::setSelectionRule "void Lattice3D::setSelectionRule(const ISelectionRule &selection_rule)

Sets a selection rule for the reciprocal vectors. 
";


// File: classLayer.xml
%feature("docstring") Layer "

A layer in a  MultiLayer sample.

C++ includes: Layer.h
";

%feature("docstring")  Layer::Layer "Layer::Layer(Material material, double thickness=0)

Constructor of a layer with thickness and material

Parameters:
-----------

material: 
material the layer is made of

thickness: 
thickness of a layer in nanometers 
";

%feature("docstring")  Layer::~Layer "Layer::~Layer() override
";

%feature("docstring")  Layer::clone "Layer * Layer::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Layer::className "std::string Layer::className() const final
";

%feature("docstring")  Layer::parDefs "std::vector<ParaMeta> Layer::parDefs() const final
";

%feature("docstring")  Layer::nodeChildren "std::vector< const INode * > Layer::nodeChildren() const override
";

%feature("docstring")  Layer::material "const Material* Layer::material() const override

Returns nullptr, unless overwritten to return a specific material. 
";

%feature("docstring")  Layer::thickness "double Layer::thickness() const
";

%feature("docstring")  Layer::addLayout "void Layer::addLayout(const ParticleLayout &layout)
";

%feature("docstring")  Layer::numberOfLayouts "size_t Layer::numberOfLayouts() const
";

%feature("docstring")  Layer::layouts "std::vector< const ParticleLayout * > Layer::layouts() const
";

%feature("docstring")  Layer::setNumberOfSlices "void Layer::setNumberOfSlices(unsigned int n_slices)
";

%feature("docstring")  Layer::numberOfSlices "unsigned int Layer::numberOfSlices() const
";


// File: classLayerInterface.xml
%feature("docstring") LayerInterface "

Interface between two layers, possibly with roughness.

C++ includes: LayerInterface.h
";

%feature("docstring")  LayerInterface::~LayerInterface "LayerInterface::~LayerInterface() override
";

%feature("docstring")  LayerInterface::clone "LayerInterface * LayerInterface::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  LayerInterface::className "std::string LayerInterface::className() const final
";

%feature("docstring")  LayerInterface::setRoughness "void LayerInterface::setRoughness(const LayerRoughness &roughness)

Sets roughness of the interface. 
";

%feature("docstring")  LayerInterface::roughness "const LayerRoughness * LayerInterface::roughness() const

Returns roughness of the interface. 
";

%feature("docstring")  LayerInterface::topLayer "const Layer * LayerInterface::topLayer() const
";

%feature("docstring")  LayerInterface::bottomLayer "const Layer * LayerInterface::bottomLayer() const
";

%feature("docstring")  LayerInterface::nodeChildren "std::vector< const INode * > LayerInterface::nodeChildren() const override
";


// File: classLayerRoughness.xml
%feature("docstring") LayerRoughness "

A roughness of interface between two layers.

Based on the article \"X-ray reflection and transmission by rough surfaces\" by D. K. G. de Boer, Physical Review B 51, 5297 (1995)

C++ includes: LayerRoughness.h
";

%feature("docstring")  LayerRoughness::LayerRoughness "LayerRoughness::LayerRoughness(double sigma, double hurstParameter=0, double lateralCorrLength=0)

Constructor of layer roughness.

Parameters:
-----------

sigma: 
rms of the roughness in nanometers

hurstParameter: 
hurst parameter which describes how jagged the interface, dimensionless [0.0, 1.0], where 0.0 gives more spikes, 1.0 more smoothness

lateralCorrLength: 
lateral correlation length of the roughness in nanometers 
";

%feature("docstring")  LayerRoughness::LayerRoughness "LayerRoughness::LayerRoughness()
";

%feature("docstring")  LayerRoughness::clone "LayerRoughness* LayerRoughness::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  LayerRoughness::className "std::string LayerRoughness::className() const final
";

%feature("docstring")  LayerRoughness::parDefs "std::vector<ParaMeta> LayerRoughness::parDefs() const final
";

%feature("docstring")  LayerRoughness::spectralFunction "double LayerRoughness::spectralFunction(R3 kvec) const

Returns power spectral density of the surface roughness.

Power spectral density of the surface roughness is a result of two-dimensional Fourier transform of the correlation function of the roughness profile.

Based on the article D.K.G. de Boer, Physical review B, Volume 51, Number 8, 15 February 1995 \"X-ray reflection and transmission by rough surfaces\" 
";

%feature("docstring")  LayerRoughness::corrFunction "double LayerRoughness::corrFunction(R3 k) const

Correlation function of the roughness profile. 
";

%feature("docstring")  LayerRoughness::setSigma "void LayerRoughness::setSigma(double sigma)

Sets rms of roughness. 
";

%feature("docstring")  LayerRoughness::sigma "double LayerRoughness::sigma() const

Returns rms of roughness. 
";

%feature("docstring")  LayerRoughness::setHurstParameter "void LayerRoughness::setHurstParameter(double hurstParameter)

Sets hurst parameter. It describes how jagged the surface is. 
";

%feature("docstring")  LayerRoughness::hurst "double LayerRoughness::hurst() const

Returns hurst parameter. 
";

%feature("docstring")  LayerRoughness::setLatteralCorrLength "void LayerRoughness::setLatteralCorrLength(double lateralCorrLength)

Sets lateral correlation length. 
";

%feature("docstring")  LayerRoughness::lateralCorrLength "double LayerRoughness::lateralCorrLength() const

Returns lateral correlation length. 
";

%feature("docstring")  LayerRoughness::pythonConstructor "std::string LayerRoughness::pythonConstructor() const

Creates the Python constructor of this class. 
";


// File: classLorentzFisherPeakShape.xml
%feature("docstring") LorentzFisherPeakShape "

A peak shape that is Lorentzian in the radial direction and uses the Mises-Fisher distribution in the angular direction.

C++ includes: IPeakShape.h
";

%feature("docstring")  LorentzFisherPeakShape::LorentzFisherPeakShape "LorentzFisherPeakShape::LorentzFisherPeakShape(double max_intensity, double radial_size, double kappa)
";

%feature("docstring")  LorentzFisherPeakShape::~LorentzFisherPeakShape "LorentzFisherPeakShape::~LorentzFisherPeakShape() override
";

%feature("docstring")  LorentzFisherPeakShape::clone "LorentzFisherPeakShape * LorentzFisherPeakShape::clone() const override
";

%feature("docstring")  LorentzFisherPeakShape::className "std::string LorentzFisherPeakShape::className() const final
";

%feature("docstring")  LorentzFisherPeakShape::parDefs "std::vector<ParaMeta> LorentzFisherPeakShape::parDefs() const final
";

%feature("docstring")  LorentzFisherPeakShape::peakDistribution "double LorentzFisherPeakShape::peakDistribution(R3 q, R3 q_lattice_point) const override

Peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  LorentzFisherPeakShape::angularDisorder "bool LorentzFisherPeakShape::angularDisorder() const override

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classMagneticMaterialImpl.xml
%feature("docstring") MagneticMaterialImpl "

Basic implementation for magnetized material. Inherited by  RefractiveMaterialImpl and  MaterialBySLDImpl. Incorporates data and methods required to handle material magnetization.

C++ includes: MagneticMaterialImpl.h
";

%feature("docstring")  MagneticMaterialImpl::MagneticMaterialImpl "MagneticMaterialImpl::MagneticMaterialImpl(const std::string &name, R3 magnetization)

Constructs basic material with name and magnetization. 
";

%feature("docstring")  MagneticMaterialImpl::~MagneticMaterialImpl "MagneticMaterialImpl::~MagneticMaterialImpl() override=default
";

%feature("docstring")  MagneticMaterialImpl::clone "MagneticMaterialImpl* MagneticMaterialImpl::clone() const override=0

Returns pointer to a copy of material. 
";

%feature("docstring")  MagneticMaterialImpl::inverted "MagneticMaterialImpl * MagneticMaterialImpl::inverted() const override

Constructs a material with inverted magnetization. 
";

%feature("docstring")  MagneticMaterialImpl::isScalarMaterial "bool MagneticMaterialImpl::isScalarMaterial() const override

Indicates whether the interaction with the material is scalar. This means that different polarization states will be diffracted equally 
";

%feature("docstring")  MagneticMaterialImpl::isMagneticMaterial "bool MagneticMaterialImpl::isMagneticMaterial() const override
";

%feature("docstring")  MagneticMaterialImpl::magnetization "R3 MagneticMaterialImpl::magnetization() const override

Returns the magnetization (in A/m) 
";

%feature("docstring")  MagneticMaterialImpl::polarizedSubtrSLD "Eigen::Matrix2cd MagneticMaterialImpl::polarizedSubtrSLD(const WavevectorInfo &wavevectors) const override

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld) matrix with magnetization corrections. 
";

%feature("docstring")  MagneticMaterialImpl::rotatedMaterial "MagneticMaterialImpl * MagneticMaterialImpl::rotatedMaterial(const RotMatrix &transform) const override
";


// File: classMaterial.xml
%feature("docstring") Material "

A wrapper for underlying material implementation

C++ includes: Material.h
";

%feature("docstring")  Material::Material "Material::Material(std::unique_ptr< BaseMaterialImpl > material_impl)

Creates material with particular material implementation. 
";

%feature("docstring")  Material::Material "Material::Material(const Material &material)
";

%feature("docstring")  Material::Material "Material::Material(Material &&material)=default
";

%feature("docstring")  Material::inverted "Material Material::inverted() const

Constructs a material with inverted magnetization. 
";

%feature("docstring")  Material::refractiveIndex "complex_t Material::refractiveIndex(double wavelength) const

Returns refractive index. 
";

%feature("docstring")  Material::refractiveIndex2 "complex_t Material::refractiveIndex2(double wavelength) const

Returns squared refractive index. 
";

%feature("docstring")  Material::isScalarMaterial "bool Material::isScalarMaterial() const

Indicates whether the interaction with the material is scalar. This means that different polarization states will be diffracted equally 
";

%feature("docstring")  Material::isMagneticMaterial "bool Material::isMagneticMaterial() const
";

%feature("docstring")  Material::materialName "std::string Material::materialName() const

Returns the name of material. 
";

%feature("docstring")  Material::typeID "MATERIAL_TYPES Material::typeID() const

Returns the type of underlying material implementation. 
";

%feature("docstring")  Material::magnetization "R3 Material::magnetization() const

Get the magnetization (in A/m) 
";

%feature("docstring")  Material::materialData "complex_t Material::materialData() const

Returns delta + i beta. 
";

%feature("docstring")  Material::isEmpty "bool Material::isEmpty() const

Returns true if material underlying data is nullptr. 
";

%feature("docstring")  Material::isDefaultMaterial "bool Material::isDefaultMaterial() const

Returns true if material has refractive index of (1.0, 0.0) and zero magnetization. 
";

%feature("docstring")  Material::scalarSubtrSLD "complex_t Material::scalarSubtrSLD(const WavevectorInfo &wavevectors) const

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld), sld (in  $nm^{-2}$) being the scattering length density 
";

%feature("docstring")  Material::polarizedSubtrSLD "Eigen::Matrix2cd Material::polarizedSubtrSLD(const WavevectorInfo &wavevectors) const

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld) matrix with magnetization corrections. 
";

%feature("docstring")  Material::rotatedMaterial "Material Material::rotatedMaterial(const RotMatrix &transform) const
";


// File: classMaterialBySLDImpl.xml
%feature("docstring") MaterialBySLDImpl "

Material implementation based on wavelength-independent data (valid for a range of wavelengths)

C++ includes: MaterialBySLDImpl.h
";

%feature("docstring")  MaterialBySLDImpl::~MaterialBySLDImpl "MaterialBySLDImpl::~MaterialBySLDImpl() override=default
";

%feature("docstring")  MaterialBySLDImpl::clone "MaterialBySLDImpl * MaterialBySLDImpl::clone() const override

Returns pointer to a copy of material. 
";

%feature("docstring")  MaterialBySLDImpl::refractiveIndex "complex_t MaterialBySLDImpl::refractiveIndex(double wavelength) const override

Returns refractive index. 
";

%feature("docstring")  MaterialBySLDImpl::refractiveIndex2 "complex_t MaterialBySLDImpl::refractiveIndex2(double wavelength) const override

Returns squared refractive index. 
";

%feature("docstring")  MaterialBySLDImpl::materialData "complex_t MaterialBySLDImpl::materialData() const override

Returns underlying material data. 
";

%feature("docstring")  MaterialBySLDImpl::typeID "MATERIAL_TYPES MaterialBySLDImpl::typeID() const override

Returns type of material implementation. 
";

%feature("docstring")  MaterialBySLDImpl::scalarSubtrSLD "complex_t MaterialBySLDImpl::scalarSubtrSLD(double lambda0) const override

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld), sld (in  $nm^{-2}$) being the scattering length density 
";

%feature("docstring")  MaterialBySLDImpl::print "void MaterialBySLDImpl::print(std::ostream &ostr) const override

Prints object data. 
";


// File: classMesoCrystal.xml
%feature("docstring") MesoCrystal "

A particle with a crystalline inner structure, made of smaller particles, and an outer shape described by a particle form factor.

C++ includes: MesoCrystal.h
";

%feature("docstring")  MesoCrystal::MesoCrystal "MesoCrystal::MesoCrystal(const Crystal &crystal, const IBornFF &formfactor)
";

%feature("docstring")  MesoCrystal::~MesoCrystal "MesoCrystal::~MesoCrystal() override
";

%feature("docstring")  MesoCrystal::clone "MesoCrystal * MesoCrystal::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  MesoCrystal::className "std::string MesoCrystal::className() const final
";

%feature("docstring")  MesoCrystal::nodeChildren "std::vector< const INode * > MesoCrystal::nodeChildren() const override
";

%feature("docstring")  MesoCrystal::outerShape "const IBornFF* MesoCrystal::outerShape() const
";

%feature("docstring")  MesoCrystal::particleStructure "const Crystal & MesoCrystal::particleStructure() const
";


// File: classMisesFisherGaussPeakShape.xml
%feature("docstring") MisesFisherGaussPeakShape "

A peak shape that is Gaussian in the radial direction and a convolution of a Mises-Fisher distribution with a Mises distribution on the two-sphere.

C++ includes: IPeakShape.h
";

%feature("docstring")  MisesFisherGaussPeakShape::MisesFisherGaussPeakShape "MisesFisherGaussPeakShape::MisesFisherGaussPeakShape(double max_intensity, double radial_size, R3 zenith, double kappa_1, double kappa_2)
";

%feature("docstring")  MisesFisherGaussPeakShape::~MisesFisherGaussPeakShape "MisesFisherGaussPeakShape::~MisesFisherGaussPeakShape() override
";

%feature("docstring")  MisesFisherGaussPeakShape::clone "MisesFisherGaussPeakShape * MisesFisherGaussPeakShape::clone() const override
";

%feature("docstring")  MisesFisherGaussPeakShape::className "std::string MisesFisherGaussPeakShape::className() const final
";

%feature("docstring")  MisesFisherGaussPeakShape::parDefs "std::vector<ParaMeta> MisesFisherGaussPeakShape::parDefs() const final
";

%feature("docstring")  MisesFisherGaussPeakShape::peakDistribution "double MisesFisherGaussPeakShape::peakDistribution(R3 q, R3 q_lattice_point) const override

Peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  MisesFisherGaussPeakShape::angularDisorder "bool MisesFisherGaussPeakShape::angularDisorder() const override

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classMisesGaussPeakShape.xml
%feature("docstring") MisesGaussPeakShape "

A peak shape that is a convolution of a Mises-Fisher distribution with a 3d Gaussian.

C++ includes: IPeakShape.h
";

%feature("docstring")  MisesGaussPeakShape::MisesGaussPeakShape "MisesGaussPeakShape::MisesGaussPeakShape(double max_intensity, double radial_size, R3 zenith, double kappa)
";

%feature("docstring")  MisesGaussPeakShape::~MisesGaussPeakShape "MisesGaussPeakShape::~MisesGaussPeakShape() override
";

%feature("docstring")  MisesGaussPeakShape::clone "MisesGaussPeakShape * MisesGaussPeakShape::clone() const override
";

%feature("docstring")  MisesGaussPeakShape::className "std::string MisesGaussPeakShape::className() const final
";

%feature("docstring")  MisesGaussPeakShape::parDefs "std::vector<ParaMeta> MisesGaussPeakShape::parDefs() const final
";

%feature("docstring")  MisesGaussPeakShape::peakDistribution "double MisesGaussPeakShape::peakDistribution(R3 q, R3 q_lattice_point) const override

Peak shape at q from a reciprocal lattice point at q_lattice_point. 
";

%feature("docstring")  MisesGaussPeakShape::angularDisorder "bool MisesGaussPeakShape::angularDisorder() const override

Indicates if the peak shape encodes angular disorder, in which case all peaks in a spherical shell are needed 
";


// File: classMultiLayer.xml
%feature("docstring") MultiLayer "

Our sample model: a stack of layers one below the other. Example of system of 4 layers (3 interfaces):

ambience layer #0 ------ interface #0 z=0.0 Fe, 20A layer #1 ------ interface #1 z=-20.0 Cr, 40A layer #2 ------ interface #2 z=-60.0 substrate layer #3

C++ includes: MultiLayer.h
";

%feature("docstring")  MultiLayer::MultiLayer "MultiLayer::MultiLayer(std::string name=\"Unnamed\")
";

%feature("docstring")  MultiLayer::~MultiLayer "MultiLayer::~MultiLayer() override
";

%feature("docstring")  MultiLayer::clone "MultiLayer * MultiLayer::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  MultiLayer::className "std::string MultiLayer::className() const final
";

%feature("docstring")  MultiLayer::numberOfLayers "size_t MultiLayer::numberOfLayers() const
";

%feature("docstring")  MultiLayer::addLayer "void MultiLayer::addLayer(const Layer &layer)

Adds layer with default (zero) roughness. 
";

%feature("docstring")  MultiLayer::addLayerWithTopRoughness "void MultiLayer::addLayerWithTopRoughness(const Layer &layer, const LayerRoughness &roughness)

Adds layer with top roughness. 
";

%feature("docstring")  MultiLayer::setRoughnessModel "void MultiLayer::setRoughnessModel(RoughnessModel roughnessModel)
";

%feature("docstring")  MultiLayer::setCrossCorrLength "void MultiLayer::setCrossCorrLength(double crossCorrLength)

Sets cross correlation length of roughnesses between interfaces. 
";

%feature("docstring")  MultiLayer::setExternalField "void MultiLayer::setExternalField(R3 ext_field)

Sets the external field applied to the multilayer (units: A/m) 
";

%feature("docstring")  MultiLayer::layer "const Layer * MultiLayer::layer(size_t i_layer) const

Returns layer with given index. 
";

%feature("docstring")  MultiLayer::layerInterface "const LayerInterface * MultiLayer::layerInterface(size_t i_interface) const

Returns interface with given index. 
";

%feature("docstring")  MultiLayer::roughnessModel "RoughnessModel MultiLayer::roughnessModel() const
";

%feature("docstring")  MultiLayer::crossCorrLength "double MultiLayer::crossCorrLength() const

Returns cross correlation length of roughnesses between interfaces. 
";

%feature("docstring")  MultiLayer::externalField "R3 MultiLayer::externalField() const

Returns the external field applied to the multilayer (units: A/m) 
";

%feature("docstring")  MultiLayer::nodeChildren "std::vector< const INode * > MultiLayer::nodeChildren() const override
";

%feature("docstring")  MultiLayer::setSampleName "void MultiLayer::setSampleName(const std::string &name)
";

%feature("docstring")  MultiLayer::sampleName "const std::string& MultiLayer::sampleName() const
";


// File: structOneAdmixture.xml
%feature("docstring") OneAdmixture "

An admixture to a slice, consisting of a certain volume fraction of a homogeneous material.

C++ includes: Admixtures.h
";


// File: classParticle.xml
%feature("docstring") Particle "

A particle with a form factor and refractive index.

C++ includes: Particle.h
";

%feature("docstring")  Particle::Particle "Particle::Particle(Material material, const IBornFF &formfactor)
";

%feature("docstring")  Particle::Particle "Particle::Particle(Material material, const IBornFF &formfactor, const IRotation &rotation)
";

%feature("docstring")  Particle::~Particle "Particle::~Particle() override
";

%feature("docstring")  Particle::clone "Particle * Particle::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  Particle::className "std::string Particle::className() const override
";

%feature("docstring")  Particle::nodeChildren "std::vector< const INode * > Particle::nodeChildren() const override
";

%feature("docstring")  Particle::material "const Material* Particle::material() const override

Returns nullptr, unless overwritten to return a specific material. 
";

%feature("docstring")  Particle::formfactor_at_bottom "const IBornFF* Particle::formfactor_at_bottom() const
";


// File: classParticleComposition.xml
%feature("docstring") ParticleComposition "

A composition of particles at fixed positions

C++ includes: ParticleComposition.h
";

%feature("docstring")  ParticleComposition::ParticleComposition "ParticleComposition::ParticleComposition()
";

%feature("docstring")  ParticleComposition::~ParticleComposition "ParticleComposition::~ParticleComposition() override
";

%feature("docstring")  ParticleComposition::clone "ParticleComposition * ParticleComposition::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  ParticleComposition::className "std::string ParticleComposition::className() const final
";

%feature("docstring")  ParticleComposition::nodeChildren "std::vector< const INode * > ParticleComposition::nodeChildren() const override
";

%feature("docstring")  ParticleComposition::decompose "std::vector< std::unique_ptr< IParticle > > ParticleComposition::decompose() const override

Decompose in constituent  IParticle objects. 
";

%feature("docstring")  ParticleComposition::addParticle "void ParticleComposition::addParticle(const IParticle &particle)
";

%feature("docstring")  ParticleComposition::addParticle "void ParticleComposition::addParticle(const IParticle &particle, R3 position)
";

%feature("docstring")  ParticleComposition::addParticles "void ParticleComposition::addParticles(const IParticle &particle, std::vector< R3 > positions)
";

%feature("docstring")  ParticleComposition::nbrParticles "size_t ParticleComposition::nbrParticles() const

Returns number of different particles. 
";

%feature("docstring")  ParticleComposition::particles "std::vector< const IParticle * > ParticleComposition::particles() const
";


// File: classParticleCoreShell.xml
%feature("docstring") ParticleCoreShell "

A particle with a core/shell geometry.

C++ includes: ParticleCoreShell.h
";

%feature("docstring")  ParticleCoreShell::ParticleCoreShell "ParticleCoreShell::ParticleCoreShell(const Particle &shell, const Particle &core, R3 relative_core_position=R3(0.0, 0.0, 0.0))
";

%feature("docstring")  ParticleCoreShell::~ParticleCoreShell "ParticleCoreShell::~ParticleCoreShell() override
";

%feature("docstring")  ParticleCoreShell::clone "ParticleCoreShell * ParticleCoreShell::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  ParticleCoreShell::className "std::string ParticleCoreShell::className() const final
";

%feature("docstring")  ParticleCoreShell::nodeChildren "std::vector< const INode * > ParticleCoreShell::nodeChildren() const override
";

%feature("docstring")  ParticleCoreShell::shellParticle "const Particle* ParticleCoreShell::shellParticle() const
";

%feature("docstring")  ParticleCoreShell::coreParticle "const Particle* ParticleCoreShell::coreParticle() const
";


// File: classParticleLayout.xml
%feature("docstring") ParticleLayout "

Decorator class that adds particles to  ISampleNode objects.

C++ includes: ParticleLayout.h
";

%feature("docstring")  ParticleLayout::ParticleLayout "ParticleLayout::ParticleLayout()
";

%feature("docstring")  ParticleLayout::ParticleLayout "ParticleLayout::ParticleLayout(const IParticle &particle, double abundance=-1.0)
";

%feature("docstring")  ParticleLayout::~ParticleLayout "ParticleLayout::~ParticleLayout() override
";

%feature("docstring")  ParticleLayout::clone "ParticleLayout * ParticleLayout::clone() const override

Returns a clone of this  ISampleNode object. 
";

%feature("docstring")  ParticleLayout::className "std::string ParticleLayout::className() const final
";

%feature("docstring")  ParticleLayout::parDefs "std::vector<ParaMeta> ParticleLayout::parDefs() const final
";

%feature("docstring")  ParticleLayout::nodeChildren "std::vector< const INode * > ParticleLayout::nodeChildren() const override
";

%feature("docstring")  ParticleLayout::addParticle "void ParticleLayout::addParticle(const IParticle &particle, double abundance=-1.0, R3 position={}, const IRotation &rotation=IdentityRotation())

Adds particle to the layout with abundance, position and the rotation defined.

Parameters:
-----------

particle: 
to be added

abundance: 
 Particle abundance

position: 
 Particle position

rotation: 
 Particle rotation 
";

%feature("docstring")  ParticleLayout::particles "const std::vector<std::unique_ptr<IParticle> >& ParticleLayout::particles() const
";

%feature("docstring")  ParticleLayout::interferenceFunction "const IInterference * ParticleLayout::interferenceFunction() const
";

%feature("docstring")  ParticleLayout::totalAbundance "double ParticleLayout::totalAbundance() const
";

%feature("docstring")  ParticleLayout::setInterference "void ParticleLayout::setInterference(const IInterference &interparticle)

Adds interference functions. 
";

%feature("docstring")  ParticleLayout::totalParticleSurfaceDensity "double ParticleLayout::totalParticleSurfaceDensity() const
";

%feature("docstring")  ParticleLayout::setTotalParticleSurfaceDensity "void ParticleLayout::setTotalParticleSurfaceDensity(double particle_density)

Sets total particle surface density.

Parameters:
-----------

particle_density: 
number of particles per square nanometer 
";

%feature("docstring")  ParticleLayout::weight "double ParticleLayout::weight() const

Returns the relative weight of this layout. 
";

%feature("docstring")  ParticleLayout::setWeight "void ParticleLayout::setWeight(double weight)

Sets the relative weight of this layout. 
";

%feature("docstring")  ParticleLayout::weightedParticleSurfaceDensity "double ParticleLayout::weightedParticleSurfaceDensity() const
";


// File: classProfile1DCauchy.xml
%feature("docstring") Profile1DCauchy "

Exponential  IProfile1D exp(-|omega*x|); its Fourier transform standardizedFT(q) is a Cauchy-Lorentzian starting at standardizedFT(0)=1.

C++ includes: Profiles1D.h
";

%feature("docstring")  Profile1DCauchy::Profile1DCauchy "Profile1DCauchy::Profile1DCauchy(std::vector< double > P)
";

%feature("docstring")  Profile1DCauchy::Profile1DCauchy "Profile1DCauchy::Profile1DCauchy(double omega)
";

%feature("docstring")  Profile1DCauchy::clone "Profile1DCauchy * Profile1DCauchy::clone() const override
";

%feature("docstring")  Profile1DCauchy::className "std::string Profile1DCauchy::className() const final
";

%feature("docstring")  Profile1DCauchy::parDefs "std::vector<ParaMeta> Profile1DCauchy::parDefs() const final
";

%feature("docstring")  Profile1DCauchy::standardizedFT "double Profile1DCauchy::standardizedFT(double q) const override

Returns Fourier transform of the normalized distribution; is a decay function starting at standardizedFT(0)=1. 
";

%feature("docstring")  Profile1DCauchy::decayFT "double Profile1DCauchy::decayFT(double q) const override

Returns Fourier transform of the distribution scaled as decay function f(x)/f(0). 
";

%feature("docstring")  Profile1DCauchy::qSecondDerivative "double Profile1DCauchy::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  Profile1DCauchy::createSampler "std::unique_ptr< IDistribution1DSampler > Profile1DCauchy::createSampler() const override
";


// File: classProfile1DCosine.xml
%feature("docstring") Profile1DCosine "

IProfile1D consisting of one cosine wave [1+cos(pi*x/omega) if |x|<omega, and 0 otherwise]; its Fourier transform standardizedFT(q) starts at standardizedFT(0)=1.

C++ includes: Profiles1D.h
";

%feature("docstring")  Profile1DCosine::Profile1DCosine "Profile1DCosine::Profile1DCosine(std::vector< double > P)
";

%feature("docstring")  Profile1DCosine::Profile1DCosine "Profile1DCosine::Profile1DCosine(double omega)
";

%feature("docstring")  Profile1DCosine::clone "Profile1DCosine * Profile1DCosine::clone() const override
";

%feature("docstring")  Profile1DCosine::className "std::string Profile1DCosine::className() const final
";

%feature("docstring")  Profile1DCosine::parDefs "std::vector<ParaMeta> Profile1DCosine::parDefs() const final
";

%feature("docstring")  Profile1DCosine::standardizedFT "double Profile1DCosine::standardizedFT(double q) const override

Returns Fourier transform of the normalized distribution; is a decay function starting at standardizedFT(0)=1. 
";

%feature("docstring")  Profile1DCosine::decayFT "double Profile1DCosine::decayFT(double q) const override

Returns Fourier transform of the distribution scaled as decay function f(x)/f(0). 
";

%feature("docstring")  Profile1DCosine::qSecondDerivative "double Profile1DCosine::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  Profile1DCosine::createSampler "std::unique_ptr< IDistribution1DSampler > Profile1DCosine::createSampler() const override
";


// File: classProfile1DGate.xml
%feature("docstring") Profile1DGate "

Square gate  IProfile1D; its Fourier transform standardizedFT(q) is a sinc function starting at standardizedFT(0)=1.

C++ includes: Profiles1D.h
";

%feature("docstring")  Profile1DGate::Profile1DGate "Profile1DGate::Profile1DGate(std::vector< double > P)
";

%feature("docstring")  Profile1DGate::Profile1DGate "Profile1DGate::Profile1DGate(double omega)
";

%feature("docstring")  Profile1DGate::clone "Profile1DGate * Profile1DGate::clone() const override
";

%feature("docstring")  Profile1DGate::className "std::string Profile1DGate::className() const final
";

%feature("docstring")  Profile1DGate::parDefs "std::vector<ParaMeta> Profile1DGate::parDefs() const final
";

%feature("docstring")  Profile1DGate::standardizedFT "double Profile1DGate::standardizedFT(double q) const override

Returns Fourier transform of the normalized distribution; is a decay function starting at standardizedFT(0)=1. 
";

%feature("docstring")  Profile1DGate::decayFT "double Profile1DGate::decayFT(double q) const override

Returns Fourier transform of the distribution scaled as decay function f(x)/f(0). 
";

%feature("docstring")  Profile1DGate::qSecondDerivative "double Profile1DGate::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  Profile1DGate::createSampler "std::unique_ptr< IDistribution1DSampler > Profile1DGate::createSampler() const override
";


// File: classProfile1DGauss.xml
%feature("docstring") Profile1DGauss "

Gaussian  IProfile1D; its Fourier transform standardizedFT(q) is a Gaussian starting at standardizedFT(0)=1.

C++ includes: Profiles1D.h
";

%feature("docstring")  Profile1DGauss::Profile1DGauss "Profile1DGauss::Profile1DGauss(std::vector< double > P)
";

%feature("docstring")  Profile1DGauss::Profile1DGauss "Profile1DGauss::Profile1DGauss(double omega)
";

%feature("docstring")  Profile1DGauss::clone "Profile1DGauss * Profile1DGauss::clone() const override
";

%feature("docstring")  Profile1DGauss::className "std::string Profile1DGauss::className() const final
";

%feature("docstring")  Profile1DGauss::parDefs "std::vector<ParaMeta> Profile1DGauss::parDefs() const final
";

%feature("docstring")  Profile1DGauss::standardizedFT "double Profile1DGauss::standardizedFT(double q) const override

Returns Fourier transform of the normalized distribution; is a decay function starting at standardizedFT(0)=1. 
";

%feature("docstring")  Profile1DGauss::decayFT "double Profile1DGauss::decayFT(double q) const override

Returns Fourier transform of the distribution scaled as decay function f(x)/f(0). 
";

%feature("docstring")  Profile1DGauss::qSecondDerivative "double Profile1DGauss::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  Profile1DGauss::createSampler "std::unique_ptr< IDistribution1DSampler > Profile1DGauss::createSampler() const override
";


// File: classProfile1DTriangle.xml
%feature("docstring") Profile1DTriangle "

Triangle  IProfile1D [1-|x|/omega if |x|<omega, and 0 otherwise]; its Fourier transform standardizedFT(q) is a squared sinc function starting at standardizedFT(0)=1.

C++ includes: Profiles1D.h
";

%feature("docstring")  Profile1DTriangle::Profile1DTriangle "Profile1DTriangle::Profile1DTriangle(std::vector< double > P)
";

%feature("docstring")  Profile1DTriangle::Profile1DTriangle "Profile1DTriangle::Profile1DTriangle(double omega)
";

%feature("docstring")  Profile1DTriangle::clone "Profile1DTriangle * Profile1DTriangle::clone() const override
";

%feature("docstring")  Profile1DTriangle::className "std::string Profile1DTriangle::className() const final
";

%feature("docstring")  Profile1DTriangle::parDefs "std::vector<ParaMeta> Profile1DTriangle::parDefs() const final
";

%feature("docstring")  Profile1DTriangle::standardizedFT "double Profile1DTriangle::standardizedFT(double q) const override

Returns Fourier transform of the normalized distribution; is a decay function starting at standardizedFT(0)=1. 
";

%feature("docstring")  Profile1DTriangle::decayFT "double Profile1DTriangle::decayFT(double q) const override

Returns Fourier transform of the distribution scaled as decay function f(x)/f(0). 
";

%feature("docstring")  Profile1DTriangle::qSecondDerivative "double Profile1DTriangle::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  Profile1DTriangle::createSampler "std::unique_ptr< IDistribution1DSampler > Profile1DTriangle::createSampler() const override
";


// File: classProfile1DVoigt.xml
%feature("docstring") Profile1DVoigt "

IProfile1D that provides a Fourier transform standardizedFT(q) in form of a pseudo-Voigt decay function eta*Gauss + (1-eta)*Cauchy, with both components starting at 1 for q=0.

C++ includes: Profiles1D.h
";

%feature("docstring")  Profile1DVoigt::Profile1DVoigt "Profile1DVoigt::Profile1DVoigt(std::vector< double > P)
";

%feature("docstring")  Profile1DVoigt::Profile1DVoigt "Profile1DVoigt::Profile1DVoigt(double omega, double eta)
";

%feature("docstring")  Profile1DVoigt::clone "Profile1DVoigt * Profile1DVoigt::clone() const override
";

%feature("docstring")  Profile1DVoigt::className "std::string Profile1DVoigt::className() const final
";

%feature("docstring")  Profile1DVoigt::parDefs "std::vector<ParaMeta> Profile1DVoigt::parDefs() const final
";

%feature("docstring")  Profile1DVoigt::standardizedFT "double Profile1DVoigt::standardizedFT(double q) const override

Returns Fourier transform of the normalized distribution; is a decay function starting at standardizedFT(0)=1. 
";

%feature("docstring")  Profile1DVoigt::decayFT "double Profile1DVoigt::decayFT(double q) const override

Returns Fourier transform of the distribution scaled as decay function f(x)/f(0). 
";

%feature("docstring")  Profile1DVoigt::eta "double Profile1DVoigt::eta() const
";

%feature("docstring")  Profile1DVoigt::qSecondDerivative "double Profile1DVoigt::qSecondDerivative() const override

Returns the negative of the second order derivative in q space around q=0. 
";

%feature("docstring")  Profile1DVoigt::createSampler "std::unique_ptr< IDistribution1DSampler > Profile1DVoigt::createSampler() const override
";

%feature("docstring")  Profile1DVoigt::pythonConstructor "std::string Profile1DVoigt::pythonConstructor() const override

Creates the Python constructor of this class (or derived classes) 
";


// File: classProfile2DCauchy.xml
%feature("docstring") Profile2DCauchy "

Two-dimensional Cauchy distribution in Fourier space; corresponds to a normalized exp(-r) in real space, with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: Profiles2D.h
";

%feature("docstring")  Profile2DCauchy::Profile2DCauchy "Profile2DCauchy::Profile2DCauchy(std::vector< double > P)
";

%feature("docstring")  Profile2DCauchy::Profile2DCauchy "Profile2DCauchy::Profile2DCauchy(double omega_x, double omega_y, double gamma)
";

%feature("docstring")  Profile2DCauchy::clone "Profile2DCauchy * Profile2DCauchy::clone() const override
";

%feature("docstring")  Profile2DCauchy::className "std::string Profile2DCauchy::className() const final
";

%feature("docstring")  Profile2DCauchy::parDefs "std::vector<ParaMeta> Profile2DCauchy::parDefs() const final
";

%feature("docstring")  Profile2DCauchy::standardizedFT2D "double Profile2DCauchy::standardizedFT2D(double qx, double qy) const override

Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  Profile2DCauchy::decayFT2D "double Profile2DCauchy::decayFT2D(double qx, double qy) const override
";

%feature("docstring")  Profile2DCauchy::createSampler "std::unique_ptr< IDistribution2DSampler > Profile2DCauchy::createSampler() const override
";


// File: classProfile2DComponents.xml
%feature("docstring") Profile2DComponents "

Predefined Fourier transformed distributions for functional tests.

C++ includes: Profile2DComponents.h
";

%feature("docstring")  Profile2DComponents::Profile2DComponents "Profile2DComponents::Profile2DComponents()
";


// File: classProfile2DCone.xml
%feature("docstring") Profile2DCone "

Two-dimensional cone distribution in Fourier space; corresponds to 1-r if r<1 (and 0 otherwise) in real space with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: Profiles2D.h
";

%feature("docstring")  Profile2DCone::Profile2DCone "Profile2DCone::Profile2DCone(std::vector< double > P)
";

%feature("docstring")  Profile2DCone::Profile2DCone "Profile2DCone::Profile2DCone(double omega_x, double omega_y, double gamma)
";

%feature("docstring")  Profile2DCone::clone "Profile2DCone * Profile2DCone::clone() const override
";

%feature("docstring")  Profile2DCone::className "std::string Profile2DCone::className() const final
";

%feature("docstring")  Profile2DCone::parDefs "std::vector<ParaMeta> Profile2DCone::parDefs() const final
";

%feature("docstring")  Profile2DCone::standardizedFT2D "double Profile2DCone::standardizedFT2D(double qx, double qy) const override

Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  Profile2DCone::decayFT2D "double Profile2DCone::decayFT2D(double qx, double qy) const override
";

%feature("docstring")  Profile2DCone::createSampler "std::unique_ptr< IDistribution2DSampler > Profile2DCone::createSampler() const override
";


// File: classProfile2DGate.xml
%feature("docstring") Profile2DGate "

Two-dimensional gate distribution in Fourier space; corresponds to normalized constant if r<1 (and 0 otherwise) in real space, with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: Profiles2D.h
";

%feature("docstring")  Profile2DGate::Profile2DGate "Profile2DGate::Profile2DGate(std::vector< double > P)
";

%feature("docstring")  Profile2DGate::Profile2DGate "Profile2DGate::Profile2DGate(double omega_x, double omega_y, double gamma)
";

%feature("docstring")  Profile2DGate::clone "Profile2DGate * Profile2DGate::clone() const override
";

%feature("docstring")  Profile2DGate::className "std::string Profile2DGate::className() const final
";

%feature("docstring")  Profile2DGate::parDefs "std::vector<ParaMeta> Profile2DGate::parDefs() const final
";

%feature("docstring")  Profile2DGate::standardizedFT2D "double Profile2DGate::standardizedFT2D(double qx, double qy) const override

Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  Profile2DGate::decayFT2D "double Profile2DGate::decayFT2D(double qx, double qy) const override
";

%feature("docstring")  Profile2DGate::createSampler "std::unique_ptr< IDistribution2DSampler > Profile2DGate::createSampler() const override
";


// File: classProfile2DGauss.xml
%feature("docstring") Profile2DGauss "

Two-dimensional Gauss distribution in Fourier space; corresponds to normalized exp(-r^2/2) in real space with  $r=\\\\sqrt{(\\\\frac{x}{\\\\omega_x})^2 + (\\\\frac{y}{\\\\omega_y})^2}$.

C++ includes: Profiles2D.h
";

%feature("docstring")  Profile2DGauss::Profile2DGauss "Profile2DGauss::Profile2DGauss(std::vector< double > P)
";

%feature("docstring")  Profile2DGauss::Profile2DGauss "Profile2DGauss::Profile2DGauss(double omega_x, double omega_y, double gamma)
";

%feature("docstring")  Profile2DGauss::clone "Profile2DGauss * Profile2DGauss::clone() const override
";

%feature("docstring")  Profile2DGauss::className "std::string Profile2DGauss::className() const final
";

%feature("docstring")  Profile2DGauss::parDefs "std::vector<ParaMeta> Profile2DGauss::parDefs() const final
";

%feature("docstring")  Profile2DGauss::standardizedFT2D "double Profile2DGauss::standardizedFT2D(double qx, double qy) const override

Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  Profile2DGauss::decayFT2D "double Profile2DGauss::decayFT2D(double qx, double qy) const override
";

%feature("docstring")  Profile2DGauss::createSampler "std::unique_ptr< IDistribution2DSampler > Profile2DGauss::createSampler() const override
";


// File: classProfile2DVoigt.xml
%feature("docstring") Profile2DVoigt "

Two-dimensional Voigt distribution in Fourier space; corresponds to eta*Gauss + (1-eta)*Cauchy

C++ includes: Profiles2D.h
";

%feature("docstring")  Profile2DVoigt::Profile2DVoigt "Profile2DVoigt::Profile2DVoigt(std::vector< double > P)
";

%feature("docstring")  Profile2DVoigt::Profile2DVoigt "Profile2DVoigt::Profile2DVoigt(double omega_x, double omega_y, double gamma, double eta)
";

%feature("docstring")  Profile2DVoigt::clone "Profile2DVoigt * Profile2DVoigt::clone() const override
";

%feature("docstring")  Profile2DVoigt::className "std::string Profile2DVoigt::className() const final
";

%feature("docstring")  Profile2DVoigt::parDefs "std::vector<ParaMeta> Profile2DVoigt::parDefs() const final
";

%feature("docstring")  Profile2DVoigt::standardizedFT2D "double Profile2DVoigt::standardizedFT2D(double qx, double qy) const override

Fourier transformed distribution for q in X,Y coordinates the original distribution (in real space) is assumed to be normalized: total integral is equal to 1 
";

%feature("docstring")  Profile2DVoigt::decayFT2D "double Profile2DVoigt::decayFT2D(double qx, double qy) const override
";

%feature("docstring")  Profile2DVoigt::eta "double Profile2DVoigt::eta() const
";

%feature("docstring")  Profile2DVoigt::createSampler "std::unique_ptr< IDistribution2DSampler > Profile2DVoigt::createSampler() const override
";

%feature("docstring")  Profile2DVoigt::pythonConstructor "std::string Profile2DVoigt::pythonConstructor() const override

Creates the Python constructor of this class (or derived classes) 
";


// File: structLattice2D_1_1ReciprocalBases.xml
%feature("docstring") Lattice2D::ReciprocalBases "";


// File: classRefractiveMaterialImpl.xml
%feature("docstring") RefractiveMaterialImpl "

Material implementation based on refractive coefficiencts (valid for one wavelength value only)

C++ includes: RefractiveMaterialImpl.h
";

%feature("docstring")  RefractiveMaterialImpl::~RefractiveMaterialImpl "RefractiveMaterialImpl::~RefractiveMaterialImpl() override=default
";

%feature("docstring")  RefractiveMaterialImpl::clone "RefractiveMaterialImpl * RefractiveMaterialImpl::clone() const override

Returns pointer to a copy of material. 
";

%feature("docstring")  RefractiveMaterialImpl::refractiveIndex "complex_t RefractiveMaterialImpl::refractiveIndex(double wavelength) const override

Returns refractive index For this particular implementation returned value does not depend on passed wavelength 
";

%feature("docstring")  RefractiveMaterialImpl::refractiveIndex2 "complex_t RefractiveMaterialImpl::refractiveIndex2(double wavelength) const override

Returns squared refractive index. For this particular implementation returned value does not depend on passed wavelength. 
";

%feature("docstring")  RefractiveMaterialImpl::materialData "complex_t RefractiveMaterialImpl::materialData() const override

Returns underlying material data. 
";

%feature("docstring")  RefractiveMaterialImpl::typeID "MATERIAL_TYPES RefractiveMaterialImpl::typeID() const override

Returns type of material implementation. 
";

%feature("docstring")  RefractiveMaterialImpl::scalarSubtrSLD "complex_t RefractiveMaterialImpl::scalarSubtrSLD(double lambda0) const override

Returns (  $ \\\\pi/\\\\lambda^2 $ - sld), sld (in  $nm^{-2}$) being the scattering length density. If the wavelength associated with passed wavevector is different from the one associated with refractive coefficients used during the object construction, provided result is inconsistent. 
";

%feature("docstring")  RefractiveMaterialImpl::print "void RefractiveMaterialImpl::print(std::ostream &ostr) const override

Prints object data. 
";


// File: classRippleCosine.xml
%feature("docstring") RippleCosine "";

%feature("docstring")  RippleCosine::RippleCosine "RippleCosine::RippleCosine(double length, double width, double height)
";

%feature("docstring")  RippleCosine::~RippleCosine "RippleCosine::~RippleCosine() override
";


// File: classRippleSawtooth.xml
%feature("docstring") RippleSawtooth "";

%feature("docstring")  RippleSawtooth::RippleSawtooth "RippleSawtooth::RippleSawtooth(double length, double width, double height, double asymmetry)
";

%feature("docstring")  RippleSawtooth::~RippleSawtooth "RippleSawtooth::~RippleSawtooth() override
";


// File: classRotationEuler.xml
%feature("docstring") RotationEuler "

A sequence of rotations about the z-x'-z'' axes.

C++ includes: Rotations.h
";

%feature("docstring")  RotationEuler::RotationEuler "RotationEuler::RotationEuler(std::vector< double > P)
";

%feature("docstring")  RotationEuler::RotationEuler "RotationEuler::RotationEuler(double alpha, double beta, double gamma)
";

%feature("docstring")  RotationEuler::clone "RotationEuler* RotationEuler::clone() const override
";

%feature("docstring")  RotationEuler::className "std::string RotationEuler::className() const final
";

%feature("docstring")  RotationEuler::parDefs "std::vector<ParaMeta> RotationEuler::parDefs() const final
";

%feature("docstring")  RotationEuler::createInverse "IRotation * RotationEuler::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  RotationEuler::alpha "double RotationEuler::alpha() const
";

%feature("docstring")  RotationEuler::beta "double RotationEuler::beta() const
";

%feature("docstring")  RotationEuler::gamma "double RotationEuler::gamma() const
";

%feature("docstring")  RotationEuler::rotMatrix "RotMatrix RotationEuler::rotMatrix() const override

Returns transformation. 
";


// File: classRotationX.xml
%feature("docstring") RotationX "

A rotation about the x axis.

C++ includes: Rotations.h
";

%feature("docstring")  RotationX::RotationX "RotationX::RotationX(std::vector< double > P)

Constructor of rotation around x-axis. 
";

%feature("docstring")  RotationX::RotationX "RotationX::RotationX(double angle)
";

%feature("docstring")  RotationX::clone "RotationX* RotationX::clone() const override
";

%feature("docstring")  RotationX::className "std::string RotationX::className() const final
";

%feature("docstring")  RotationX::parDefs "std::vector<ParaMeta> RotationX::parDefs() const final
";

%feature("docstring")  RotationX::createInverse "RotationX* RotationX::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  RotationX::angle "double RotationX::angle() const
";

%feature("docstring")  RotationX::rotMatrix "RotMatrix RotationX::rotMatrix() const override

Returns transformation. 
";


// File: classRotationY.xml
%feature("docstring") RotationY "

A rotation about the y axis.

C++ includes: Rotations.h
";

%feature("docstring")  RotationY::RotationY "RotationY::RotationY(std::vector< double > P)

Constructor of rotation around y-axis. 
";

%feature("docstring")  RotationY::RotationY "RotationY::RotationY(double angle)
";

%feature("docstring")  RotationY::clone "RotationY* RotationY::clone() const override
";

%feature("docstring")  RotationY::className "std::string RotationY::className() const final
";

%feature("docstring")  RotationY::parDefs "std::vector<ParaMeta> RotationY::parDefs() const final
";

%feature("docstring")  RotationY::createInverse "RotationY* RotationY::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  RotationY::angle "double RotationY::angle() const
";

%feature("docstring")  RotationY::rotMatrix "RotMatrix RotationY::rotMatrix() const override

Returns transformation. 
";


// File: classRotationZ.xml
%feature("docstring") RotationZ "

A rotation about the z axis.

C++ includes: Rotations.h
";

%feature("docstring")  RotationZ::RotationZ "RotationZ::RotationZ(std::vector< double > P)

Constructor of rotation around z-axis. 
";

%feature("docstring")  RotationZ::RotationZ "RotationZ::RotationZ(double angle)
";

%feature("docstring")  RotationZ::clone "RotationZ* RotationZ::clone() const override
";

%feature("docstring")  RotationZ::className "std::string RotationZ::className() const final
";

%feature("docstring")  RotationZ::parDefs "std::vector<ParaMeta> RotationZ::parDefs() const final
";

%feature("docstring")  RotationZ::createInverse "RotationZ* RotationZ::createInverse() const override

Returns a new  IRotation object that is the current object's inverse. 
";

%feature("docstring")  RotationZ::angle "double RotationZ::angle() const
";

%feature("docstring")  RotationZ::rotMatrix "RotMatrix RotationZ::rotMatrix() const override

Returns transformation. 
";


// File: structRoughnessModelWrap.xml
%feature("docstring") RoughnessModelWrap "";


// File: classSimpleSelectionRule.xml
%feature("docstring") SimpleSelectionRule "

Selection rule (v*q)modulus!=0, defined by vector v(a,b,c) and modulus.

C++ includes: ISelectionRule.h
";

%feature("docstring")  SimpleSelectionRule::SimpleSelectionRule "SimpleSelectionRule::SimpleSelectionRule(int a, int b, int c, int modulus)
";

%feature("docstring")  SimpleSelectionRule::~SimpleSelectionRule "SimpleSelectionRule::~SimpleSelectionRule() override=default
";

%feature("docstring")  SimpleSelectionRule::clone "SimpleSelectionRule * SimpleSelectionRule::clone() const override
";

%feature("docstring")  SimpleSelectionRule::coordinateSelected "bool SimpleSelectionRule::coordinateSelected(const I3 &coordinate) const override
";


// File: classSquareLattice2D.xml
%feature("docstring") SquareLattice2D "

A two-dimensional Bravais lattice with square unit cell.

C++ includes: Lattice2D.h
";

%feature("docstring")  SquareLattice2D::SquareLattice2D "SquareLattice2D::SquareLattice2D(double length, double xi=0.0)
";

%feature("docstring")  SquareLattice2D::clone "SquareLattice2D * SquareLattice2D::clone() const override
";

%feature("docstring")  SquareLattice2D::className "std::string SquareLattice2D::className() const final
";

%feature("docstring")  SquareLattice2D::parDefs "std::vector<ParaMeta> SquareLattice2D::parDefs() const final
";

%feature("docstring")  SquareLattice2D::length1 "double SquareLattice2D::length1() const override
";

%feature("docstring")  SquareLattice2D::length2 "double SquareLattice2D::length2() const override
";

%feature("docstring")  SquareLattice2D::latticeAngle "double SquareLattice2D::latticeAngle() const override
";

%feature("docstring")  SquareLattice2D::unitCellArea "double SquareLattice2D::unitCellArea() const override
";


// File: classTruncatedEllipsoid.xml
%feature("docstring") TruncatedEllipsoid "";

%feature("docstring")  TruncatedEllipsoid::TruncatedEllipsoid "TruncatedEllipsoid::TruncatedEllipsoid(double r_x, double r_y, double r_z, double height, double dh)
";

%feature("docstring")  TruncatedEllipsoid::~TruncatedEllipsoid "TruncatedEllipsoid::~TruncatedEllipsoid() override
";


// File: namespace_0d122.xml


// File: namespace_0d126.xml


// File: namespace_0d130.xml


// File: namespace_0d140.xml


// File: namespace_0d142.xml


// File: namespace_0d16.xml


// File: namespace_0d183.xml


// File: namespace_0d196.xml


// File: namespace_0d2.xml


// File: namespace_0d206.xml


// File: namespace_0d228.xml


// File: namespace_0d241.xml


// File: namespace_0d34.xml


// File: namespace_0d36.xml


// File: namespace_0d38.xml


// File: namespace_0d4.xml


// File: namespacebake.xml
%feature("docstring")  bake::CubicLattice "Lattice3D bake::CubicLattice(double a)

Returns a primitive cubic (cP) lattice with edge length a. 
";

%feature("docstring")  bake::FCCLattice "Lattice3D bake::FCCLattice(double a)

Returns a face-centered cubic (cF) lattice with edge length a. 
";

%feature("docstring")  bake::HexagonalLattice "Lattice3D bake::HexagonalLattice(double a, double c)

Returns a primitive hexagonal (hP) lattice with hexagonal edge a and height c. 
";

%feature("docstring")  bake::HCPLattice "Lattice3D bake::HCPLattice(double a, double c)

TODO: Clarify how this is meant: HCP is not a Bravais lattice. 
";

%feature("docstring")  bake::TetragonalLattice "Lattice3D bake::TetragonalLattice(double a, double c)

Returns a primitive tetragonal (tP) lattice with square base edge a and height c. 
";

%feature("docstring")  bake::BCTLattice "Lattice3D bake::BCTLattice(double a, double c)

Returns a body-centered cubic (cI) lattice with edge length a. TODO: Clarify meaning of c 
";


// File: namespaceExemplarySamples.xml
%feature("docstring")  ExemplarySamples::createBoxCompositionRotateX "MultiLayer * ExemplarySamples::createBoxCompositionRotateX()
";

%feature("docstring")  ExemplarySamples::createBoxCompositionRotateY "MultiLayer * ExemplarySamples::createBoxCompositionRotateY()
";

%feature("docstring")  ExemplarySamples::createBoxCompositionRotateZ "MultiLayer * ExemplarySamples::createBoxCompositionRotateZ()
";

%feature("docstring")  ExemplarySamples::createBoxCompositionRotateZandY "MultiLayer * ExemplarySamples::createBoxCompositionRotateZandY()
";

%feature("docstring")  ExemplarySamples::createBoxStackComposition "MultiLayer * ExemplarySamples::createBoxStackComposition()
";

%feature("docstring")  ExemplarySamples::createBoxesSquareLattice2D "MultiLayer * ExemplarySamples::createBoxesSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createCoreShellParticle "MultiLayer * ExemplarySamples::createCoreShellParticle()
";

%feature("docstring")  ExemplarySamples::createCoreShellBoxRotateZandY "MultiLayer * ExemplarySamples::createCoreShellBoxRotateZandY()
";

%feature("docstring")  ExemplarySamples::createCustomMorphology "MultiLayer * ExemplarySamples::createCustomMorphology()
";

%feature("docstring")  ExemplarySamples::createCylindersAndPrisms "MultiLayer * ExemplarySamples::createCylindersAndPrisms()
";

%feature("docstring")  ExemplarySamples::createCylindersInDWBA "MultiLayer * ExemplarySamples::createCylindersInDWBA()
";

%feature("docstring")  ExemplarySamples::createCylindersInBA "MultiLayer * ExemplarySamples::createCylindersInBA(double height=5, double radius=5)
";

%feature("docstring")  ExemplarySamples::createLargeCylindersInDWBA "MultiLayer * ExemplarySamples::createLargeCylindersInDWBA(double height=1000, double radius=500)
";

%feature("docstring")  ExemplarySamples::createRotatedCylinders "MultiLayer * ExemplarySamples::createRotatedCylinders()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayer "MultiLayer * ExemplarySamples::createFeNiBilayer()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerTanh "MultiLayer * ExemplarySamples::createFeNiBilayerTanh()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerNC "MultiLayer * ExemplarySamples::createFeNiBilayerNC()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerSpinFlip "MultiLayer * ExemplarySamples::createFeNiBilayerSpinFlip()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerSpinFlipTanh "MultiLayer * ExemplarySamples::createFeNiBilayerSpinFlipTanh()
";

%feature("docstring")  ExemplarySamples::createFeNiBilayerSpinFlipNC "MultiLayer * ExemplarySamples::createFeNiBilayerSpinFlipNC()
";

%feature("docstring")  ExemplarySamples::createHomogeneousMultilayer "MultiLayer * ExemplarySamples::createHomogeneousMultilayer()
";

%feature("docstring")  ExemplarySamples::createLattice1D "MultiLayer * ExemplarySamples::createLattice1D()
";

%feature("docstring")  ExemplarySamples::createLayersWithAbsorptionWithFF "MultiLayer * ExemplarySamples::createLayersWithAbsorptionWithFF(const IBornFF *)
";

%feature("docstring")  ExemplarySamples::createLayersWithAbsorptionBySLD "MultiLayer * ExemplarySamples::createLayersWithAbsorptionBySLD()
";

%feature("docstring")  ExemplarySamples::createMagneticSubstrateZeroField "MultiLayer * ExemplarySamples::createMagneticSubstrateZeroField()
";

%feature("docstring")  ExemplarySamples::createSimpleMagneticLayer "MultiLayer * ExemplarySamples::createSimpleMagneticLayer()
";

%feature("docstring")  ExemplarySamples::createMagneticLayer "MultiLayer * ExemplarySamples::createMagneticLayer()
";

%feature("docstring")  ExemplarySamples::createSimpleMagneticRotationWithRoughness "MultiLayer * ExemplarySamples::createSimpleMagneticRotationWithRoughness(const std::string &roughnessKey)
";

%feature("docstring")  ExemplarySamples::createMagneticRotation "MultiLayer * ExemplarySamples::createMagneticRotation()
";

%feature("docstring")  ExemplarySamples::createMagneticParticleZeroField "MultiLayer * ExemplarySamples::createMagneticParticleZeroField()
";

%feature("docstring")  ExemplarySamples::createMagneticCylinders "MultiLayer * ExemplarySamples::createMagneticCylinders()
";

%feature("docstring")  ExemplarySamples::createMagneticSpheres "MultiLayer * ExemplarySamples::createMagneticSpheres()
";

%feature("docstring")  ExemplarySamples::createMesoCrystal "MultiLayer * ExemplarySamples::createMesoCrystal()
";

%feature("docstring")  ExemplarySamples::createMultiLayerWithNCRoughness "MultiLayer * ExemplarySamples::createMultiLayerWithNCRoughness()
";

%feature("docstring")  ExemplarySamples::createMultiLayerWithRoughness "MultiLayer * ExemplarySamples::createMultiLayerWithRoughness()
";

%feature("docstring")  ExemplarySamples::createMultipleLayout "MultiLayer * ExemplarySamples::createMultipleLayout()
";

%feature("docstring")  ExemplarySamples::createRadialParaCrystal "MultiLayer * ExemplarySamples::createRadialParaCrystal()
";

%feature("docstring")  ExemplarySamples::createBasic2DParaCrystalWithFTDis "MultiLayer * ExemplarySamples::createBasic2DParaCrystalWithFTDis(const IProfile2D *pdf2)
";

%feature("docstring")  ExemplarySamples::createHexParaCrystal "MultiLayer * ExemplarySamples::createHexParaCrystal()
";

%feature("docstring")  ExemplarySamples::createRectParaCrystal "MultiLayer * ExemplarySamples::createRectParaCrystal()
";

%feature("docstring")  ExemplarySamples::createParticleComposition "MultiLayer * ExemplarySamples::createParticleComposition()
";

%feature("docstring")  ExemplarySamples::createCylindersWithSizeDistribution "MultiLayer * ExemplarySamples::createCylindersWithSizeDistribution()
";

%feature("docstring")  ExemplarySamples::createTwoTypesCylindersDistribution "MultiLayer * ExemplarySamples::createTwoTypesCylindersDistribution()
";

%feature("docstring")  ExemplarySamples::createRotatedPyramidsDistribution "MultiLayer * ExemplarySamples::createRotatedPyramidsDistribution()
";

%feature("docstring")  ExemplarySamples::createSpheresWithLimitsDistribution "MultiLayer * ExemplarySamples::createSpheresWithLimitsDistribution()
";

%feature("docstring")  ExemplarySamples::createConesWithLimitsDistribution "MultiLayer * ExemplarySamples::createConesWithLimitsDistribution()
";

%feature("docstring")  ExemplarySamples::createLinkedBoxDistribution "MultiLayer * ExemplarySamples::createLinkedBoxDistribution()
";

%feature("docstring")  ExemplarySamples::createParticleInVacuumWithFF "MultiLayer * ExemplarySamples::createParticleInVacuumWithFF(const IBornFF *)
";

%feature("docstring")  ExemplarySamples::createHardDisk "MultiLayer * ExemplarySamples::createHardDisk()
";

%feature("docstring")  ExemplarySamples::createPlainMultiLayerBySLD "MultiLayer * ExemplarySamples::createPlainMultiLayerBySLD(int n_layers=10, double thick_ti=3.0)
";

%feature("docstring")  ExemplarySamples::createResonator "MultiLayer * ExemplarySamples::createResonator(double ti_thickness=13.0)
";

%feature("docstring")  ExemplarySamples::createCosineRipple "MultiLayer * ExemplarySamples::createCosineRipple()
";

%feature("docstring")  ExemplarySamples::createTriangularRipple "MultiLayer * ExemplarySamples::createTriangularRipple(double d=0)
";

%feature("docstring")  ExemplarySamples::createAsymRipple "MultiLayer * ExemplarySamples::createAsymRipple()
";

%feature("docstring")  ExemplarySamples::createRotatedPyramids "MultiLayer * ExemplarySamples::createRotatedPyramids()
";

%feature("docstring")  ExemplarySamples::createSizeDistributionDAModel "MultiLayer * ExemplarySamples::createSizeDistributionDAModel()
";

%feature("docstring")  ExemplarySamples::createSizeDistributionLMAModel "MultiLayer * ExemplarySamples::createSizeDistributionLMAModel()
";

%feature("docstring")  ExemplarySamples::createSizeDistributionSSCAModel "MultiLayer * ExemplarySamples::createSizeDistributionSSCAModel()
";

%feature("docstring")  ExemplarySamples::createCylindersInSSCA "MultiLayer * ExemplarySamples::createCylindersInSSCA()
";

%feature("docstring")  ExemplarySamples::createSlicedComposition "MultiLayer * ExemplarySamples::createSlicedComposition()
";

%feature("docstring")  ExemplarySamples::createSlicedCylinders "MultiLayer * ExemplarySamples::createSlicedCylinders()
";

%feature("docstring")  ExemplarySamples::createSLDSlicedCylinders "MultiLayer * ExemplarySamples::createSLDSlicedCylinders()
";

%feature("docstring")  ExemplarySamples::createAveragedSlicedCylinders "MultiLayer * ExemplarySamples::createAveragedSlicedCylinders()
";

%feature("docstring")  ExemplarySamples::createThickAbsorptiveSample "MultiLayer * ExemplarySamples::createThickAbsorptiveSample()
";

%feature("docstring")  ExemplarySamples::createTransformBox "MultiLayer * ExemplarySamples::createTransformBox()
";

%feature("docstring")  ExemplarySamples::createBasic2DLattice "MultiLayer * ExemplarySamples::createBasic2DLattice()
";

%feature("docstring")  ExemplarySamples::createSquareLattice2D "MultiLayer * ExemplarySamples::createSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createCenteredSquareLattice2D "MultiLayer * ExemplarySamples::createCenteredSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createRotatedSquareLattice2D "MultiLayer * ExemplarySamples::createRotatedSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createFiniteSquareLattice2D "MultiLayer * ExemplarySamples::createFiniteSquareLattice2D()
";

%feature("docstring")  ExemplarySamples::createSuperLattice "MultiLayer * ExemplarySamples::createSuperLattice()
";


// File: namespaceff.xml


// File: namespaceMaterialUtils.xml
%feature("docstring")  MaterialUtils::ScalarReducedPotential "complex_t MaterialUtils::ScalarReducedPotential(complex_t n, R3 k, double n_ref)

Function for calculating the reduced potential, used for obtaining the Fresnel coefficients (non-polarized material case) 
";

%feature("docstring")  MaterialUtils::PolarizedReducedPotential "Eigen::Matrix2cd MaterialUtils::PolarizedReducedPotential(complex_t n, R3 b_field, R3 k, double n_ref)

Function for calculating the reduced potential, used for obtaining the Fresnel coefficients (polarized material case) 
";

%feature("docstring")  MaterialUtils::MagnetizationCorrection "Eigen::Matrix2cd MaterialUtils::MagnetizationCorrection(complex_t unit_factor, double magnetic_factor, Vec3< T > polarization)
";

%feature("docstring")  MaterialUtils::checkMaterialTypes "MATERIAL_TYPES MaterialUtils::checkMaterialTypes(const std::vector< const Material * > &materials)

Checks if all non-default materials in  materials are of the same type and returns this type. If several types of materials are involved, InvalidMaterialType identifier is returned. 
";


// File: namespacePolyhedralUtil.xml
%feature("docstring")  PolyhedralUtil::BottomZ "double PolyhedralUtil::BottomZ(const std::vector< R3 > &vertices, const IRotation *rotation)

Calculates the z-coordinate of the lowest vertex after rotation. 
";

%feature("docstring")  PolyhedralUtil::TopZ "double PolyhedralUtil::TopZ(const std::vector< R3 > &vertices, const IRotation *rotation)

Calculates the z-coordinate of the highest vertex after rotation. 
";


// File: namespacePy.xml


// File: namespacePy_1_1Import.xml
%feature("docstring")  Py::Import::createFromPython "std::unique_ptr< MultiLayer > Py::Import::createFromPython(const std::string &script, const std::string &functionName, const std::string &path=\"\")

Creates a multi layer by running python code in embedded interpreter.

Parameters:
-----------

script: 
Python script

functionName: 
A function name in this script which produces a  MultiLayer

path: 
A path to import BornAgain library. If empty, relies on PYTHONPATH 
";

%feature("docstring")  Py::Import::listOfFunctions "std::vector< std::string > Py::Import::listOfFunctions(const std::string &script, const std::string &path=\"\")

Returns list of functions defined in the script.

Parameters:
-----------

script: 
Python script

path: 
A path to import BornAgain library. If empty, relies on PYTHONPATH 
";


// File: namespacerefMat.xml


// File: namespaceripples.xml
%feature("docstring")  ripples::factor_x_box "complex_t ripples::factor_x_box(complex_t q, double l)
";

%feature("docstring")  ripples::factor_x_Gauss "complex_t ripples::factor_x_Gauss(complex_t q, double l)
";

%feature("docstring")  ripples::factor_x_Lorentz "complex_t ripples::factor_x_Lorentz(complex_t q, double l)
";

%feature("docstring")  ripples::profile_yz_bar "complex_t ripples::profile_yz_bar(complex_t qy, complex_t qz, double width, double height)

Complex form factor of rectangular ripple (bar). 
";

%feature("docstring")  ripples::profile_yz_cosine "complex_t ripples::profile_yz_cosine(complex_t qy, complex_t qz, double width, double height)

Complex form factor of cosine ripple. 
";

%feature("docstring")  ripples::profile_yz_triangular "complex_t ripples::profile_yz_triangular(complex_t qy, complex_t qz, double width, double height, double asymmetry)

Complex form factor of triangular ripple. 
";


// File: namespaceSampleUtils.xml


// File: namespaceSampleUtils_1_1Multilayer.xml
%feature("docstring")  SampleUtils::Multilayer::LayerTopRoughness "const LayerRoughness * SampleUtils::Multilayer::LayerTopRoughness(const MultiLayer &multilayer, size_t i)

Returns top roughness of layer. 
";

%feature("docstring")  SampleUtils::Multilayer::IndexOfLayer "size_t SampleUtils::Multilayer::IndexOfLayer(const MultiLayer &multilayer, const Layer *p_layer)

Returns the index of the given layer. 
";

%feature("docstring")  SampleUtils::Multilayer::ContainsCompatibleMaterials "bool SampleUtils::Multilayer::ContainsCompatibleMaterials(const MultiLayer &multilayer)

Returns true if the multilayer contains non-default materials of one type only. 
";

%feature("docstring")  SampleUtils::Multilayer::hasRoughness "bool SampleUtils::Multilayer::hasRoughness(const MultiLayer &sample)
";


// File: namespaceSampleUtils_1_1someff.xml
%feature("docstring")  SampleUtils::someff::ffSphere "complex_t SampleUtils::someff::ffSphere(C3 q, double R)

Returns the form factor of a sphere of radius R.

Used by the hard sphere and by several soft sphere classes. 
";


// File: namespacestd.xml


// File: IInterference_8cpp.xml


// File: IInterference_8h.xml


// File: Interference1DLattice_8cpp.xml


// File: Interference1DLattice_8h.xml


// File: Interference2DLattice_8cpp.xml


// File: Interference2DLattice_8h.xml


// File: Interference2DParaCrystal_8cpp.xml


// File: Interference2DParaCrystal_8h.xml


// File: Interference2DSuperLattice_8cpp.xml


// File: Interference2DSuperLattice_8h.xml


// File: Interference3DLattice_8cpp.xml


// File: Interference3DLattice_8h.xml


// File: InterferenceFinite2DLattice_8cpp.xml


// File: InterferenceFinite2DLattice_8h.xml


// File: InterferenceFinite3DLattice_8cpp.xml


// File: InterferenceFinite3DLattice_8h.xml


// File: InterferenceHardDisk_8cpp.xml


// File: InterferenceHardDisk_8h.xml


// File: InterferenceNone_8cpp.xml


// File: InterferenceNone_8h.xml


// File: InterferenceRadialParaCrystal_8cpp.xml


// File: InterferenceRadialParaCrystal_8h.xml


// File: Interferences_8h.xml


// File: InterferenceTwin_8cpp.xml


// File: InterferenceTwin_8h.xml


// File: ParticleLayout_8cpp.xml


// File: ParticleLayout_8h.xml


// File: FormFactorComponents_8cpp.xml


// File: FormFactorComponents_8h.xml


// File: IRegistry_8h.xml


// File: Profile2DComponents_8cpp.xml


// File: Profile2DComponents_8h.xml


// File: IDistribution1DSampler_8cpp.xml


// File: IDistribution1DSampler_8h.xml


// File: IDistribution2DSampler_8cpp.xml


// File: IDistribution2DSampler_8h.xml


// File: IPeakShape_8cpp.xml


// File: IPeakShape_8h.xml


// File: Profiles1D_8cpp.xml


// File: Profiles1D_8h.xml


// File: Profiles2D_8cpp.xml


// File: Profiles2D_8h.xml


// File: FormFactorBar_8cpp.xml


// File: FormFactorBar_8h.xml


// File: FormFactorBipyramid4_8cpp.xml


// File: FormFactorBipyramid4_8h.xml


// File: FormFactorBox_8cpp.xml


// File: FormFactorBox_8h.xml


// File: FormFactorCantellatedCube_8cpp.xml


// File: FormFactorCantellatedCube_8h.xml


// File: FormFactorCone_8cpp.xml


// File: FormFactorCone_8h.xml


// File: FormFactorCosineRipple_8cpp.xml


// File: FormFactorCosineRipple_8h.xml


// File: FormFactorCylinder_8cpp.xml


// File: FormFactorCylinder_8h.xml


// File: FormFactorDodecahedron_8cpp.xml


// File: FormFactorDodecahedron_8h.xml


// File: FormFactorEllipsoidalCylinder_8cpp.xml


// File: FormFactorEllipsoidalCylinder_8h.xml


// File: FormFactorFullSphere_8cpp.xml


// File: FormFactorFullSphere_8h.xml


// File: FormFactorFullSpheroid_8cpp.xml


// File: FormFactorFullSpheroid_8h.xml


// File: FormFactorHemiEllipsoid_8cpp.xml


// File: FormFactorHemiEllipsoid_8h.xml


// File: FormFactorHollowSphere_8cpp.xml


// File: FormFactorHollowSphere_8h.xml


// File: FormFactorIcosahedron_8cpp.xml


// File: FormFactorIcosahedron_8h.xml


// File: FormFactorLongBoxGauss_8cpp.xml


// File: FormFactorLongBoxGauss_8h.xml


// File: FormFactorLongBoxLorentz_8cpp.xml


// File: FormFactorLongBoxLorentz_8h.xml


// File: FormFactorPlatonicOctahedron_8cpp.xml


// File: FormFactorPlatonicOctahedron_8h.xml


// File: FormFactorPlatonicTetrahedron_8cpp.xml


// File: FormFactorPlatonicTetrahedron_8h.xml


// File: FormFactorPrism3_8cpp.xml


// File: FormFactorPrism3_8h.xml


// File: FormFactorPrism6_8cpp.xml


// File: FormFactorPrism6_8h.xml


// File: FormFactorPyramid2_8cpp.xml


// File: FormFactorPyramid2_8h.xml


// File: FormFactorPyramid3_8cpp.xml


// File: FormFactorPyramid3_8h.xml


// File: FormFactorPyramid4_8cpp.xml


// File: FormFactorPyramid4_8h.xml


// File: FormFactorPyramid6_8cpp.xml


// File: FormFactorPyramid6_8h.xml


// File: FormFactorSawtoothRipple_8cpp.xml


// File: FormFactorSawtoothRipple_8h.xml


// File: FormFactorTruncatedCube_8cpp.xml


// File: FormFactorTruncatedCube_8h.xml


// File: FormFactorTruncatedSphere_8cpp.xml


// File: FormFactorTruncatedSphere_8h.xml


// File: FormFactorTruncatedSpheroid_8cpp.xml


// File: FormFactorTruncatedSpheroid_8h.xml


// File: HardParticles_8h.xml


// File: IFormFactorPolyhedron_8cpp.xml


// File: IFormFactorPolyhedron_8h.xml


// File: IFormFactorPrism_8cpp.xml


// File: IFormFactorPrism_8h.xml


// File: IProfileRipple_8cpp.xml


// File: IProfileRipple_8h.xml


// File: Ripples_8cpp.xml


// File: Ripples_8h.xml


// File: LayerInterface_8cpp.xml


// File: LayerInterface_8h.xml


// File: LayerRoughness_8cpp.xml


// File: LayerRoughness_8h.xml


// File: BakeLattice_8cpp.xml


// File: BakeLattice_8h.xml


// File: ISelectionRule_8h.xml


// File: Lattice2D_8cpp.xml


// File: Lattice2D_8h.xml


// File: Lattice3D_8cpp.xml


// File: Lattice3D_8h.xml


// File: SomeFormFactors_8cpp.xml


// File: SomeFormFactors_8h.xml


// File: Admixtures_8h.xml


// File: BaseMaterialImpl_8h.xml


// File: MagneticMaterialImpl_8cpp.xml


// File: MagneticMaterialImpl_8h.xml


// File: Material_8cpp.xml


// File: Material_8h.xml


// File: MaterialBySLDImpl_8cpp.xml


// File: MaterialBySLDImpl_8h.xml


// File: MaterialFactoryFuncs_8cpp.xml
%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial(const std::string &name, complex_t refractive_index, R3 magnetization)

Constructs a material with  name,  refractive_index and  magnetization (in A/m). Alternatively,  $\\\\delta$ and  $\\\\beta$ for refractive index  $n = 1 - \\\\delta + i \\\\beta$ can be passed directly. With no parameters given, constructs default (vacuum) material with  $n = 1$ and zero magnetization. 
";

%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial(const std::string &name, double delta, double beta, R3 magnetization)
";

%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial()
";

%feature("docstring")  MaterialBySLD "Material MaterialBySLD()
";

%feature("docstring")  MaterialBySLD "Material MaterialBySLD(const std::string &name, double sld_real, double sld_imag, R3 magnetization)

Constructs a wavelength-independent material with a given complex-valued scattering length density (SLD). SLD values for a wide variety of materials can be found on https://sld-calculator.appspot.com/ and https://www.ncnr.nist.gov/resources/activation/ By convention, SLD imaginary part is treated as negative by default, which corresponds to attenuation of the signal. With no parameters given, MaterialBySLD constructs default (vacuum) material with zero sld and zero magnetization.

Parameters:
-----------

name: 
material name

sld_real: 
real part of the scattering length density, inverse square angstroms

sld_imag: 
imaginary part of the scattering length density, inverse square angstroms

magnetization: 
magnetization (in A/m) 
";


// File: MaterialFactoryFuncs_8h.xml
%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial()
";

%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial(const std::string &name, double delta, double beta, R3 magnetization={})
";

%feature("docstring")  HomogeneousMaterial "Material HomogeneousMaterial(const std::string &name, complex_t refractive_index, R3 magnetization={})

Constructs a material with  name,  refractive_index and  magnetization (in A/m). Alternatively,  $\\\\delta$ and  $\\\\beta$ for refractive index  $n = 1 - \\\\delta + i \\\\beta$ can be passed directly. With no parameters given, constructs default (vacuum) material with  $n = 1$ and zero magnetization. 
";

%feature("docstring")  MaterialBySLD "Material MaterialBySLD()
";

%feature("docstring")  MaterialBySLD "Material MaterialBySLD(const std::string &name, double sld_real, double sld_imag, R3 magnetization={})

Constructs a wavelength-independent material with a given complex-valued scattering length density (SLD). SLD values for a wide variety of materials can be found on https://sld-calculator.appspot.com/ and https://www.ncnr.nist.gov/resources/activation/ By convention, SLD imaginary part is treated as negative by default, which corresponds to attenuation of the signal. With no parameters given, MaterialBySLD constructs default (vacuum) material with zero sld and zero magnetization.

Parameters:
-----------

name: 
material name

sld_real: 
real part of the scattering length density, inverse square angstroms

sld_imag: 
imaginary part of the scattering length density, inverse square angstroms

magnetization: 
magnetization (in A/m) 
";


// File: MaterialUtils_8cpp.xml
%feature("docstring")  Unit_Matrix "const Eigen::Matrix2cd Unit_Matrix(Eigen::Matrix2cd::Identity())
";


// File: MaterialUtils_8h.xml


// File: RefractiveMaterialImpl_8cpp.xml


// File: RefractiveMaterialImpl_8h.xml


// File: Layer_8cpp.xml


// File: Layer_8h.xml


// File: MultiLayer_8cpp.xml


// File: MultiLayer_8h.xml


// File: MultilayerUtils_8cpp.xml


// File: MultilayerUtils_8h.xml


// File: PyImport_8cpp.xml


// File: PyImport_8h.xml


// File: RoughnessModels_8cpp.xml


// File: RoughnessModels_8h.xml


// File: Crystal_8cpp.xml


// File: Crystal_8h.xml


// File: IBornFF_8cpp.xml


// File: IBornFF_8h.xml


// File: IParticle_8cpp.xml


// File: IParticle_8h.xml


// File: MesoCrystal_8cpp.xml


// File: MesoCrystal_8h.xml


// File: Particle_8cpp.xml


// File: Particle_8h.xml


// File: ParticleComposition_8cpp.xml


// File: ParticleComposition_8h.xml


// File: ParticleCoreShell_8cpp.xml


// File: ParticleCoreShell_8h.xml


// File: PolyhedralUtil_8cpp.xml


// File: PolyhedralUtil_8h.xml


// File: ISampleNode_8cpp.xml


// File: ISampleNode_8h.xml


// File: Rotations_8cpp.xml
%feature("docstring")  createProduct "IRotation* createProduct(const IRotation &left, const IRotation &right)

Returns concatenated rotation (first right, then left). 
";


// File: Rotations_8h.xml
%feature("docstring")  createProduct "IRotation* createProduct(const IRotation &left, const IRotation &right)

Returns concatenated rotation (first right, then left). 
";


// File: Box_8cpp.xml


// File: Box_8h.xml


// File: DoubleEllipse_8cpp.xml


// File: DoubleEllipse_8h.xml


// File: IShape3D_8cpp.xml
%feature("docstring")  RectangleVertices "std::vector<R3> RectangleVertices(double length, double width, double z)

Helper functions to construct lists of vertices

Generate vertices of centered rectangle at height z 
";

%feature("docstring")  EllipseVertices "std::vector<R3> EllipseVertices(double r_x, double r_y, double z)

Generate vertices of centered ellipse with given semi-axes at height z. 
";


// File: IShape3D_8h.xml
%feature("docstring")  RectangleVertices "std::vector<R3> RectangleVertices(double length, double width, double z)

Helper functions to construct lists of vertices

Generate vertices of centered rectangle at height z 
";

%feature("docstring")  EllipseVertices "std::vector<R3> EllipseVertices(double r_x, double r_y, double z)

Generate vertices of centered ellipse with given semi-axes at height z. 
";


// File: RippleCosine_8cpp.xml


// File: RippleCosine_8h.xml


// File: RippleSawtooth_8cpp.xml


// File: RippleSawtooth_8h.xml


// File: TruncatedEllipsoid_8cpp.xml


// File: TruncatedEllipsoid_8h.xml


// File: FormFactorGauss_8cpp.xml


// File: FormFactorGauss_8h.xml


// File: FormFactorSphereGaussianRadius_8cpp.xml


// File: FormFactorSphereGaussianRadius_8h.xml


// File: FormFactorSphereLogNormalRadius_8cpp.xml


// File: FormFactorSphereLogNormalRadius_8h.xml


// File: SoftParticles_8h.xml


// File: BoxCompositionBuilder_8cpp.xml


// File: BoxCompositionBuilder_8h.xml


// File: BoxesSquareLatticeBuilder_8cpp.xml


// File: BoxesSquareLatticeBuilder_8h.xml


// File: CoreShellParticleBuilder_8cpp.xml


// File: CoreShellParticleBuilder_8h.xml


// File: CustomMorphologyBuilder_8cpp.xml


// File: CustomMorphologyBuilder_8h.xml


// File: CylindersAndPrismsBuilder_8cpp.xml


// File: CylindersAndPrismsBuilder_8h.xml


// File: CylindersBuilder_8cpp.xml


// File: CylindersBuilder_8h.xml


// File: ExemplarySamples_8h.xml


// File: FeNiBilayerBuilder_8cpp.xml


// File: FeNiBilayerBuilder_8h.xml


// File: HomogeneousMultilayerBuilder_8cpp.xml


// File: HomogeneousMultilayerBuilder_8h.xml


// File: LatticeBuilder_8cpp.xml


// File: LatticeBuilder_8h.xml


// File: LayersWithAbsorptionBuilder_8cpp.xml


// File: LayersWithAbsorptionBuilder_8h.xml


// File: LayersWithAbsorptionBySLDBuilder_8cpp.xml
%feature("docstring")  middle_layer_thickness "const double middle_layer_thickness(60.0)
";


// File: LayersWithAbsorptionBySLDBuilder_8h.xml


// File: MagneticLayersBuilder_8cpp.xml


// File: MagneticLayersBuilder_8h.xml


// File: MagneticParticlesBuilder_8cpp.xml


// File: MagneticParticlesBuilder_8h.xml


// File: MesoCrystalBuilder_8cpp.xml


// File: MesoCrystalBuilder_8h.xml


// File: MultiLayerWithNCRoughnessBuilder_8cpp.xml


// File: MultiLayerWithNCRoughnessBuilder_8h.xml


// File: MultiLayerWithRoughnessBuilder_8cpp.xml


// File: MultiLayerWithRoughnessBuilder_8h.xml


// File: MultipleLayoutBuilder_8cpp.xml


// File: MultipleLayoutBuilder_8h.xml


// File: ParaCrystalBuilder_8cpp.xml


// File: ParaCrystalBuilder_8h.xml


// File: ParticleCompositionBuilder_8cpp.xml


// File: ParticleCompositionBuilder_8h.xml


// File: ParticleDistributionsBuilder_8cpp.xml


// File: ParticleDistributionsBuilder_8h.xml


// File: ParticleInVacuumBuilder_8cpp.xml


// File: ParticleInVacuumBuilder_8h.xml


// File: PercusYevickBuilder_8cpp.xml


// File: PercusYevickBuilder_8h.xml


// File: PlainMultiLayerBySLDBuilder_8cpp.xml


// File: PlainMultiLayerBySLDBuilder_8h.xml


// File: ReferenceMaterials_8h.xml


// File: ResonatorBuilder_8cpp.xml


// File: ResonatorBuilder_8h.xml


// File: RipplesBuilder_8cpp.xml


// File: RipplesBuilder_8h.xml


// File: RotatedPyramidsBuilder_8cpp.xml


// File: RotatedPyramidsBuilder_8h.xml


// File: SizeDistributionModelsBuilder_8cpp.xml


// File: SizeDistributionModelsBuilder_8h.xml


// File: SlicedCompositionBuilder_8cpp.xml


// File: SlicedCompositionBuilder_8h.xml


// File: SlicedCylindersBuilder_8cpp.xml


// File: SlicedCylindersBuilder_8h.xml


// File: ThickAbsorptiveSampleBuilder_8cpp.xml


// File: ThickAbsorptiveSampleBuilder_8h.xml


// File: TransformationsBuilder_8cpp.xml


// File: TransformationsBuilder_8h.xml


// File: TwoDimLatticeBuilder_8cpp.xml


// File: TwoDimLatticeBuilder_8h.xml


// File: dir_220e7f16e10b4e45e27e10ed0346ff0c.xml


// File: dir_53ad17160220d2858133377088cf64b3.xml


// File: dir_7b210e8d28f50f0c519681ee1b473363.xml


// File: dir_844f24c588eea1b259def164cc466f1a.xml


// File: dir_ff19b2623e8f6ab46659baac68a70953.xml


// File: dir_da063889c15f3636a66540651967c41d.xml


// File: dir_ed097210e0926370940660d36aeab42a.xml


// File: dir_fba8602a8c23825d875c7205aab8e979.xml


// File: dir_9b633c8be420b8d6b83f5ed5376ef19b.xml


// File: dir_61bfb933e72dfe3586b97d80db501038.xml


// File: dir_8f7f72226bf217e57890a767dfa82dfa.xml


// File: dir_c4bcd3a441ff6332187b5528d22c5933.xml


// File: dir_7002b98d93049c66d9f454102abc535d.xml


// File: dir_ccd033f493018670b3204f8d6a838d21.xml


// File: dir_d9d42b37b662547974602e66402128ce.xml

